<?php
/**
 * Customizer active callbacks
 *
 * @package Theme Palace
 * @subpackage Mega Charity Pro
 * @since Mega Charity Pro 1.0.0
 */

if ( ! function_exists( 'mega_charity_pro_is_loader_enable' ) ) :
	/**
	 * Check if loader is enabled.
	 *
	 * @since Mega Charity Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function mega_charity_pro_is_loader_enable( $control ) {
		return $control->manager->get_setting( 'mega_charity_pro_theme_options[loader_enable]' )->value();
	}
endif;

if ( ! function_exists( 'mega_charity_pro_is_breadcrumb_enable' ) ) :
	/**
	 * Check if breadcrumb is enabled.
	 *
	 * @since Mega Charity Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function mega_charity_pro_is_breadcrumb_enable( $control ) {
		return $control->manager->get_setting( 'mega_charity_pro_theme_options[breadcrumb_enable]' )->value();
	}
endif;

if ( ! function_exists( 'mega_charity_pro_is_pagination_enable' ) ) :
	/**
	 * Check if pagination is enabled.
	 *
	 * @since Mega Charity Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function mega_charity_pro_is_pagination_enable( $control ) {
		return $control->manager->get_setting( 'mega_charity_pro_theme_options[pagination_enable]' )->value();
	}
endif;

if ( ! function_exists( 'mega_charity_pro_is_static_homepage_enable' ) ) :
	/**
	 * Check if static homepage is enabled.
	 *
	 * @since Mega Charity Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function mega_charity_pro_is_static_homepage_enable( $control ) {
		return ( 'page' == $control->manager->get_setting( 'show_on_front' )->value() );
	}
endif;

if ( ! function_exists( 'mega_charity_pro_is_nav_btn_enable' ) ) :
	
	function mega_charity_pro_is_nav_btn_enable( $control ) {
	return ( $control->manager->get_setting( 'mega_charity_pro_theme_options[nav_btn]' )->value() );
}
endif;

if ( ! function_exists( 'mega_charity_pro_is_footer_Section_enable' ) ) :
	
	function mega_charity_pro_is_footer_Section_enable( $control ) {
	return ( $control->manager->get_setting( 'mega_charity_pro_theme_options[footer_section]' )->value() );
}
endif;

if ( ! function_exists( 'mega_charity_pro_is_footer_menu_enable' ) ) :
	
	function mega_charity_pro_is_footer_menu_enable( $control ) {
	return ( $control->manager->get_setting( 'mega_charity_pro_theme_options[footer_menu]' )->value() && $control->manager->get_setting( 'mega_charity_pro_theme_options[footer_section]' )->value() );
}
endif;

/**
 * Front Page Active Callbacks
 */
/*=================Hero Banner====================*/

/**
 * Check if hero_banner section is enabled.
 *
 * @since Mega Charity Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_charity_pro_is_hero_banner_section_enable( $control ) {
	return ( $control->manager->get_setting( 'mega_charity_pro_theme_options[hero_banner_section_enable]' )->value() );
}

/**
 * Check if hero_banner section content type is post.
 *
 * @since Mega Charity Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_charity_pro_is_hero_banner_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_charity_pro_theme_options_hero_banner_content_type' )->value();
	return mega_charity_pro_is_hero_banner_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if hero_banner section content type is page.
 *
 * @since Mega Charity Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_charity_pro_is_hero_banner_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_charity_pro_theme_options_hero_banner_content_type' )->value();
	return mega_charity_pro_is_hero_banner_section_enable( $control ) && ( 'page' == $content_type );
}


/*=====================Service====================*/

/**
* Check if service section is enabled.
*
* @since Mega Charity Pro 1.0.0
* @param WP_Customize_Control $control WP_Customize_Control instance.
* @return bool Whether the control is active to the current preview.
*/
function mega_charity_pro_is_service_section_enable( $control ) {
	return ( $control->manager->get_setting( 'mega_charity_pro_theme_options[service_section_enable]' )->value() );
}

/**
* Check if service section content type is post.
*
* @since Mega Charity Pro 1.0.0
* @param WP_Customize_Control $control WP_Customize_Control instance.
* @return bool Whether the control is active to the current preview.
*/
function mega_charity_pro_is_service_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_charity_pro_theme_options_service_content_type' )->value();
	return mega_charity_pro_is_service_section_enable( $control ) && ( 'post' == $content_type );
}

/**
* Check if service section seperator.
*
* @since Mega Charity Pro 1.0.0
* @param WP_Customize_Control $control WP_Customize_Control instance.
* @return bool Whether the control is active to the current preview.
*/
function mega_charity_pro_is_service_section_content_seperator_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_charity_pro_theme_options_service_content_type' )->value();
	return mega_charity_pro_is_service_section_enable( $control ) && ( in_array( $content_type, array( 'page', 'post' ) ) );
}

/**
* Check if service section content type is page.
*
* @since Mega Charity Pro 1.0.0
* @param WP_Customize_Control $control WP_Customize_Control instance.
* @return bool Whether the control is active to the current preview.
*/
function mega_charity_pro_is_service_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_charity_pro_theme_options_service_content_type' )->value();
	return mega_charity_pro_is_service_section_enable( $control ) && ( 'page' == $content_type );
}

/**
* Check if service section content type is category.
*
* @since Mega Charity Pro 1.0.0
* @param WP_Customize_Control $control WP_Customize_Control instance.
* @return bool Whether the control is active to the current preview.
*/
function mega_charity_pro_is_service_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_charity_pro_theme_options_service_content_type' )->value();
	return mega_charity_pro_is_service_section_enable( $control ) && ( 'category' == $content_type );
}

/*=======================CTA========================*/
/**
 * Check if video section is enabled.
 *
 * @since mega_charity_pro_ 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_charity_pro_is_cta_section_enable( $control ) {
	return ( $control->manager->get_setting( 'mega_charity_pro_theme_options[cta_section_enable]' )->value() );
}

/**
 * Check if cta section content type is post.
 *
 * @since mega_charity_pro_ 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_charity_pro_is_cta_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_charity_pro_theme_options_cta_content_type' )->value();
	return mega_charity_pro_is_cta_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if cta section content type is page.
 *
 * @since mega_charity_pro_ 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_charity_pro_is_cta_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_charity_pro_theme_options_cta_content_type' )->value();
	return mega_charity_pro_is_cta_section_enable( $control ) && ( 'page' == $content_type );
}

/*==================About=====================*/

/**
 * Check if about section is enabled.
 *
 * @since Mega Charity Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_charity_pro_is_about_section_enable( $control ) {
	return ( $control->manager->get_setting( 'mega_charity_pro_theme_options[about_section_enable]' )->value() );
}

/**
 * Check if about section content type is post.
 *
 * @since Mega Charity Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_charity_pro_is_about_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_charity_pro_theme_options_about_content_type' )->value();
	return mega_charity_pro_is_about_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if about section content type is page.
 *
 * @since Mega Charity Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_charity_pro_is_about_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_charity_pro_theme_options_about_content_type' )->value();
	return mega_charity_pro_is_about_section_enable( $control ) && ( 'page' == $content_type );
}

/*===================Counter====================*/
/**
 * Check if counter section is enabled.
 *
 * @since Mega Charity Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_charity_pro_is_counter_design_enable( $control ) {
	$home_layout = $control->manager->get_setting( 'mega_charity_pro_theme_options[home_layout]' )->value();
	return in_array($home_layout, array('default-design', 'second-design', 'seventh-design', 'eighth-design', 'ninth-design', 'tenth-design'));
}

/**
 * Check if counter section is enabled.
 *
 * @since Mega Charity Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_charity_pro_is_counter_section_enable( $control ) {
	return ( $control->manager->get_setting( 'mega_charity_pro_theme_options[counter_section_enable]' )->value() );
}

/*=====================Help Us=============================*/

/**
 * Check if help_us section is enabled.
 *
 * @since Mega Charity Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_charity_pro_is_help_us_section_enable( $control ) {
	return ( $control->manager->get_setting( 'mega_charity_pro_theme_options[help_us_section_enable]' )->value() );
}

/**
 * Check if help_us section content type is category.
 *
 * @since Mega Charity Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_charity_pro_is_help_us_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_charity_pro_theme_options_help_us_content_type' )->value();
	return mega_charity_pro_is_help_us_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if help_us section content type is post.
 *
 * @since Mega Charity Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_charity_pro_is_help_us_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_charity_pro_theme_options_help_us_content_type' )->value();
	return mega_charity_pro_is_help_us_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if help_us section content type is page.
 *
 * @since Mega Charity Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_charity_pro_is_help_us_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_charity_pro_theme_options_help_us_content_type' )->value();
	return mega_charity_pro_is_help_us_section_enable( $control ) && ( 'page' == $content_type );
}

/*=======================Pricing========================*/
/**
 * Check if video section is enabled.
 *
 * @since mega_charity_pro_ 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_charity_pro_is_pricing_section_enable( $control ) {
	return ( $control->manager->get_setting( 'mega_charity_pro_theme_options[pricing_section_enable]' )->value() );
}

/**
 * Check if pricing section content type is post.
 *
 * @since mega_charity_pro_ 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_charity_pro_is_pricing_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_charity_pro_theme_options_pricing_content_type' )->value();
	return mega_charity_pro_is_pricing_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if pricing section content type is page.
 *
 * @since mega_charity_pro_ 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_charity_pro_is_pricing_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_charity_pro_theme_options_pricing_content_type' )->value();
	return mega_charity_pro_is_pricing_section_enable( $control ) && ( 'page' == $content_type );
}

/*========================Gallery====================*/

/**
 * Check if gallery section is enabled.
 *
 * @since Mega Charity Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_charity_pro_is_gallery_section_enable( $control ) {
	return ( $control->manager->get_setting( 'mega_charity_pro_theme_options[gallery_section_enable]' )->value() );
}

/**
 * Check if gallery section content type is category.
 *
 * @since Mega Charity Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_charity_pro_is_gallery_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_charity_pro_theme_options_gallery_content_type' )->value();
	return mega_charity_pro_is_gallery_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if gallery section content type is page.
 *
 * @since Mega Charity Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_charity_pro_is_gallery_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_charity_pro_theme_options_gallery_content_type' )->value();
	return mega_charity_pro_is_gallery_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if gallery section content type is post.
 *
 * @since Mega Charity Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_charity_pro_is_gallery_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_charity_pro_theme_options_gallery_content_type' )->value();
	return mega_charity_pro_is_gallery_section_enable( $control ) && ( 'post' == $content_type );
}

/*====================stories=====================*/
/**
 * Check if stories section is enabled.
 *
 * @since Mega Charity Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_charity_pro_is_stories_section_enable( $control ) {
	return ( $control->manager->get_setting( 'mega_charity_pro_theme_options[stories_section_enable]' )->value() );
}

/**
 * Check if stories section content type is post.
 *
 * @since Mega Charity Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_charity_pro_is_stories_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_charity_pro_theme_options_stories_content_type' )->value();
	return mega_charity_pro_is_stories_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if stories section content type is page.
 *
 * @since Mega Charity Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_charity_pro_is_stories_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_charity_pro_theme_options_stories_content_type' )->value();
	return mega_charity_pro_is_stories_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if stories section content type is category.
 *
 * @since Mega Charity Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_charity_pro_is_stories_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_charity_pro_theme_options_stories_content_type' )->value();
	return mega_charity_pro_is_stories_section_enable( $control ) && ( 'category' == $content_type );
}

/*==================Testimonial===================*/

/**
 * Check if testimonial section is enabled.
 *
 * @since Mega Charity Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_charity_pro_is_testimonial_section_enable( $control ) {
	return ( $control->manager->get_setting( 'mega_charity_pro_theme_options[testimonial_section_enable]' )->value() );
}

/**
 * Check if testimonial section content type is post.
 *
 * @since Mega Charity Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_charity_pro_is_testimonial_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_charity_pro_theme_options_testimonial_content_type' )->value();
	return mega_charity_pro_is_testimonial_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if testimonial section content type is page.
 *
 * @since Mega Charity Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_charity_pro_is_testimonial_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_charity_pro_theme_options_testimonial_content_type' )->value();
	return mega_charity_pro_is_testimonial_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if testimonial section content type is category.
 *
 * @since Mega Charity Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_charity_pro_is_testimonial_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_charity_pro_theme_options_testimonial_content_type' )->value();
	return mega_charity_pro_is_testimonial_section_enable( $control ) && ( 'category' == $content_type );
}

/*===============Team======================*/


/**
 * Check if team section is enabled.
 *
 * @since Mega Charity Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_charity_pro_is_team_section_enable( $control ) {
	return ( $control->manager->get_setting( 'mega_charity_pro_theme_options[team_section_enable]' )->value() );
}

/**
 * Check if team section content type is category.
 *
 * @since Mega Charity Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_charity_pro_is_team_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_charity_pro_theme_options_team_content_type' )->value();
	return mega_charity_pro_is_team_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if team section content type is page.
 *
 * @since Mega Charity Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_charity_pro_is_team_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_charity_pro_theme_options_team_content_type' )->value();
	return mega_charity_pro_is_team_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if team section content type is post.
 *
 * @since Mega Charity Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_charity_pro_is_team_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_charity_pro_theme_options_team_content_type' )->value();
	return mega_charity_pro_is_team_section_enable( $control ) && ( 'post' == $content_type );
}

/*=========================Latest Posts==================*/

/**
 * Check if latest_posts section is enabled.
 *
 * @since Mega Charity Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_charity_pro_is_latest_posts_section_enable( $control ) {
	return ( $control->manager->get_setting( 'mega_charity_pro_theme_options[latest_posts_section_enable]' )->value() );
}

/**
 * Check if latest_posts section content type is category.
 *
 * @since Mega Charity Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_charity_pro_is_latest_posts_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_charity_pro_theme_options_latest_posts_content_type' )->value();
	return mega_charity_pro_is_latest_posts_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if latest_posts section content type is page.
 *
 * @since Mega Charity Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_charity_pro_is_latest_posts_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_charity_pro_theme_options_latest_posts_content_type' )->value();
	return mega_charity_pro_is_latest_posts_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if latest_posts section content type is post.
 *
 * @since Mega Charity Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_charity_pro_is_latest_posts_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_charity_pro_theme_options_latest_posts_content_type' )->value();
	return mega_charity_pro_is_latest_posts_section_enable( $control ) && ( 'post' == $content_type );
}

/*==================Contact Us===============*/

/**
 * Check if contact section is enabled.
 *
 * @since Mega Charity Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_charity_pro_is_contact_section_enable( $control ) {
	return ( $control->manager->get_setting( 'mega_charity_pro_theme_options[contact_section_enable]' )->value() );
}

/*==================Slider===============*/

/**
 * Check if slider section is enabled.
 *
 * @since Mega Charity Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_charity_pro_is_slider_section_enable( $control ) {
	return ( $control->manager->get_setting( 'mega_charity_pro_theme_options[slider_section_enable]' )->value() );
}

/**
 * Check if slider section content type is page.
 *
 * @since Mega Charity Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_charity_pro_is_slider_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_charity_pro_theme_options_slider_content_type' )->value();
	return mega_charity_pro_is_slider_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if slider section content type is post.
 *
 * @since Mega Charity Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_charity_pro_is_slider_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_charity_pro_theme_options_slider_content_type' )->value();
	return mega_charity_pro_is_slider_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if slider section content type is category.
 *
 * @since Mega Charity Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_charity_pro_is_slider_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_charity_pro_theme_options_slider_content_type' )->value();
	return mega_charity_pro_is_slider_section_enable( $control ) && ( 'category' == $content_type );
}

/*======================Subscription==================*/

function mega_charity_pro_is_subscription_section_enable( $control ) {
	return ( $control->manager->get_setting( 'mega_charity_pro_theme_options[subscription_section_enable]' )->value() );
}


/*=========================Blog==================*/

/**
 * Check if blog section is enabled.
 *
 * @since Mega Charity Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_charity_pro_is_blog_section_enable( $control ) {
	return ( $control->manager->get_setting( 'mega_charity_pro_theme_options[blog_section_enable]' )->value() );
}

/**
 * Check if blog section content type is category.
 *
 * @since Mega Charity Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_charity_pro_is_blog_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_charity_pro_theme_options_blog_content_type' )->value();
	return mega_charity_pro_is_blog_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if blog section content type is page.
 *
 * @since Mega Charity Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_charity_pro_is_blog_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_charity_pro_theme_options_blog_content_type' )->value();
	return mega_charity_pro_is_blog_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if blog section content type is post.
 *
 * @since Mega Charity Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_charity_pro_is_blog_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_charity_pro_theme_options_blog_content_type' )->value();
	return mega_charity_pro_is_blog_section_enable( $control ) && ( 'post' == $content_type );
}

/*==================Video=====================*/

/**
 * Check if video section is enabled.
 *
 * @since Mega Charity Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_charity_pro_is_video_section_enable( $control ) {
	return ( $control->manager->get_setting( 'mega_charity_pro_theme_options[video_section_enable]' )->value() );
}

/**
 * Check if video section content type is post.
 *
 * @since Mega Charity Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_charity_pro_is_video_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_charity_pro_theme_options_video_content_type' )->value();
	return mega_charity_pro_is_video_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if video section content type is page.
 *
 * @since Mega Charity Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_charity_pro_is_video_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_charity_pro_theme_options_video_content_type' )->value();
	return mega_charity_pro_is_video_section_enable( $control ) && ( 'page' == $content_type );
}

/*==================Medical Services===============*/

/**
 * Check if medical_services section is enabled.
 *
 * @since Mega Charity Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_charity_pro_is_medical_services_section_enable( $control ) {
	return ( $control->manager->get_setting( 'mega_charity_pro_theme_options[medical_services_section_enable]' )->value() );
}

/**
 * Check if medical_services section content type is page.
 *
 * @since Mega Charity Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_charity_pro_is_medical_services_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_charity_pro_theme_options_medical_services_content_type' )->value();
	return mega_charity_pro_is_medical_services_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if medical_services section content type is post.
 *
 * @since Mega Charity Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_charity_pro_is_medical_services_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_charity_pro_theme_options_medical_services_content_type' )->value();
	return mega_charity_pro_is_medical_services_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if medical_services section content type is category.
 *
 * @since Mega Charity Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_charity_pro_is_medical_services_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_charity_pro_theme_options_medical_services_content_type' )->value();
	return mega_charity_pro_is_medical_services_section_enable( $control ) && ( 'category' == $content_type );
}

/*=====================Medical Features====================*/

/**
* Check if medical_features section is enabled.
*
* @since Mega Charity Pro 1.0.0
* @param WP_Customize_Control $control WP_Customize_Control instance.
* @return bool Whether the control is active to the current preview.
*/
function mega_charity_pro_is_medical_features_section_enable( $control ) {
	return ( $control->manager->get_setting( 'mega_charity_pro_theme_options[medical_features_section_enable]' )->value() );
}

/**
* Check if medical_features section content type is post.
*
* @since Mega Charity Pro 1.0.0
* @param WP_Customize_Control $control WP_Customize_Control instance.
* @return bool Whether the control is active to the current preview.
*/
function mega_charity_pro_is_medical_features_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_charity_pro_theme_options_medical_features_content_type' )->value();
	return mega_charity_pro_is_medical_features_section_enable( $control ) && ( 'post' == $content_type );
}

/**
* Check if medical_features section seperator.
*
* @since Mega Charity Pro 1.0.0
* @param WP_Customize_Control $control WP_Customize_Control instance.
* @return bool Whether the control is active to the current preview.
*/
function mega_charity_pro_is_medical_features_section_content_seperator_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_charity_pro_theme_options_medical_features_content_type' )->value();
	return mega_charity_pro_is_medical_features_section_enable( $control ) && ( in_array( $content_type, array( 'page', 'post' ) ) );
}

/**
* Check if medical_features section content type is page.
*
* @since Mega Charity Pro 1.0.0
* @param WP_Customize_Control $control WP_Customize_Control instance.
* @return bool Whether the control is active to the current preview.
*/
function mega_charity_pro_is_medical_features_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_charity_pro_theme_options_medical_features_content_type' )->value();
	return mega_charity_pro_is_medical_features_section_enable( $control ) && ( 'page' == $content_type );
}

/**
* Check if medical_features section content type is category.
*
* @since Mega Charity Pro 1.0.0
* @param WP_Customize_Control $control WP_Customize_Control instance.
* @return bool Whether the control is active to the current preview.
*/
function mega_charity_pro_is_medical_features_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_charity_pro_theme_options_medical_features_content_type' )->value();
	return mega_charity_pro_is_medical_features_section_enable( $control ) && ( 'category' == $content_type );
}

/*====================Medical Reason===================*/

/**
* Check if medical_features section is enabled.
*
* @since Mega Charity Pro 1.0.0
* @param WP_Customize_Control $control WP_Customize_Control instance.
* @return bool Whether the control is active to the current preview.
*/
function mega_charity_pro_is_reason_section_enable( $control ) {
	return ( $control->manager->get_setting( 'mega_charity_pro_theme_options[reason_section_enable]' )->value() );
}

/**
 * Check if reason section content type is page.
 *
 * @since mega Charity Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_charity_pro_is_reason_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_charity_pro_theme_options_reason_content_type' )->value();
	return mega_charity_pro_is_reason_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if reason section content type is post.
 *
 * @since mega Charity Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_charity_pro_is_reason_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_charity_pro_theme_options_reason_content_type' )->value();
	return mega_charity_pro_is_reason_section_enable( $control ) && ( 'post' == $content_type );
}

/*=========================Medical News==================*/

/**
 * Check if medical_news section is enabled.
 *
 * @since Mega Charity Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_charity_pro_is_medical_news_section_enable( $control ) {
	return ( $control->manager->get_setting( 'mega_charity_pro_theme_options[medical_news_section_enable]' )->value() );
}

/**
 * Check if medical_news section content type is category.
 *
 * @since Mega Charity Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_charity_pro_is_medical_news_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_charity_pro_theme_options_medical_news_content_type' )->value();
	return mega_charity_pro_is_medical_news_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if medical_news section content type is page.
 *
 * @since Mega Charity Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_charity_pro_is_medical_news_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_charity_pro_theme_options_medical_news_content_type' )->value();
	return mega_charity_pro_is_medical_news_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if medical_news section content type is post.
 *
 * @since Mega Charity Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_charity_pro_is_medical_news_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_charity_pro_theme_options_medical_news_content_type' )->value();
	return mega_charity_pro_is_medical_news_section_enable( $control ) && ( 'post' == $content_type );
}

/*==================masonry=================*/
/**
 * Check if product section is enabled.
 *
 * @since Mega Charity Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_charity_pro_is_masonry_section_enable( $control ) {
	return ( $control->manager->get_setting( 'mega_charity_pro_theme_options[masonry_section_enable]' )->value() ) && class_exists( 'WooCommerce' );
}

/*=================recent product================*/

/**
 * Check if recent_products section is enabled.
 *
 * @since Mega Charity Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_charity_pro_is_recent_products_section_enable( $control ) {
	return ( $control->manager->get_setting( 'mega_charity_pro_theme_options[recent_products_section_enable]' )->value() );
}

function mega_charity_pro_is_recent_products_section_content_product_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_charity_pro_theme_options_recent_products_content_type' )->value();
	return mega_charity_pro_is_recent_products_section_enable( $control ) && ( 'product' == $content_type );
}

function mega_charity_pro_is_recent_products_section_content_product_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_charity_pro_theme_options_recent_products_content_type' )->value();
	return mega_charity_pro_is_recent_products_section_enable( $control ) && ( 'product-category' == $content_type );
}

/*===============featured products================*/
/**
 * Check if featured_products section is enabled.
 *
 * @since Mega Charity Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_charity_pro_is_featured_products_section_enable( $control ) {
	return ( $control->manager->get_setting( 'mega_charity_pro_theme_options[featured_products_section_enable]' )->value() );
}

/**
 * Check if featured_products section content type is product.
 *
 * @since Mega Charity Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_charity_pro_is_featured_products_section_content_product_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_charity_pro_theme_options_featured_products_content_type' )->value();
	return mega_charity_pro_is_featured_products_section_enable( $control ) && ( 'product' == $content_type );
}

/**
 * Check if featured_products section content type is page.
 *
 * @since Mega Charity Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_charity_pro_is_featured_products_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_charity_pro_theme_options_featured_products_content_type' )->value();
	return mega_charity_pro_is_featured_products_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if featured_products section content type is post.
 *
 * @since Mega Charity Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_charity_pro_is_featured_products_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_charity_pro_theme_options_featured_products_content_type' )->value();
	return mega_charity_pro_is_featured_products_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if featured_products section content type is category.
 *
 * @since Mega Charity Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_charity_pro_is_featured_products_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_charity_pro_theme_options_featured_products_content_type' )->value();
	return mega_charity_pro_is_featured_products_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if featured_products section content type is product-category.
 *
 * @since Mega Charity Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_charity_pro_is_featured_products_section_content_product_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_charity_pro_theme_options_featured_products_content_type' )->value();
	return mega_charity_pro_is_featured_products_section_enable( $control ) && ( 'product-category' == $content_type );
}

/*==============release=====================*/
/**
 * Check if release section is enabled.
 *
 * @since Mega Charity Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_charity_pro_is_release_section_enable( $control ) {
	return ( $control->manager->get_setting( 'mega_charity_pro_theme_options[release_section_enable]' )->value() );
}

/**
 * Check if release section content type is post.
 *
 * @since Mega Charity Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_charity_pro_is_release_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_charity_pro_theme_options_release_content_type' )->value();
	return mega_charity_pro_is_release_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if release section content type is page.
 *
 * @since Mega Charity Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_charity_pro_is_release_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_charity_pro_theme_options_release_content_type' )->value();
	return mega_charity_pro_is_release_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if release section content type is category.
 *
 * @since Mega Charity Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_charity_pro_is_release_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_charity_pro_theme_options_release_content_type' )->value();
	return mega_charity_pro_is_release_section_enable( $control ) && ( 'category' == $content_type );
}

/*=================event=========================*/

/**
 * Check if event section is enabled.
 *
 * @since Mega Charity Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_charity_pro_is_event_section_enable( $control ) {
	return ( $control->manager->get_setting( 'mega_charity_pro_theme_options[event_section_enable]' )->value() );
}

/**
 * Check if event section content type is post.
 *
 * @since Mega Charity Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_charity_pro_is_event_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_charity_pro_theme_options_event_content_type' )->value();
	return mega_charity_pro_is_event_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if event section content type is page.
 *
 * @since Mega Charity Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_charity_pro_is_event_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_charity_pro_theme_options_event_content_type' )->value();
	return mega_charity_pro_is_event_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if event section content type is category.
 *
 * @since Mega Charity Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_charity_pro_is_event_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_charity_pro_theme_options_event_content_type' )->value();
	return mega_charity_pro_is_event_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if event section content type is event.
 *
 * @since Mega Charity Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_charity_pro_is_event_section_content_event_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_charity_pro_theme_options_event_content_type' )->value();
	return mega_charity_pro_is_event_section_enable( $control ) && ( 'event' == $content_type );
}

/**
 * Check if event section content type is event category.
 *
 * @since Mega Charity Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_charity_pro_is_event_section_content_event_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_charity_pro_theme_options_event_content_type' )->value();
	return mega_charity_pro_is_event_section_enable( $control ) && ( 'event-category' == $content_type );
}




////////////////////////////////

/**
 * Check if trending section is enabled.
 *
 * @since Mega Charity Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_charity_pro_is_trending_design_enable( $control ) {
	$home_layout = $control->manager->get_setting( 'mega_charity_pro_theme_options[home_layout]' )->value();
	return in_array($home_layout, array('default-design', 'third-design', 'fifth-design', 'eighth-design', 'ninth-design', 'tenth-design' ));
}

/**
 * Check if trending section is enabled.
 *
 * @since Mega Charity Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_charity_pro_is_trending_section_enable( $control ) {
	return ( $control->manager->get_setting( 'mega_charity_pro_theme_options[trending_section_enable]' )->value() );
}

/**
 * Check if trending section content type is category.
 *
 * @since Mega Charity Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_charity_pro_is_trending_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_charity_pro_theme_options[trending_content_type]' )->value();
	return mega_charity_pro_is_trending_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if trending section content type is page.
 *
 * @since Mega Charity Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_charity_pro_is_trending_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_charity_pro_theme_options[trending_content_type]' )->value();
	return mega_charity_pro_is_trending_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if trending section content type is post.
 *
 * @since Mega Charity Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_charity_pro_is_trending_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_charity_pro_theme_options[trending_content_type]' )->value();
	return mega_charity_pro_is_trending_section_enable( $control ) && ( 'post' == $content_type );
}

/*end trending section*/



