	<?php
/**
 * Mega Charity Pro Customizer.
 *
 * @package Theme Palace
 * @subpackage Mega Charity Pro
 * @since Mega Charity Pro 1.0.0
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function mega_charity_pro_customize_register( $wp_customize ) {

	$options = mega_charity_pro_get_theme_options();

	// Load custom control functions.
	require get_template_directory() . '/inc/customizer/custom-controls.php';

	// Load customize active callback functions.
	require get_template_directory() . '/inc/customizer/active-callback.php';

	// Load partial callback functions.
	require get_template_directory() . '/inc/customizer/partial.php';

	// Load validation callback functions.
	require get_template_directory() . '/inc/customizer/validation.php';

	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
	$wp_customize->get_setting( 'header_textcolor' )->transport  = 'postMessage';

	// Remove the core header textcolor control, as it shares the main text color.
	$wp_customize->remove_control( 'header_textcolor' );

	// Header title color setting and control.
	$wp_customize->add_setting( 'mega_charity_pro_theme_options[header_title_color]', array(
		'default'           => $options['header_title_color'],
		'sanitize_callback' => 'sanitize_hex_color',
		'transport'			=> 'postMessage'
	) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'mega_charity_pro_theme_options[header_title_color]', array(
		'priority'			=> 5,
		'label'             => esc_html__( 'Header Title Color', 'mega-charity-pro' ),
		'section'           => 'colors',
	) ) );

	// Header tagline color setting and control.
	$wp_customize->add_setting( 'mega_charity_pro_theme_options[header_tagline_color]', array(
		'default'           => $options['header_tagline_color'],
		'sanitize_callback' => 'sanitize_hex_color',
		'transport'			=> 'postMessage'
	) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'mega_charity_pro_theme_options[header_tagline_color]', array(
		'priority'			=> 6,
		'label'             => esc_html__( 'Header Tagline Color', 'mega-charity-pro' ),
		'section'           => 'colors',
	) ) );

	// Site identity extra options.
	$wp_customize->add_setting( 'mega_charity_pro_theme_options[header_txt_logo_extra]', array(
		'default'           => $options['header_txt_logo_extra'],
		'sanitize_callback' => 'mega_charity_pro_sanitize_select',
		'transport'			=> 'refresh'
	) );

	$wp_customize->add_control( 'mega_charity_pro_theme_options[header_txt_logo_extra]', array(
		'priority'			=> 50,
		'type'				=> 'radio',
		'label'             => esc_html__( 'Site Identity Extra Options', 'mega-charity-pro' ),
		'section'           => 'title_tagline',
		'choices'				=> array( 
			'hide-all'     => esc_html__( 'Hide All', 'mega-charity-pro' ),
			'show-all'     => esc_html__( 'Show All', 'mega-charity-pro' ),
			'title-only'   => esc_html__( 'Title Only', 'mega-charity-pro' ),
			'tagline-only' => esc_html__( 'Tagline Only', 'mega-charity-pro' ),
			'logo-title'   => esc_html__( 'Logo + Title', 'mega-charity-pro' ),
			'logo-tagline' => esc_html__( 'Logo + Tagline', 'mega-charity-pro' ),
			)
	) );

	$wp_customize->add_setting( 'mega_charity_pro_theme_options[theme_version]', array(
		'default'           => $options['theme_version'],
		'sanitize_callback' => 'mega_charity_pro_sanitize_select',
	) );

	$wp_customize->add_control( 'mega_charity_pro_theme_options[theme_version]', array(
		'type'     => 'radio',
		'label'    => esc_html__( 'Theme Version', 'mega-charity-pro' ),
		'choices'  => array(
			'dark-version'   => esc_html__( 'Dark Version', 'mega-charity-pro' ),
            'lite-version'   => esc_html__( 'Lite Version', 'mega-charity-pro' ),
		),
		'section'  => 'colors',
	) );

	/**
	 * Custom colors.
	 */
	$wp_customize->add_setting( 'mega_charity_pro_theme_options[colorscheme]', array(
		'default'           => $options['colorscheme'],
		'sanitize_callback' => 'mega_charity_pro_sanitize_select',
	) );

	$wp_customize->add_control( 'mega_charity_pro_theme_options[colorscheme]', array(
		'type'    => 'radio',
		'label'    => esc_html__( 'Color Scheme', 'mega-charity-pro' ),
		'choices'  => array(
			'default'   => esc_html__( 'Default', 'mega-charity-pro' ),
            'blue'      => esc_html__( 'Blue', 'mega-charity-pro' ),
            'green'     => esc_html__( 'Green', 'mega-charity-pro' ),
            'red'       => esc_html__( 'Red', 'mega-charity-pro' ),
            'yellow'    => esc_html__( 'Yellow', 'mega-charity-pro' ),
            'custom'    => esc_html__( 'Custom', 'mega-charity-pro' ),
		),
		'section'  => 'colors',
	) );


	$wp_customize->add_setting( 'mega_charity_pro_theme_options[colorscheme_hue]', array(
		'default'           => $options['colorscheme_hue'],
		'sanitize_callback' => 'sanitize_hex_color', // The hue is stored as a positive integer.
	) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'mega_charity_pro_theme_options[colorscheme_hue]', array(
		'section'  => 'colors',
	) ) );

	// Add panel for common theme options
	$wp_customize->add_panel( 'mega_charity_pro_theme_options_panel' , array(
	    'title'      => esc_html__( 'Theme Options','mega-charity-pro' ),
	    'description'=> esc_html__( 'Mega Charity Pro Theme Options.', 'mega-charity-pro' ),
	    'priority'   => 150,
	) );

	// homepage sortable
	require get_template_directory() . '/inc/customizer/theme-options/sortable.php';

	// loader
	require get_template_directory() . '/inc/customizer/theme-options/loader.php';

	// breadcrumb
	require get_template_directory() . '/inc/customizer/theme-options/breadcrumb.php';

	// typography
	require get_template_directory() . '/inc/customizer/theme-options/typography.php';

	// load layout
	require get_template_directory() . '/inc/customizer/theme-options/layout.php';

	// load menu
	require get_template_directory() . '/inc/customizer/theme-options/menu.php';

	// load static homepage option
	require get_template_directory() . '/inc/customizer/theme-options/homepage-static.php';

	// load archive option
	require get_template_directory() . '/inc/customizer/theme-options/excerpt.php';

	// load archive option
	require get_template_directory() . '/inc/customizer/theme-options/archive.php';
	
	// load single post option
	require get_template_directory() . '/inc/customizer/theme-options/single-posts.php';

	// load pagination option
	require get_template_directory() . '/inc/customizer/theme-options/pagination.php';

	// load footer option
	require get_template_directory() . '/inc/customizer/theme-options/footer.php';

	// load reset option
	require get_template_directory() . '/inc/customizer/theme-options/reset.php';


	// Add panel for front page theme options.
	$wp_customize->add_panel( 'mega_charity_pro_front_page_panel' , array(
	    'title'      => esc_html__( 'Front Page','mega-charity-pro' ),
	    'description'=> esc_html__( 'Front Page Theme Options.', 'mega-charity-pro' ),
	    'priority'   => 140,
	) );

	// load homepage layout option
	require get_template_directory() . '/inc/customizer/sections/home-layout.php';

	if( $options['home_layout'] == 'default-design-all' ){

	// load slider option
	require get_template_directory() . '/inc/customizer/sections/slider.php';

	//load Hero Slider
	require get_template_directory() . '/inc/customizer/sections/hero-banner.php';

	// load service option
	require get_template_directory() . '/inc/customizer/sections/service.php';

	//load about option
	require get_template_directory() . '/inc/customizer/sections/about.php';

	// load counter option
	require get_template_directory() . '/inc/customizer/sections/counter.php';

	//load help-us
	require get_template_directory() . '/inc/customizer/sections/help-us.php';

	//load pricing
	require get_template_directory() . '/inc/customizer/sections/pricing.php';

	//load gallery option
	require get_template_directory() . '/inc/customizer/sections/gallery.php';

	//load stories option
	require get_template_directory() . '/inc/customizer/sections/stories.php';

	//load team option
	require get_template_directory() . '/inc/customizer/sections/team.php';

	// load latest-posts option
	require get_template_directory() . '/inc/customizer/sections/latest-posts.php';

	//load video option
	require get_template_directory() . '/inc/customizer/sections/video.php';

	// load medical-services option
	require get_template_directory() . '/inc/customizer/sections/medical-services.php';

	//load medical-features option
	require get_template_directory() . '/inc/customizer/sections/medical-features.php';

	//load medical-reasons option
	require get_template_directory() . '/inc/customizer/sections/medical-reasons.php';

	//load medical-news option
	require get_template_directory() . '/inc/customizer/sections/medical-news.php';

	// load masonry option
	require get_template_directory() . '/inc/customizer/sections/masonry.php';

	// load recent-products option
	require get_template_directory() . '/inc/customizer/sections/recent-products.php';

	// load featured-products option
	require get_template_directory() . '/inc/customizer/sections/featured-products.php';

	//load cta
	require get_template_directory() . '/inc/customizer/sections/cta.php';

	// load release option
	require get_template_directory() . '/inc/customizer/sections/release.php';

	// load event option
	require get_template_directory() . '/inc/customizer/sections/event.php';

	// load testimonial option
	require get_template_directory() . '/inc/customizer/sections/testimonial.php';

	//load blog option
	require get_template_directory() . '/inc/customizer/sections/blog.php';

	//load subscription option
	require get_template_directory() . '/inc/customizer/sections/subscription.php';

	// load contact-us option
	require get_template_directory() . '/inc/customizer/sections/contact-us.php';

	}

	if( $options['home_layout'] == 'default-design' ){

	//load Hero Slider
	require get_template_directory() . '/inc/customizer/sections/hero-banner.php';

	// load service option
	require get_template_directory() . '/inc/customizer/sections/service.php';

	//load cta
	require get_template_directory() . '/inc/customizer/sections/cta.php';

	//load about option
	require get_template_directory() . '/inc/customizer/sections/about.php';

	// load counter option
	require get_template_directory() . '/inc/customizer/sections/counter.php';

	//load help-us
	require get_template_directory() . '/inc/customizer/sections/help-us.php';

	//load pricing
	require get_template_directory() . '/inc/customizer/sections/pricing.php';

	//load gallery option
	require get_template_directory() . '/inc/customizer/sections/gallery.php';

	//load stories option
	require get_template_directory() . '/inc/customizer/sections/stories.php';

	// load testimonial option
	require get_template_directory() . '/inc/customizer/sections/testimonial.php';

	//load team option
	require get_template_directory() . '/inc/customizer/sections/team.php';

	// load latest-posts option
	require get_template_directory() . '/inc/customizer/sections/latest-posts.php';

	// load contact-us option
	require get_template_directory() . '/inc/customizer/sections/contact-us.php';

	}

	if( $options['home_layout'] == 'fifth-design' ){

	// load slider option
	require get_template_directory() . '/inc/customizer/sections/slider.php';

	// load service option
	require get_template_directory() . '/inc/customizer/sections/service.php';

	//load about option
	require get_template_directory() . '/inc/customizer/sections/about.php';

	// load counter option
	require get_template_directory() . '/inc/customizer/sections/counter.php';

	//load team option
	require get_template_directory() . '/inc/customizer/sections/team.php';

	//load subscription option
	require get_template_directory() . '/inc/customizer/sections/subscription.php';

	//load blog option
	require get_template_directory() . '/inc/customizer/sections/blog.php';

	// load contact-us option
	require get_template_directory() . '/inc/customizer/sections/contact-us.php';

	}


	if( $options['home_layout'] == 'sixth-design' ){

	// load slider option
	require get_template_directory() . '/inc/customizer/sections/slider.php';

	// load service option
	require get_template_directory() . '/inc/customizer/sections/service.php';

	// load masonry option
	require get_template_directory() . '/inc/customizer/sections/masonry.php';

	// load recent-products option
	require get_template_directory() . '/inc/customizer/sections/recent-products.php';

	// load featured-products option
	require get_template_directory() . '/inc/customizer/sections/featured-products.php';

	//load help-us
	require get_template_directory() . '/inc/customizer/sections/help-us.php';

	//load blog option
	require get_template_directory() . '/inc/customizer/sections/blog.php';

	// load contact-us option
	require get_template_directory() . '/inc/customizer/sections/contact-us.php';

	}

	if( $options['home_layout'] == 'seventh-design' ){

	// load slider option
	require get_template_directory() . '/inc/customizer/sections/slider.php';

	// load medical-services option
	require get_template_directory() . '/inc/customizer/sections/medical-services.php';

	//load about option
	require get_template_directory() . '/inc/customizer/sections/about.php';

	//load medical-features option
	require get_template_directory() . '/inc/customizer/sections/medical-features.php';

	//load team option
	require get_template_directory() . '/inc/customizer/sections/team.php';

	//load medical-reasons option
	require get_template_directory() . '/inc/customizer/sections/medical-reasons.php';

	//load medical-news option
	require get_template_directory() . '/inc/customizer/sections/medical-news.php';

	// load contact-us option
	require get_template_directory() . '/inc/customizer/sections/contact-us.php';

	}

	if( $options['home_layout'] == 'eight-design' ){

	// load slider option
	require get_template_directory() . '/inc/customizer/sections/slider.php';

	// load service option
	require get_template_directory() . '/inc/customizer/sections/service.php';

	//load about option
	require get_template_directory() . '/inc/customizer/sections/about.php';

	//load cta
	require get_template_directory() . '/inc/customizer/sections/cta.php';

	//load help-us
	require get_template_directory() . '/inc/customizer/sections/help-us.php';

	// load counter option
	require get_template_directory() . '/inc/customizer/sections/counter.php';

	//load gallery option
	require get_template_directory() . '/inc/customizer/sections/gallery.php';

	//load team option
	require get_template_directory() . '/inc/customizer/sections/team.php';

	//load blog option
	require get_template_directory() . '/inc/customizer/sections/blog.php';

	// load contact-us option
	require get_template_directory() . '/inc/customizer/sections/contact-us.php';

	}

	if( $options['home_layout'] == 'ninth-design' ){

	// load slider option
	require get_template_directory() . '/inc/customizer/sections/slider.php';

	// load release option
	require get_template_directory() . '/inc/customizer/sections/release.php';

	//load cta
	require get_template_directory() . '/inc/customizer/sections/cta.php';

	// load service option
	require get_template_directory() . '/inc/customizer/sections/service.php';

	// load event option
	require get_template_directory() . '/inc/customizer/sections/event.php';

	//load team option
	require get_template_directory() . '/inc/customizer/sections/team.php';

	// load counter option
	require get_template_directory() . '/inc/customizer/sections/counter.php';

	// load recent-products option
	require get_template_directory() . '/inc/customizer/sections/recent-products.php';

	//load blog option
	require get_template_directory() . '/inc/customizer/sections/blog.php';

	// load contact-us option
	require get_template_directory() . '/inc/customizer/sections/contact-us.php';

	}

	if( $options['home_layout'] == 'tenth-design' ){

	// load slider option
	require get_template_directory() . '/inc/customizer/sections/slider.php';

	//load about option
	require get_template_directory() . '/inc/customizer/sections/about.php';

	//load video option
	require get_template_directory() . '/inc/customizer/sections/video.php';

	// load service option
	require get_template_directory() . '/inc/customizer/sections/service.php';

	// load counter option
	require get_template_directory() . '/inc/customizer/sections/counter.php';

	//load help-us
	require get_template_directory() . '/inc/customizer/sections/help-us.php';

	//load blog option
	require get_template_directory() . '/inc/customizer/sections/blog.php';

	// load contact-us option
	require get_template_directory() . '/inc/customizer/sections/contact-us.php';

	}	

}
add_action( 'customize_register', 'mega_charity_pro_customize_register' );

/*
 * Load customizer sanitization functions.
 */
require get_template_directory() . '/inc/customizer/sanitize.php';

require get_template_directory() . '/inc/customizer/customizer-style.php';
require get_template_directory() . '/inc/customizer/customizer-script.php';

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function mega_charity_pro_customize_preview_js() {
	wp_enqueue_script( 'mega-charity-pro-customizer', get_template_directory_uri() . '/assets/js/customizer' . mega_charity_pro_min() . '.js', array( 'customize-preview' ), '20151215', true );
}
add_action( 'customize_preview_init', 'mega_charity_pro_customize_preview_js' );

/**
 * Load dynamic logic for the customizer controls area.
 */
function mega_charity_pro_customize_control_js() {
	// fontawesome
	wp_enqueue_style( 'font-awesome-css', get_template_directory_uri() . '/assets/css/font-awesome' . mega_charity_pro_min() . '.css' );
	
	// Choose from select jquery.
	wp_enqueue_style( 'chosen-css', get_template_directory_uri() . '/assets/css/chosen' . mega_charity_pro_min() . '.css' );


	wp_enqueue_script( 'jquery-chosen', get_template_directory_uri() . '/assets/js/chosen.jquery' . mega_charity_pro_min() . '.js', array( 'jquery' ), '1.4.2', true );

	// simple icon picker
	wp_enqueue_style( 'simple-iconpicker-css', get_template_directory_uri() . '/assets/css/simple-iconpicker' . mega_charity_pro_min() . '.css' );
	wp_enqueue_script( 'jquery-simple-iconpicker', get_template_directory_uri() . '/assets/js/simple-iconpicker' . mega_charity_pro_min() . '.js', array( 'jquery' ), '', true );

	wp_enqueue_style( 'mega-charity-pro-customize-controls-css', get_template_directory_uri() . '/assets/css/customize-controls.css' );

	wp_add_inline_style( 'mega-charity-pro-customize-controls-css', mega_charity_pro_customizer_style() );
	
	wp_enqueue_script( 'mega-charity-pro-customize-controls', get_template_directory_uri() . '/assets/js/customize-controls' . mega_charity_pro_min() . '.js', array(), '1.0', true );

	wp_add_inline_script( 'mega-charity-pro-customize-controls', mega_charity_pro_customizer_script() );

	$mega_charity_pro_reset_data = array(
		'reset_message' => esc_html__( 'Refresh the customizer page after saving to view reset effects', 'mega-charity-pro' )
	);


	
	
	// Send list of color variables as object to custom customizer js
	wp_localize_script( 'mega-charity-pro-customize-controls', 'mega_charity_pro_reset_data', $mega_charity_pro_reset_data );
}
add_action( 'customize_controls_enqueue_scripts', 'mega_charity_pro_customize_control_js' );

if ( !function_exists( 'mega_charity_pro_reset_options' ) ) :
	/**
	 * Reset all options
	 *
	 * @since Mega Charity Pro 1.0.0
	 *
	 * @param bool $checked Whether the reset is checked.
	 * @return bool Whether the reset is checked.
	 */
	function mega_charity_pro_reset_options() {
		$options = mega_charity_pro_get_theme_options();
		if ( true === $options['reset_options'] ) {
			// Reset custom theme options.
			set_theme_mod( 'mega_charity_pro_theme_options', array() );
			// Reset custom header and backgrounds.
			remove_theme_mod( 'header_image' );
			remove_theme_mod( 'header_image_data' );
			remove_theme_mod( 'background_image' );
			remove_theme_mod( 'background_color' );
			remove_theme_mod( 'header_textcolor' );
	    }
	  	else {
		    return false;
	  	}
	}
endif;
add_action( 'customize_save_after', 'mega_charity_pro_reset_options' );
