<?php
/**
 * Customizer default options
 *
 * @package Theme Palace
 * @subpackage Mega Charity Pro
 * @since Mega Charity Pro 1.0.0
 * @return array An array of default values
 */

function mega_charity_pro_get_default_theme_options() {
	$theme_data = wp_get_theme();
	$mega_charity_pro_default_options = array(
		// Color Options
		'header_title_color'			=> '#000',
		'header_tagline_color'			=> '#fff',
		'header_txt_logo_extra'			=> 'show-all',
		'colorscheme_hue'				=> '#ff6633',
		'colorscheme'					=> 'default',
		'theme_version'					=> 'lite-version',
		'home_layout'					=> 'default-design',
		
		// typography Options
		'theme_typography' 				=> 'default',
		'body_theme_typography' 		=> 'default',

		//body typography
		'body_font_family'			=> 'Muli',
		'body_font_weight'			=> 300,
		'body_font_size'			=> 16,
		'body_font_style'			=> 'normal',
		'body_text_transform'		=> 'none',

		//h1 typography
		'heading_h1_font_family'		=> 'Raleway',
		'heading_h1_font_weight'		=> 300,
		'heading_h1_text_transform'		=> 'none',
		'heading_h1_font_style'			=> 'normal',

		//h2 typography
		'heading_h2_font_family'		=> 'Raleway',
		'heading_h2_font_weight'		=> 700,
		'heading_h2_text_transform'		=> 'none',
		'heading_h2_font_style'			=> 'normal',

		//h3 typography
		'heading_h3_font_family'		=> 'Raleway',
		'heading_h3_font_weight'		=> 700,
		'heading_h3_text_transform'		=> 'none',
		'heading_h3_font_style'			=> 'normal',

		//h4 typography
		'heading_h4_font_family'		=> 'Raleway',
		'heading_h4_font_weight'		=> 700,
		'heading_h4_text_transform'		=> 'none',
		'heading_h4_font_style'			=> 'normal',

		//h5 typography
		'heading_h5_font_family'		=> 'Raleway',
		'heading_h5_font_weight'		=> 700,
		'heading_h5_text_transform'		=> 'none',
		'heading_h5_font_style'			=> 'normal',

		//h6 typography
		'heading_h6_font_family'		=> 'Raleway',
		'heading_h6_font_weight'		=> 700,
		'heading_h6_text_transform'		=> 'none',
		'heading_h6_font_style'			=> 'normal',

		//p typography
		'heading_p_font_family'			=> 'Muli',
		'heading_p_font_weight'			=> 400,
		'heading_p_text_transform'		=> 'none',
		'heading_p_font_style'			=> 'normal',

		//button
		'button_background_color'		=> '#e5f8fc',
		'button_text_color'		=> '#00afe9',
		
		// loader
		'loader_enable'         		=> false,
		'loader_icon'         			=> 'default',

		// breadcrumb
		'breadcrumb_enable'				=> true,
		'breadcrumb_separator'			=> '/',
		
		// layout 
		'site_layout'         			=> 'wide-layout',
		'sidebar_position'         		=> 'right-sidebar',
		'post_sidebar_position' 		=> 'right-sidebar',
		'page_sidebar_position' 		=> 'right-sidebar',
		
		//menu
		'menu_sticky'					=> false,
		'search_icon'					=> true,
		'nav_btn'						=> true,
		'nav_btn_txt' 					=> esc_html__( 'Donate Now', 'mega-charity-pro' ),
		'nav_btn_url' 					=> '#',

		// excerpt options
		'long_excerpt_length'           => 25,
		
		// pagination options
		'pagination_enable'         	=> true,
		'pagination_type'         		=> 'default',

		// footer options
		'copyright_text'           		=> sprintf( esc_html_x( 'Copyright &copy; %1$s %2$s', '1: Year, 2: Site Title with home URL', 'mega-charity-pro' ), '[the-year]', '[site-link]' ),
		'scroll_top_visible'        	=> true,
		'footer_info_menu'        	=> true,
		'footer_menu'        	=> true,
		'footer_section'        	=> true,
		'footer_btn_text'        	=> esc_html__('Donate Now', 'mega-charity-pro'),
		'footer_description'	=> esc_html__('The bigger issue in our society is that we don’t help poorer people (or any people) with the services they need. In other countries that provide subsidized childcare, health care, higher minimum wages, better public education. We are always there for help. :)', 'mega-charity-pro'),

		// reset options
		'reset_options'      			=> false,
		
		// homepage options
		'enable_frontpage_content' 		=> false,

		// homepage sections sortable
		'sortable' 						=> 'slider,hero_banner,service,about,counter,help_us,pricing,gallery,stories,team,latest_posts,video,medical_services,medical_features,reason,medical_news,masonry,recent_products,featured_products,cta,release,event,testimonial,blog,subscription,contact',

		// blog/archive options
		'your_latest_posts_title' 		=> esc_html__( 'Blogs', 'mega-charity-pro' ),
		'single_post_hide_banner'		=> false,
		'hide_date' 					=> false,
		'hide_author'					=> false,
		'hide_banner'					=> false,		
		'blog_column'					=> 'col-2',

		// single post theme options
		'single_post_hide_date' 		=> false,
		'single_post_hide_author'		=> false,
		'single_post_hide_category'		=> false,
		'single_post_hide_tags'			=> false,

		/* Front Page */

		// hero_banner
		'hero_banner_section_enable'		=> true,
		'hero_banner_content_type'			=> 'post',
		'hero_banner_sub_title'				=> esc_html__( 'Together', 'mega-charity-pro' ),
		'hero_banner_excerpt_length'		=> 15,
		'hero_banner_btn_title'				=> esc_html__( 'Discover', 'mega-charity-pro' ),
		'hero_banner_alt_btn_title'			=> esc_html__( 'Donate Now', 'mega-charity-pro' ),

		// service
		'service_section_enable'		=> true,
		'service_section_icon_enable'	=> true,
		'service_column_layout'			=> 'col-4',
		'service_content_type'			=> 'category',
		'service_count'					=> 4,
		'service_excerpt_length'		=> 25,
		'service_title'					=> esc_html('We Are Always Where  Others <span>Needs Help</span>', 'mega-charity-pro'),
		'service_btn_title'				=> esc_html('View All Services', 'mega-charity-pro'),

		//cta
		'cta_section_enable'			=> true,
		'cta_content_type'				=> 'page',
		'cta_subtitle'					=> esc_html__( 'JOIN US', 'mega-charity-pro' ),
		'cta_excerpt_length'			=> 35,
		'cta_title'						=> esc_html__( 'We Need Your Help', 'mega-charity-pro' ),
		'cta_description'				=> esc_html__( 'The bigger issue in our society is that we don’t help poorer people (or any people) with the services they need. In other countries that provide subsidized childcare, health care, higher minimum wages, better public education', 'mega-charity-pro' ),
		'cta_button'					=> esc_html__( 'Explore More', 'mega-charity-pro' ),
		'cta_alt_button'				=> esc_html__( 'Be a Volunteer', 'mega-charity-pro' ),

		// about
		'about_section_enable'			=> true,
		'about_content_type'			=> 'page',
		'about_sub_title'				=> esc_html__( 'Keep Helping', 'mega-charity-pro' ),
		'about_btn_title'				=> esc_html__( 'More About Us', 'mega-charity-pro' ),
		'about_excerpt_length'			=> 35,

		//counter
		'counter_section_enable'		=> true,
		'counter_count'					=> 4,
		'counter_column'				=> 'col-4',

		//help us
		'help_us_section_enable'		=> true,
		'help_us_count'					=> 3,
		'help_us_excerpt_length'		=> 30,
		'help_us_content_type'			=> 'category',
		'help_us_subtitle'				=> __( 'HELP US', 'mega-charity-pro' ),
		'help_us_title'					=> __( 'Join Our Cause, Anyone Can Help', 'mega-charity-pro' ),
		'help_us_btn'					=> __( 'Learn More', 'mega-charity-pro' ),

		//pricing
		'pricing_section_enable'			=> true,
		'pricing_content_type'				=> 'page',
		'pricing_excerpt_length'			=> 35,
		'pricing_title'						=> esc_html__( 'Keep Contributing Us, We Will Keep Helping', 'mega-charity-pro' ),
		'pricing_description'				=> esc_html__( 'The bigger issue in our society is that we don’t help poorer people (or any people) with the services they need. In other countries that provide subsidized childcare, health care, higher minimum wages, better public education...', 'mega-charity-pro' ),
		'pricing_button'					=> esc_html__( 'Donate Now', 'mega-charity-pro' ),

		// gallery
		'gallery_section_enable'		=> true,
		'gallery_content_type'			=> 'category',
		'gallery_count'					=> 5,
		'gallery_title'					=> esc_html__( 'Helping The Needy People is <span>Best Feelings</span>', 'mega-charity-pro' ),
		'gallery_subtitle'				=> esc_html__( 'OUR GALLERY', 'mega-charity-pro' ),
		'gallery_button'				=> esc_html__( 'View All Photos', 'mega-charity-pro' ),

		// stories
		'stories_section_enable'	=> true,
		'stories_auto_play'			=> false,
		'stories_content_type'		=> 'category',
		'stories_count'				=> 5,
		'stories_excerpt_length'	=> 25,
		'stories_section_title'		=> esc_html__( 'Learn The Stories of Those We’ve Already', 'mega-charity-pro' ),
		'stories_btn'				=> esc_html__( 'Learn More', 'mega-charity-pro' ),

		// testimonial
		'testimonial_section_enable'	=> true,
		'testimonial_auto_play'			=> false,
		'testimonial_content_type'		=> 'category',
		'testimonial_count'				=> 4,	
		'testimonial_excerpt_length'	=> 35,	

		// team
		'team_section_enable'		=> true,
		'team_content_type'			=> 'category',
		'team_count'				=> 4,
		'team_title'				=> esc_html('Meet Our Team', 'mega-charity-pro'),
		'team_column'				=> 'col-4',

		// latest_posts
		'latest_posts_section_enable'	=> true,
		'latest_posts_content_type'		=> 'category',
		'latest_posts_count'			=> 4,
		'latest_posts_title'			=> esc_html__( 'News & Happenings Around Us', 'mega-charity-pro' ),
		'latest_posts_excerpt_length'	=> 15,

		// Contact Us
		'contact_section_enable'		=> true,
		'contact_social_menu_enable'	=> true,
		'contact_contact_info'			=> __( 'Contact us and join the team HelpYou', 'mega-charity-pro' ),
		'contact_phone_no'				=> __( '+508-982-5074', 'mega-charity-pro' ),
		'contact_email'					=> __( 'info@helpyou.com', 'mega-charity-pro' ),

		// Slider
		'slider_section_enable'		=> true,
		'slider_autoplay'			=> false,
		'slider_arrow'				=> true,
		'slider_content_type'		=> 'category',
		'slider_count'				=> 3,
		'slider_excerpt_length'		=> 30,
		'slider_btn_label'			=> esc_html__( 'Read More', 'mega-charity-pro' ),

		// subscription
		'subscription_section_enable'		=> true,
		'subscription_title'				=> esc_html__( 'Get In Touch', 'mega-charity-pro' ),
		'subscription_sub_title'			=> esc_html__( 'Newsletter', 'mega-charity-pro' ),
		'subscription_btn_label'			=> esc_html__( 'Subscribe Now', 'mega-charity-pro' ),
		'subscription_description'			=> esc_html__( 'Business consulting excepteur sint occaecat cupidatat consulting non proident, sunt in culpa qui officia deserunt laborum Market.', 'mega-charity-pro' ),

		// blog
		'blog_section_enable'	=> true,
		'blog_content_type'		=> 'category',
		'blog_count'			=> 3,
		'blog_title'			=> esc_html__( 'Latest Updates.', 'mega-charity-pro' ),
		'blog_description'			=> esc_html__( 'Although fashion and technology are often perceived as entirely', 'mega-charity-pro' ),
		'blog_excerpt_length'	=> 25,

		// video
		'video_section_enable'			=> true,
		'video_content_type'			=> 'page',
		'video_title'					=> esc_html__( 'Care About Earth, We Will', 'mega-charity-pro' ),
		'video_description'				=> esc_html__( 'Although “music that you like” should be given preference, most people have a fairly wide range of tastes, so using a certain type of music just for work isn’t out of the question.', 'mega-charity-pro' ),
		'video_excerpt_length'			=> 35,

		// medical_services
		'medical_services_section_enable'		=> true,
		'medical_services_content_type'			=> 'category',
		'medical_services_count'				=> 3,
		'medical_services_column_layout'		=> 'col-3',

		// medical_features
		'medical_features_section_enable'			=> true,
		'medical_features_column_layout'			=> 'col-3',
		'medical_features_content_type'				=> 'category',
		'medical_features_count'					=> 3,
		'medical_features_excerpt_length'			=> 20,
		'medical_features_title'					=> esc_html('Our Features', 'mega-charity-pro'),

		//reason
		'reason_section_enable'		=> true,
		'reason_excerpt_length'		=> 70,
		'reason_content_type'		=> 'post',

		// medical_news
		'medical_news_section_enable'	=> true,
		'medical_news_content_type'		=> 'category',
		'medical_news_count'			=> 3,
		'medical_news_title'			=> esc_html__( 'Latest News', 'mega-charity-pro' ),	
		'medical_news_btn'			=> esc_html__( 'View Details', 'mega-charity-pro' ),	
		'medical_news_excerpt_length'	=> 25,

		//masonry
		'masonry_section_enable'		=> false,

		//recent products
		'recent_products_section_enable'	=> false,
		'recent_products_content_type'		=> 'product-category',
		'recent_products_count'				=> 4,
		'recent_products_title'				=> esc_html__( 'Popular Products', 'mega-charity-pro' ),
		'recent_products_sub_title'			=> esc_html__( 'Latest spring collection for fashionable person like you.', 'mega-charity-pro' ),

		// Featured Products
		'featured_products_section_enable'		=> true,
		'featured_products_count'				=> 2,
		'featured_products_excerpt_length'		=> 7,
		'featured_products_content_type'		=> 'category',
		'featured_products_read_more'			=> esc_html__( 'Discover Now', 'mega-charity-pro' ),

		// release
		'release_section_enable'		=> true,
		'release_content_type'			=> 'post',
		'release_count'					=> 3,
		'release_column_layout'			=> 'col-3',
		'release_title'					=> esc_html__( 'New Releases', 'mega-charity-pro' ),
		'release_btn_title'				=> esc_html__( 'Explore More', 'mega-charity-pro' ),

		// Event
		'event_section_enable'			=> true,
		'event_content_type'			=> 'category',
		'event_count'					=> 3,
		'event_title'					=> esc_html__( 'Upcoming Events', 'mega-charity-pro' ),
		'event_subtitle'				=> esc_html__( 'Amazing shows around 2019', 'mega-charity-pro' ),
		'event_readmore'				=> esc_html__( 'Buy Ticket', 'mega-charity-pro' ),
		'event_btn_title'				=> esc_html__( 'View All Events', 'mega-charity-pro' ),

	);

	$output = apply_filters( 'mega_charity_pro_default_theme_options', $mega_charity_pro_default_options );

	// Sort array in ascending order, according to the key:
	if ( ! empty( $output ) ) {
		ksort( $output );
	}

	return $output;
}