<?php
/**
 * About Section options
 *
 * @package Theme Palace
 * @subpackage Mega Charity Pro
 * @since Mega Charity Pro 1.0.0
 */

// Add About section
$wp_customize->add_section( 'mega_charity_pro_about_section', array(
	'title'             => esc_html__( 'About Us','mega-charity-pro' ),
	'description'       => esc_html__( 'About Us Section options.', 'mega-charity-pro' ),
	'panel'             => 'mega_charity_pro_front_page_panel',
) );

$wp_customize->add_setting(
	'mega_charity_pro_about_section_setting',
	array(
		'default' => 'setting',
		'sanitize_callback' => 'mega_charity_pro_sanitize_select',
	)
);
$wp_customize->add_control(
	'mega_charity_pro_about_section_setting',
	array(
		'section'		=> 'mega_charity_pro_about_section',
		'type'			=> 'radio',
		'active_callback' 	=> 'mega_charity_pro_is_about_section_enable',
		'choices'		=> array(
				'setting' => esc_html__( 'Setting', 'mega-charity-pro' ),
				'style' => esc_html__( 'Style', 'mega-charity-pro' ),
		 	)
	)
);

// About content enable control and setting
$wp_customize->add_setting( 'mega_charity_pro_theme_options[about_section_enable]', array(
	'default'			=> 	$options['about_section_enable'],
	'sanitize_callback' => 'mega_charity_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Mega_Charity_Pro_Switch_Control( $wp_customize, 'mega_charity_pro_theme_options[about_section_enable]', array(
	'label'             => esc_html__( 'About Section Enable', 'mega-charity-pro' ),
	'section'           => 'mega_charity_pro_about_section',
	'on_off_label' 		=> mega_charity_pro_switch_options(),
) ) );

if( $options['home_layout'] == 'default-design-all' || $options['home_layout'] == 'default-design' ){

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'mega_charity_pro_theme_options[about_section_enable]', array(
		'selector'            => '#about-us .tooltiptext',
		'settings'            => 'mega_charity_pro_theme_options[about_section_enable]',
    ) );
}
}else{

	if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'mega_charity_pro_theme_options[about_section_enable]', array(
		'selector'            => '#business-about-us .tooltiptext',
		'settings'            => 'mega_charity_pro_theme_options[about_section_enable]',
    ) );
}

}

if( $options['home_layout'] == 'default-design-all' || $options['home_layout'] == 'default-design' ):

// about image setting and control.
$wp_customize->add_setting( 'mega_charity_pro_theme_options[about_image_1]', array(
	'sanitize_callback' => 'mega_charity_pro_sanitize_image'
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'mega_charity_pro_theme_options[about_image_1]',
		array(
		'label'       		=> esc_html__( 'About First Image', 'mega-charity-pro' ),
		'section'     		=> 'mega_charity_pro_about_section',
		'active_callback'	=> 'mega_charity_pro_is_about_section_enable',
) ) );

// about image setting and control.
$wp_customize->add_setting( 'mega_charity_pro_theme_options[about_image_2]', array(
	'sanitize_callback' => 'mega_charity_pro_sanitize_image'
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'mega_charity_pro_theme_options[about_image_2]',
		array(
		'label'       		=> esc_html__( 'About Second Image', 'mega-charity-pro' ),
		'section'     		=> 'mega_charity_pro_about_section',
		'active_callback'	=> 'mega_charity_pro_is_about_section_enable',
) ) );

endif;

// long Excerpt length setting and control.
$wp_customize->add_setting( 'mega_charity_pro_theme_options[about_excerpt_length]', array(
	'sanitize_callback' => 'mega_charity_pro_sanitize_number_range',
	'validate_callback' => 'mega_charity_pro_validate_long_excerpt',
	'default'			=> $options['about_excerpt_length'],
) );

$wp_customize->add_control( 'mega_charity_pro_theme_options[about_excerpt_length]', array(
	'label'       		=> esc_html__( 'About Excerpt Length', 'mega-charity-pro' ),
	'description' 		=> esc_html__( 'Total description words to be displayed in about posts.', 'mega-charity-pro' ),
	'section'     		=> 'mega_charity_pro_about_section',
	'active_callback' 	=> 'mega_charity_pro_is_about_section_enable',
	'type'        		=> 'number',
	'input_attrs' 		=> array(
		'style'       => 'width: 80px;',
		'max'         => 100,
		'min'         => 5,
	),
) );

// About content type control and setting
$wp_customize->add_setting( 'mega_charity_pro_theme_options_about_content_type', array(
	'default'          	=> $options['about_content_type'],
	'sanitize_callback' => 'mega_charity_pro_sanitize_select',
) );

$wp_customize->add_control( 'mega_charity_pro_theme_options_about_content_type', array(
	'label'             => esc_html__( 'Content Type', 'mega-charity-pro' ),
	'section'           => 'mega_charity_pro_about_section',
	'type'				=> 'select',
	'active_callback' 	=> 'mega_charity_pro_is_about_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'mega-charity-pro' ),
		'post' 		=> esc_html__( 'Post', 'mega-charity-pro' ),
	),
) );

if( $options['home_layout'] == 'default-design-all' || $options['home_layout'] == 'default-design' ):

// about sub title setting and control
$wp_customize->add_setting( 'mega_charity_pro_theme_options[about_sub_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['about_sub_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'mega_charity_pro_theme_options[about_sub_title]', array(
	'label'           	=> esc_html__( 'Sub Title', 'mega-charity-pro' ),
	'section'        	=> 'mega_charity_pro_about_section',
	'active_callback' 	=> 'mega_charity_pro_is_about_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'mega_charity_pro_theme_options[about_sub_title]', array(
		'selector'            => '#about-us h2.section-title span',
		'settings'            => 'mega_charity_pro_theme_options[about_sub_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'mega_charity_pro_about_sub_title_partial',
    ) );
}

endif;

// about pages drop down chooser control and setting
$wp_customize->add_setting( 'mega_charity_pro_theme_options[about_content_page]', array(
	'sanitize_callback' => 'mega_charity_pro_sanitize_page',
) );

$wp_customize->add_control( new Mega_Charity_Pro_Dropdown_Chooser( $wp_customize, 'mega_charity_pro_theme_options[about_content_page]', array(
	'label'             => esc_html__( 'Select Page', 'mega-charity-pro' ),
	'section'           => 'mega_charity_pro_about_section',
	'choices'			=> mega_charity_pro_page_choices(),
	'active_callback'	=> 'mega_charity_pro_is_about_section_content_page_enable',
) ) );

// about posts drop down chooser control and setting
$wp_customize->add_setting( 'mega_charity_pro_theme_options[about_content_post]', array(
	'sanitize_callback' => 'mega_charity_pro_sanitize_page',
) );

$wp_customize->add_control( new Mega_Charity_Pro_Dropdown_Chooser( $wp_customize, 'mega_charity_pro_theme_options[about_content_post]', array(
	'label'             => esc_html__( 'Select Post', 'mega-charity-pro' ),
	'section'           => 'mega_charity_pro_about_section',
	'choices'			=> mega_charity_pro_post_choices(),
	'active_callback'	=> 'mega_charity_pro_is_about_section_content_post_enable',
) ) );

// about btn title setting and control
$wp_customize->add_setting( 'mega_charity_pro_theme_options[about_btn_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['about_btn_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'mega_charity_pro_theme_options[about_btn_title]', array(
	'label'           	=> esc_html__( 'Button Label', 'mega-charity-pro' ),
	'section'        	=> 'mega_charity_pro_about_section',
	'active_callback' 	=> 'mega_charity_pro_is_about_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'mega_charity_pro_theme_options[about_btn_title]', array(
		'selector'            => '#about-us .wrapper .read-more a',
		'settings'            => 'mega_charity_pro_theme_options[about_btn_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'mega_charity_pro_about_btn_title_partial',
    ) );
}

require get_template_directory() . '/inc/customizer/sections/color/about.php';