<?php
/**
 * Counter Section options
 *
 * @package Theme Palace
 * @subpackage Blog Diary Pro
 * @since Blog Diary Pro 1.0.0
 */

// Add Counter section
$wp_customize->add_section( 'mega_charity_pro_counter_section', array(
	'title'             => esc_html__( 'Counter','mega-charity-pro' ),
	'description'       => esc_html__( 'Counter Section options.', 'mega-charity-pro' ),
	'panel'             => 'mega_charity_pro_front_page_panel',
) );

$wp_customize->add_setting(
	'mega_charity_pro_counter_section_setting',
	array(
		'default' => 'setting',
		'sanitize_callback' => 'mega_charity_pro_sanitize_select',
	)
);
$wp_customize->add_control(
	'mega_charity_pro_counter_section_setting',
	array(
		'section'		=> 'mega_charity_pro_counter_section',
		'type'			=> 'radio',
		'active_callback' 	=> 'mega_charity_pro_is_counter_section_enable',
		'choices'		=> array(
				'setting' => esc_html__( 'Setting', 'mega-charity-pro' ),
				'style' => esc_html__( 'Style', 'mega-charity-pro' ),
		 	)
	)
);

// Counter content enable control and setting
$wp_customize->add_setting( 'mega_charity_pro_theme_options[counter_section_enable]', array(
	'default'			=> 	$options['counter_section_enable'],
	'sanitize_callback' => 'mega_charity_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Mega_Charity_Pro_Switch_Control( $wp_customize, 'mega_charity_pro_theme_options[counter_section_enable]', array(
	'label'             => esc_html__( 'Counter Section Enable', 'mega-charity-pro' ),
	'section'           => 'mega_charity_pro_counter_section',
	'on_off_label' 		=> mega_charity_pro_switch_options(),
) ) );

if( $options['home_layout'] == 'default-design-all' || $options['home_layout'] == 'default-design' || $options['home_layout'] == 'eight-design' || $options['home_layout'] == 'ninth-design' ){
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'mega_charity_pro_theme_options[counter_section_enable]', array(
		'selector'            => '#counter .tooltiptext',
		'settings'            => 'mega_charity_pro_theme_options[counter_section_enable]',
    ) );
}
}else{
	if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'mega_charity_pro_theme_options[counter_section_enable]', array(
		'selector'            => '#business-counter .tooltiptext',
		'settings'            => 'mega_charity_pro_theme_options[counter_section_enable]',
    ) );
}
}

if( in_array($options['home_layout'], array('fifth-design', 'tenth-design') ) ){

// counter image setting and control.
$wp_customize->add_setting( 'mega_charity_pro_theme_options[counter_image]', array(
	'sanitize_callback' => 'mega_charity_pro_sanitize_image'
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'mega_charity_pro_theme_options[counter_image]',
		array(
		'label'       		=> esc_html__( 'Counter BG Image', 'mega-charity-pro' ),
		'section'     		=> 'mega_charity_pro_counter_section',
		'active_callback'	=> 'mega_charity_pro_is_counter_section_enable',
) ) );

}

// counter number control and setting
$wp_customize->add_setting( 'mega_charity_pro_theme_options_counter_count', array(
	'default'          	=> $options['counter_count'],
	'sanitize_callback' => 'mega_charity_pro_sanitize_number_range',
	'validate_callback' => 'mega_charity_pro_validate_counter_count',
) );

$wp_customize->add_control( 'mega_charity_pro_theme_options_counter_count', array(
	'label'             => esc_html__( 'Number of Posts', 'mega-charity-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'mega-charity-pro' ),
	'section'           => 'mega_charity_pro_counter_section',
	'active_callback'   => 'mega_charity_pro_is_counter_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 12,
		'style' => 'width: 100px;'
		),
) );

// Counter content type control and setting
$wp_customize->add_setting( 'mega_charity_pro_theme_options[counter_column]', array(
	'default'          	=> $options['counter_column'],
	'sanitize_callback' => 'mega_charity_pro_sanitize_select',
) );

$wp_customize->add_control( 'mega_charity_pro_theme_options[counter_column]', array(
	'label'             => esc_html__( 'Column Layout', 'mega-charity-pro' ),
	'section'           => 'mega_charity_pro_counter_section',
	'type'				=> 'select',
	'active_callback' 	=> 'mega_charity_pro_is_counter_section_enable',
	'choices'			=> array(
		'col-3'      => esc_html__( 'Three Column', 'mega-charity-pro' ),
		'col-4'      => esc_html__( 'Four Column', 'mega-charity-pro' ),
		),
) );

for ( $i = 1; $i <= get_theme_mod( 'mega_charity_pro_theme_options_counter_count', 4 ); $i++ ) :

	if( in_array($options['home_layout'], array('fifth-design', 'tenth-design') ) ){

	// counter note control and setting
	$wp_customize->add_setting( 'mega_charity_pro_theme_options[counter_icon_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( new Mega_Charity_Pro_Icon_Picker( $wp_customize, 'mega_charity_pro_theme_options[counter_icon_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Icon %d', 'mega-charity-pro' ), $i ),
		'section'           => 'mega_charity_pro_counter_section',
		'active_callback'	=> 'mega_charity_pro_is_counter_section_enable',
	) ) );

	}

	// counter title setting and control
	$wp_customize->add_setting( 'mega_charity_pro_theme_options[counter_value_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'mega_charity_pro_theme_options[counter_value_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'Value %d', 'mega-charity-pro' ), $i ),
		'section'        	=> 'mega_charity_pro_counter_section',
		'active_callback' 	=> 'mega_charity_pro_is_counter_section_enable',
		'type'				=> 'text',
	) );

	// counter position setting and control
	$wp_customize->add_setting( 'mega_charity_pro_theme_options[counter_label_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'mega_charity_pro_theme_options[counter_label_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'Label %d', 'mega-charity-pro' ), $i ),
		'section'        	=> 'mega_charity_pro_counter_section',
		'active_callback' 	=> 'mega_charity_pro_is_counter_section_enable',
		'type'				=> 'textarea',
	) );

	// counter hr setting and control
	$wp_customize->add_setting( 'mega_charity_pro_theme_options[counter_hr_'. $i .']', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( new Mega_Charity_Pro_Customize_Horizontal_Line( $wp_customize, 'mega_charity_pro_theme_options[counter_hr_'. $i .']',
		array(
			'section'         => 'mega_charity_pro_counter_section',
			'active_callback' => 'mega_charity_pro_is_counter_section_enable',
			'type'			  => 'hr'
	) ) );
endfor;

require get_template_directory() . '/inc/customizer/sections/color/counter.php';
