<?php
/**
 * CTA Section options
 *
 * @package Theme Palace
 * @subpackage Mega Charity Pro
 * @since Mega Charity Pro 1.0.0
 */

// Add CTA section
$wp_customize->add_section( 'mega_charity_pro_cta_section', array(
	'title'             => esc_html__( 'CTA','mega-charity-pro' ),
	'description'       => esc_html__( 'CTA Section options.', 'mega-charity-pro' ),
	'panel'             => 'mega_charity_pro_front_page_panel',
) );

$wp_customize->add_setting(
	'mega_charity_pro_cta_section_setting',
	array(
		'default' => 'setting',
		'sanitize_callback' => 'mega_charity_pro_sanitize_select',
	)
);
$wp_customize->add_control(
	'mega_charity_pro_cta_section_setting',
	array(
		'section'		=> 'mega_charity_pro_cta_section',
		'active_callback' 	=> 'mega_charity_pro_is_cta_section_enable',
		'type'			=> 'radio',
		'choices'		=> array(
				'setting' => esc_html__( 'Setting', 'mega-charity-pro' ),
				'style' => esc_html__( 'Style', 'mega-charity-pro' ),
		 	)
	)
);

// CTA content enable control and setting
$wp_customize->add_setting( 'mega_charity_pro_theme_options[cta_section_enable]', array(
	'default'			=> 	$options['cta_section_enable'],
	'sanitize_callback' => 'mega_charity_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Mega_Charity_Pro_Switch_Control( $wp_customize, 'mega_charity_pro_theme_options[cta_section_enable]', array(
	'label'             => esc_html__( 'CTA Section Enable', 'mega-charity-pro' ),
	'section'           => 'mega_charity_pro_cta_section',
	'on_off_label' 		=> mega_charity_pro_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'mega_charity_pro_theme_options[cta_section_enable]', array(
		'selector'            => '#cta .tooltiptext',
		'settings'            => 'mega_charity_pro_theme_options[cta_section_enable]',
    ) );
}

// cta number control and setting
$wp_customize->add_setting( 'mega_charity_pro_theme_options[cta_image]', array(
	'sanitize_callback' => 'esc_url_raw',
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'mega_charity_pro_theme_options[cta_image]', array(
	'label'             => esc_html__( 'Background Image', 'mega-charity-pro' ),
	'section'           => 'mega_charity_pro_cta_section',
	'active_callback'   => 'mega_charity_pro_is_cta_section_enable',
) ) );

// cta title setting and control
$wp_customize->add_setting( 'mega_charity_pro_theme_options[cta_subtitle]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['cta_subtitle'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'mega_charity_pro_theme_options[cta_subtitle]', array(
	'label'           	=> esc_html__( 'Sub Title', 'mega-charity-pro' ),
	'section'        	=> 'mega_charity_pro_cta_section',
	'active_callback' 	=> 'mega_charity_pro_is_cta_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'mega_charity_pro_theme_options[cta_subtitle]', array(
		'selector'            => '#cta p.section-subtitle',
		'settings'            => 'mega_charity_pro_theme_options[cta_subtitle]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'mega_charity_pro_cta_subtitle_partial',
    ) );
}

// long Excerpt length setting and control.
$wp_customize->add_setting( 'mega_charity_pro_theme_options[cta_excerpt_length]', array(
	'sanitize_callback' => 'mega_charity_pro_sanitize_number_range',
	'validate_callback' => 'mega_charity_pro_validate_long_excerpt',
	'default'			=> $options['cta_excerpt_length'],
) );

$wp_customize->add_control( 'mega_charity_pro_theme_options[cta_excerpt_length]', array(
	'label'       		=> esc_html__( 'CTA Excerpt Length', 'mega-charity-pro' ),
	'description' 		=> esc_html__( 'Total description words to be displayed in cta posts.', 'mega-charity-pro' ),
	'section'     		=> 'mega_charity_pro_cta_section',
	'active_callback' 	=> 'mega_charity_pro_is_cta_section_enable',
	'type'        		=> 'number',
	'input_attrs' 		=> array(
		'style'       => 'width: 80px;',
		'max'         => 100,
		'min'         => 5,
	),
) );

// CTA content type control and setting
$wp_customize->add_setting( 'mega_charity_pro_theme_options_cta_content_type', array(
	'default'          	=> $options['cta_content_type'],
	'sanitize_callback' => 'mega_charity_pro_sanitize_select',
) );

$wp_customize->add_control( 'mega_charity_pro_theme_options_cta_content_type', array(
	'label'             => esc_html__( 'Content Type', 'mega-charity-pro' ),
	'section'           => 'mega_charity_pro_cta_section',
	'type'				=> 'select',
	'active_callback' 	=> 'mega_charity_pro_is_cta_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'mega-charity-pro' ),
		'post' 		=> esc_html__( 'Post', 'mega-charity-pro' ),
	),
) );

// cta pages drop down chooser control and setting
$wp_customize->add_setting( 'mega_charity_pro_theme_options[cta_content_page]', array(
	'sanitize_callback' => 'mega_charity_pro_sanitize_page',
) );

$wp_customize->add_control( new Mega_Charity_Pro_Dropdown_Chooser( $wp_customize, 'mega_charity_pro_theme_options[cta_content_page]', array(
	'label'             => esc_html__( 'Select Page', 'mega-charity-pro' ),
	'section'           => 'mega_charity_pro_cta_section',
	'choices'			=> mega_charity_pro_page_choices(),
	'active_callback'	=> 'mega_charity_pro_is_cta_section_content_page_enable',
) ) );

// cta posts drop down chooser control and setting
$wp_customize->add_setting( 'mega_charity_pro_theme_options[cta_content_post]', array(
	'sanitize_callback' => 'mega_charity_pro_sanitize_page',
) );

$wp_customize->add_control( new Mega_Charity_Pro_Dropdown_Chooser( $wp_customize, 'mega_charity_pro_theme_options[cta_content_post]', array(
	'label'             => esc_html__( 'Select Post', 'mega-charity-pro' ),
	'section'           => 'mega_charity_pro_cta_section',
	'choices'			=> mega_charity_pro_post_choices(),
	'active_callback'	=> 'mega_charity_pro_is_cta_section_content_post_enable',
) ) );

// cta title setting and control
$wp_customize->add_setting( 'mega_charity_pro_theme_options[cta_button]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['cta_button'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'mega_charity_pro_theme_options[cta_button]', array(
	'label'           	=> esc_html__( 'CTA Button', 'mega-charity-pro' ),
	'section'        	=> 'mega_charity_pro_cta_section',
	'active_callback' 	=> 'mega_charity_pro_is_cta_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'mega_charity_pro_theme_options[cta_button]', array(
		'selector'            => '#cta .read-more a.first-btn',
		'settings'            => 'mega_charity_pro_theme_options[cta_button]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'mega_charity_pro_cta_button_partial',
    ) );
}

// cta title setting and control
$wp_customize->add_setting( 'mega_charity_pro_theme_options[cta_alt_button]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['cta_alt_button'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'mega_charity_pro_theme_options[cta_alt_button]', array(
	'label'           	=> esc_html__( 'CTA Alt Button', 'mega-charity-pro' ),
	'section'        	=> 'mega_charity_pro_cta_section',
	'active_callback' 	=> 'mega_charity_pro_is_cta_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'mega_charity_pro_theme_options[cta_alt_button]', array(
		'selector'            => '#cta .read-more a.second-btn',
		'settings'            => 'mega_charity_pro_theme_options[cta_alt_button]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'mega_charity_pro_cta_alt_button_partial',
    ) );
}

// cta btn link setting and control
$wp_customize->add_setting( 'mega_charity_pro_theme_options[cta_alt_button_link]', array(
	'sanitize_callback' => 'esc_url_raw',
) );

$wp_customize->add_control( 'mega_charity_pro_theme_options[cta_alt_button_link]', array(
	'label'           	=> esc_html__( 'Alt Button Link', 'mega-charity-pro' ),
	'section'        	=> 'mega_charity_pro_cta_section',
	'active_callback' 	=> 'mega_charity_pro_is_cta_section_enable',
	'type'				=> 'url',
) );

require get_template_directory() . '/inc/customizer/sections/color/cta.php';