<?php
/**
* Featured Products Section options
*
* @package Theme Palace
* @subpackage Mega Charity Pro
* @since Mega Charity Pro 1.0.0
*/

// Add Featured Products section
$wp_customize->add_section( 'mega_charity_pro_featured_products_section', array(
	'title'             => esc_html__( 'Featured Products','mega-charity-pro' ),
	'description'       => esc_html__( 'Featured Products Section options.', 'mega-charity-pro' ),
	'panel'             => 'mega_charity_pro_front_page_panel',
	) );

$wp_customize->add_setting(
    'mega_charity_pro_featured_products_section_setting',
    array(
        'default' => 'setting',
        'sanitize_callback' => 'mega_charity_pro_sanitize_select',
    )
);
$wp_customize->add_control(
    'mega_charity_pro_featured_products_section_setting',
    array(
        'section'       => 'mega_charity_pro_featured_products_section',
        'type'          => 'radio',
        'active_callback'   => 'mega_charity_pro_is_featured_products_section_enable',
        'choices'       => array(
                'setting' => esc_html__( 'Setting', 'mega-charity-pro' ),
                'style' => esc_html__( 'Style', 'mega-charity-pro' ),
            )
    )
);

// Featured Products content enable control and setting
$wp_customize->add_setting( 'mega_charity_pro_theme_options[featured_products_section_enable]', array(
	'default'			=> 	$options['featured_products_section_enable'],
	'sanitize_callback' => 'mega_charity_pro_sanitize_switch_control',
	) );

$wp_customize->add_control( new Mega_Charity_Pro_Switch_Control( $wp_customize, 'mega_charity_pro_theme_options[featured_products_section_enable]', array(
	'label'             => esc_html__( 'Featured Products Section Enable', 'mega-charity-pro' ),
	'section'           => 'mega_charity_pro_featured_products_section',
	'on_off_label' 		=> mega_charity_pro_switch_options(),
	) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'mega_charity_pro_theme_options[featured_products_section_enable]', array(
		'selector'            => '#featured-products .tooltiptext',
		'settings'            => 'mega_charity_pro_theme_options[featured_products_section_enable]',
    ) );
}

// featured_products number control and setting
$wp_customize->add_setting( 'mega_charity_pro_theme_options_featured_products_count', array(
	'default'          	=> $options['featured_products_count'],
	'sanitize_callback' => 'mega_charity_pro_sanitize_number_range',
	'validate_callback' => 'mega_charity_pro_validate_featured_products_count',
	) );

$wp_customize->add_control( 'mega_charity_pro_theme_options_featured_products_count', array(
	'label'             => esc_html__( 'Number of Posts', 'mega-charity-pro' ),
	'description'       => esc_html__( 'Note: Min 2 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'mega-charity-pro' ),
	'section'           => 'mega_charity_pro_featured_products_section',
	'active_callback'   => 'mega_charity_pro_is_featured_products_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 2,
		'max'	=> 12,
		'style' => 'width: 100px;'
		),
	) );

// long Excerpt length setting and control.
$wp_customize->add_setting( 'mega_charity_pro_theme_options[featured_products_excerpt_length]', array(
	'sanitize_callback' => 'mega_charity_pro_sanitize_number_range',
	'validate_callback' => 'mega_charity_pro_validate_long_excerpt',
	'default'			=> $options['featured_products_excerpt_length'],
) );

$wp_customize->add_control( 'mega_charity_pro_theme_options[featured_products_excerpt_length]', array(
	'label'       		=> esc_html__( 'About Excerpt Length', 'mega-charity-pro' ),
	'description' 		=> esc_html__( 'Total description words to be displayed in about posts.', 'mega-charity-pro' ),
	'section'     		=> 'mega_charity_pro_featured_products_section',
	'active_callback' 	=> 'mega_charity_pro_is_featured_products_section_enable',
	'type'        		=> 'number',
	'input_attrs' 		=> array(
		'style'       => 'width: 80px;',
		'max'         => 100,
		'min'         => 5,
	),
) );

// Featured Products content type control and setting
$wp_customize->add_setting( 'mega_charity_pro_theme_options_featured_products_content_type', array(
	'default'          	=> $options['featured_products_content_type'],
	'sanitize_callback' => 'mega_charity_pro_sanitize_select',
	) );

$wp_customize->add_control( 'mega_charity_pro_theme_options_featured_products_content_type', array(
	'label'             => esc_html__( 'Content Type', 'mega-charity-pro' ),
	'section'           => 'mega_charity_pro_featured_products_section',
	'type'				=> 'select',
	'active_callback' 	=> 'mega_charity_pro_is_featured_products_section_enable',
	'choices'			=> mega_charity_pro_featured_product_content_type(),
	) );

for ( $i = 1; $i <= get_theme_mod( 'mega_charity_pro_theme_options_featured_products_count', 2 ); $i++ ) :
// featured_products pages drop down chooser control and setting
	$wp_customize->add_setting( 'mega_charity_pro_theme_options[featured_products_content_page_' . $i . ']', array(
		'sanitize_callback' => 'mega_charity_pro_sanitize_page',
		) );

$wp_customize->add_control( new Mega_Charity_Pro_Dropdown_Chooser( $wp_customize, 'mega_charity_pro_theme_options[featured_products_content_page_' . $i . ']', array(
	'label'             => sprintf( esc_html__( 'Select Page %d', 'mega-charity-pro' ), $i ),
	'section'           => 'mega_charity_pro_featured_products_section',
	'choices'			=> mega_charity_pro_page_choices(),
	'active_callback'	=> 'mega_charity_pro_is_featured_products_section_content_page_enable',
	) ) );

// featured_products posts drop down chooser control and setting
$wp_customize->add_setting( 'mega_charity_pro_theme_options[featured_products_content_post_' . $i . ']', array(
	'sanitize_callback' => 'mega_charity_pro_sanitize_page',
	) );

$wp_customize->add_control( new Mega_Charity_Pro_Dropdown_Chooser( $wp_customize, 'mega_charity_pro_theme_options[featured_products_content_post_' . $i . ']', array(
	'label'             => sprintf( esc_html__( 'Select Post %d', 'mega-charity-pro' ), $i ),
	'section'           => 'mega_charity_pro_featured_products_section',
	'choices'			=> mega_charity_pro_post_choices(),
	'active_callback'	=> 'mega_charity_pro_is_featured_products_section_content_post_enable',
	) ) );

	// featured_products posts drop down chooser control and setting
	$wp_customize->add_setting( 'mega_charity_pro_theme_options[featured_products_content_product_' . $i . ']', array(
		'sanitize_callback' => 'mega_charity_pro_sanitize_page',
		) );

	$wp_customize->add_control( new Mega_Charity_Pro_Dropdown_Chooser( $wp_customize, 'mega_charity_pro_theme_options[featured_products_content_product_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Product %d', 'mega-charity-pro' ), $i ),
		'section'           => 'mega_charity_pro_featured_products_section',
		'choices'			=> mega_charity_pro_product_choices(),
		'active_callback'	=> 'mega_charity_pro_is_featured_products_section_content_product_enable',
		) ) );

endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'mega_charity_pro_theme_options[featured_products_content_category]', array(
	'sanitize_callback' => 'mega_charity_pro_sanitize_single_category',
	) ) ;

$wp_customize->add_control( new Mega_Charity_Pro_Dropdown_Taxonomies_Control( $wp_customize,'mega_charity_pro_theme_options[featured_products_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'mega-charity-pro' ),
	'description'      	=> esc_html__( 'Note: Featured Products selected no of posts will be shown from selected category', 'mega-charity-pro' ),
	'section'           => 'mega_charity_pro_featured_products_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'mega_charity_pro_is_featured_products_section_content_category_enable'
	) ) );

	// Add dropdown category setting and control.
$wp_customize->add_setting(  'mega_charity_pro_theme_options[featured_products_content_product_category]', array(
	'sanitize_callback' => 'absint',
	) ) ;

$wp_customize->add_control( new Mega_Charity_Pro_Dropdown_Taxonomies_Control( $wp_customize,'mega_charity_pro_theme_options[featured_products_content_product_category]', array(
	'label'             => esc_html__( 'Select Product Category', 'mega-charity-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'mega-charity-pro' ),
	'section'           => 'mega_charity_pro_featured_products_section',
	'taxonomy'			=> 'product_cat',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'mega_charity_pro_is_featured_products_section_content_product_category_enable'
	) ) );

// featured_products read more setting and control
$wp_customize->add_setting( 'mega_charity_pro_theme_options[featured_products_read_more]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default' => $options['featured_products_read_more'],
	) );

$wp_customize->add_control( 'mega_charity_pro_theme_options[featured_products_read_more]', array(
	'label'             => esc_html__( 'Read more', 'mega-charity-pro' ),
	'section'        	=> 'mega_charity_pro_featured_products_section',
	'active_callback' 	=> 'mega_charity_pro_is_featured_products_section_enable',
	'type'				=> 'text',
	) );

require get_template_directory() . '/inc/customizer/sections/color/featured-products.php';
