<?php
/**
 * Gallery Section options
 *
 * @package Theme Palace
 * @subpackage Mega Charity Pro
 * @since Mega Charity Pro 1.0.0
 */

// Add Gallery section
$wp_customize->add_section( 'mega_charity_pro_gallery_section', array(
	'title'             => esc_html__( 'Gallery Posts','mega-charity-pro' ),
	'description'       => esc_html__( 'Gallery Section options.', 'mega-charity-pro' ),
	'panel'             => 'mega_charity_pro_front_page_panel',
) );

$wp_customize->add_setting(
	'mega_charity_pro_gallery_section_setting',
	array(
		'default' => 'setting',
		'sanitize_callback' => 'mega_charity_pro_sanitize_select',
	)
);
$wp_customize->add_control(
	'mega_charity_pro_gallery_section_setting',
	array(
		'section'		=> 'mega_charity_pro_gallery_section',
		'type'			=> 'radio',
		'active_callback' 	=> 'mega_charity_pro_is_gallery_section_enable',
		'choices'		=> array(
				'setting' => esc_html__( 'Setting', 'mega-charity-pro' ),
				'style' => esc_html__( 'Style', 'mega-charity-pro' ),
		 	)
	)
);

// Gallery content enable control and setting
$wp_customize->add_setting( 'mega_charity_pro_theme_options[gallery_section_enable]', array(
	'default'			=> 	$options['gallery_section_enable'],
	'sanitize_callback' => 'mega_charity_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Mega_Charity_Pro_Switch_Control( $wp_customize, 'mega_charity_pro_theme_options[gallery_section_enable]', array(
	'label'             => esc_html__( 'Gallery Section Enable', 'mega-charity-pro' ),
	'section'           => 'mega_charity_pro_gallery_section',
	'on_off_label' 		=> mega_charity_pro_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'mega_charity_pro_theme_options[gallery_section_enable]', array(
		'selector'            => '#our-gallery .tooltiptext',
		'settings'            => 'mega_charity_pro_theme_options[gallery_section_enable]',
    ) );
}

// Gallery btn label setting and control
$wp_customize->add_setting( 'mega_charity_pro_theme_options[gallery_subtitle]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['gallery_subtitle'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'mega_charity_pro_theme_options[gallery_subtitle]', array(
	'label'           	=> esc_html__( 'Subtitle', 'mega-charity-pro' ),
	'section'        	=> 'mega_charity_pro_gallery_section',
	'active_callback' 	=> 'mega_charity_pro_is_gallery_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'mega_charity_pro_theme_options[gallery_subtitle]', array(
		'selector'            => '#our-gallery p.section-subtitle',
		'settings'            => 'mega_charity_pro_theme_options[gallery_subtitle]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'mega_charity_pro_gallery_subtitle_partial',
    ) );
}

// gallery title setting and control
$wp_customize->add_setting( 'mega_charity_pro_theme_options[gallery_title]',
	array(
		'default'       		=> $options['gallery_title'],
		'sanitize_callback'		=> 'mega_charity_pro_santize_allow_tag',
		'transport'				=> 'postMessage',
	)
);
$wp_customize->add_control( 'mega_charity_pro_theme_options[gallery_title]',
    array(
		'label'      			=> esc_html__( 'Section Title', 'mega-charity-pro' ),
		'section'    			=> 'mega_charity_pro_gallery_section',
		'type'		 			=> 'textarea',
		'active_callback'		=> 'mega_charity_pro_is_gallery_section_enable',
    )
);

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'mega_charity_pro_theme_options[gallery_title]', array(
		'selector'            => '#our-gallery h2.section-title',
		'settings'            => 'mega_charity_pro_theme_options[gallery_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'mega_charity_pro_gallery_title_partial',
    ) );
}


// Event social icons number control and setting
$wp_customize->add_setting( 'mega_charity_pro_theme_options_gallery_count', array(
	'default'          	=> $options['gallery_count'],
	'sanitize_callback' => 'mega_charity_pro_sanitize_number_range',
	'validate_callback' => 'mega_charity_pro_validate_gallery_count',
) );

$wp_customize->add_control( 'mega_charity_pro_theme_options_gallery_count', array(
	'label'             => esc_html__( 'Number of Posts', 'mega-charity-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 20. Please input the valid number and save. Then refresh the page to see the change.', 'mega-charity-pro' ),
	'section'           => 'mega_charity_pro_gallery_section',
	'active_callback'   => 'mega_charity_pro_is_gallery_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 20,
		'style' => 'width: 100px;'
		),
) );

// Gallery content type control and setting
$wp_customize->add_setting( 'mega_charity_pro_theme_options_gallery_content_type', array(
	'default'          	=> $options['gallery_content_type'],
	'sanitize_callback' => 'mega_charity_pro_sanitize_select',
) );

$wp_customize->add_control( 'mega_charity_pro_theme_options_gallery_content_type', array(
	'label'             => esc_html__( 'Content Type', 'mega-charity-pro' ),
	'section'           => 'mega_charity_pro_gallery_section',
	'type'				=> 'select',
	'active_callback' 	=> 'mega_charity_pro_is_gallery_section_enable',
	'choices'			=> array(
		'page'      => esc_html__( 'Page', 'mega-charity-pro' ),
		'post'      => esc_html__( 'Post', 'mega-charity-pro' ),
		'category'  => esc_html__( 'Category', 'mega-charity-pro' ),
		),
) );

for ( $i = 1; $i <= get_theme_mod( 'mega_charity_pro_theme_options_gallery_count', 5 ); $i++ ) :
	// gallery pages drop down chooser control and setting
	$wp_customize->add_setting( 'mega_charity_pro_theme_options[gallery_content_page_' . $i . ']', array(
		'sanitize_callback' => 'mega_charity_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Mega_Charity_Pro_Dropdown_Chooser( $wp_customize, 'mega_charity_pro_theme_options[gallery_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'mega-charity-pro' ), $i ),
		'section'           => 'mega_charity_pro_gallery_section',
		'choices'			=> mega_charity_pro_page_choices(),
		'active_callback'	=> 'mega_charity_pro_is_gallery_section_content_page_enable',
	) ) );

	// gallery posts drop down chooser control and setting
	$wp_customize->add_setting( 'mega_charity_pro_theme_options[gallery_content_post_' . $i . ']', array(
		'sanitize_callback' => 'mega_charity_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Mega_Charity_Pro_Dropdown_Chooser( $wp_customize, 'mega_charity_pro_theme_options[gallery_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'mega-charity-pro' ), $i ),
		'section'           => 'mega_charity_pro_gallery_section',
		'choices'			=> mega_charity_pro_post_choices(),
		'active_callback'	=> 'mega_charity_pro_is_gallery_section_content_post_enable',
	) ) );

endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'mega_charity_pro_theme_options[gallery_content_category]', array(
	'sanitize_callback' => 'mega_charity_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Mega_Charity_Pro_Dropdown_Taxonomies_Control( $wp_customize,'mega_charity_pro_theme_options[gallery_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'mega-charity-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'mega-charity-pro' ),
	'section'           => 'mega_charity_pro_gallery_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'mega_charity_pro_is_gallery_section_content_category_enable'
) ) );

// gallery title setting and control
$wp_customize->add_setting( 'mega_charity_pro_theme_options[gallery_button]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['gallery_button'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'mega_charity_pro_theme_options[gallery_button]', array(
	'label'           	=> esc_html__( 'Gallery Button', 'mega-charity-pro' ),
	'section'        	=> 'mega_charity_pro_gallery_section',
	'active_callback' 	=> 'mega_charity_pro_is_gallery_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'mega_charity_pro_theme_options[gallery_button]', array(
		'selector'            => '#gallery .read-more a.second-btn',
		'settings'            => 'mega_charity_pro_theme_options[gallery_button]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'mega_charity_pro_gallery_button_partial',
    ) );
}

// gallery btn link setting and control
$wp_customize->add_setting( 'mega_charity_pro_theme_options[gallery_button_link]', array(
	'sanitize_callback' => 'esc_url_raw',
) );

$wp_customize->add_control( 'mega_charity_pro_theme_options[gallery_button_link]', array(
	'label'           	=> esc_html__( 'Button Link', 'mega-charity-pro' ),
	'section'        	=> 'mega_charity_pro_gallery_section',
	'active_callback' 	=> 'mega_charity_pro_is_gallery_section_enable',
	'type'				=> 'url',
) );

require get_template_directory() . '/inc/customizer/sections/color/gallery.php';