<?php
/**
 * Help Us Section options
 *
 * @package Theme Palace
 * @subpackage Mega Charity Pro
 * @since Mega Charity Pro 1.0.0
 */

// Add Help Us section
$wp_customize->add_section( 'mega_charity_pro_help_us_section', array(
    'title'             => esc_html__( 'Help Us','mega-charity-pro' ),
    'description'       => esc_html__( 'Help Us Section options.', 'mega-charity-pro' ),
    'panel'             => 'mega_charity_pro_front_page_panel',
) );

$wp_customize->add_setting(
    'mega_charity_pro_help_us_section_setting',
    array(
        'default' => 'setting',
        'sanitize_callback' => 'mega_charity_pro_sanitize_select',
    )
);
$wp_customize->add_control(
    'mega_charity_pro_help_us_section_setting',
    array(
        'section'       => 'mega_charity_pro_help_us_section',
        'type'          => 'radio',
        'active_callback'   => 'mega_charity_pro_is_help_us_section_enable',
        'choices'       => array(
                'setting' => esc_html__( 'Setting', 'mega-charity-pro' ),
                'style' => esc_html__( 'Style', 'mega-charity-pro' ),
            )
    )
);

// Help Us content enable control and setting
$wp_customize->add_setting( 'mega_charity_pro_theme_options[help_us_section_enable]', array(
    'default'           =>  $options['help_us_section_enable'],
    'sanitize_callback' => 'mega_charity_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Mega_Charity_Pro_Switch_Control( $wp_customize, 'mega_charity_pro_theme_options[help_us_section_enable]', array(
    'label'             => esc_html__( 'Help Us Section Enable', 'mega-charity-pro' ),
    'section'           => 'mega_charity_pro_help_us_section',
    'on_off_label'      => mega_charity_pro_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'mega_charity_pro_theme_options[help_us_section_enable]', array(
        'selector'            => '#help-us .tooltiptext',
        'settings'            => 'mega_charity_pro_theme_options[help_us_section_enable]',
    ) );
}

// help_us title setting and control
$wp_customize->add_setting( 'mega_charity_pro_theme_options[help_us_subtitle]', array(
    'sanitize_callback' => 'sanitize_text_field',
    'default'           => $options['help_us_subtitle'],
    'transport'         => 'postMessage',
) );

$wp_customize->add_control( 'mega_charity_pro_theme_options[help_us_subtitle]', array(
    'label'             => esc_html__( 'Sub Title', 'mega-charity-pro' ),
    'section'           => 'mega_charity_pro_help_us_section',
    'active_callback'   => 'mega_charity_pro_is_help_us_section_enable',
    'type'              => 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'mega_charity_pro_theme_options[help_us_subtitle]', array(
        'selector'            => '#help-us p.section-subtitle',
        'settings'            => 'mega_charity_pro_theme_options[help_us_subtitle]',
        'container_inclusive' => false,
        'fallback_refresh'    => true,
        'render_callback'     => 'mega_charity_pro_help_us_subtitle_partial',
    ) );
}

// help_us title setting and control
$wp_customize->add_setting( 'mega_charity_pro_theme_options[help_us_title]', array(
    'sanitize_callback' => 'sanitize_text_field',
    'default'           => $options['help_us_title'],
    'transport'         => 'postMessage',
) );

$wp_customize->add_control( 'mega_charity_pro_theme_options[help_us_title]', array(
    'label'             => esc_html__( 'Title', 'mega-charity-pro' ),
    'section'           => 'mega_charity_pro_help_us_section',
    'active_callback'   => 'mega_charity_pro_is_help_us_section_enable',
    'type'              => 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'mega_charity_pro_theme_options[help_us_title]', array(
        'selector'            => '#help-us h2.section-title',
        'settings'            => 'mega_charity_pro_theme_options[help_us_title]',
        'container_inclusive' => false,
        'fallback_refresh'    => true,
        'render_callback'     => 'mega_charity_pro_help_us_title_partial',
    ) );
}

// content type control and setting
$wp_customize->add_setting( 'mega_charity_pro_theme_options_help_us_count', array(
    'default'           => $options['help_us_count'],
    'sanitize_callback' => 'mega_charity_pro_sanitize_number_range',
    'validate_callback' => 'mega_charity_pro_validate_help_us_count',
) );

$wp_customize->add_control( 'mega_charity_pro_theme_options_help_us_count', array(
    'label'             => esc_html__( 'Number of Posts', 'mega-charity-pro' ),
    'description'       => esc_html__( 'Note: Min 3 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'mega-charity-pro' ),
    'section'           => 'mega_charity_pro_help_us_section',
    'active_callback'   => 'mega_charity_pro_is_help_us_section_enable',
    'type'              => 'number',
    'input_attrs'       => array(
        'min'   => 3,
        'max'   => 12,
        'style' => 'width: 100px;'
        ),
) );

// long Excerpt length setting and control.
$wp_customize->add_setting( 'mega_charity_pro_theme_options[help_us_excerpt_length]', array(
    'default'           => $options['help_us_excerpt_length'],
    'sanitize_callback' => 'mega_charity_pro_sanitize_number_range',
    'validate_callback' => 'mega_charity_pro_validate_long_excerpt',
) );

$wp_customize->add_control( 'mega_charity_pro_theme_options[help_us_excerpt_length]', array(
    'label'             => esc_html__( 'Help Us Excerpt Length', 'mega-charity-pro' ),
    'description'       => esc_html__( 'Total description words to be displayed in help_us posts.', 'mega-charity-pro' ),
    'section'           => 'mega_charity_pro_help_us_section',
    'active_callback'   => 'mega_charity_pro_is_help_us_section_enable',
    'type'              => 'number',
    'input_attrs'       => array(
        'style'       => 'width: 80px;',
        'max'         => 100,
        'min'         => 5,
    ),
) );

// Help Us content type control and setting
$wp_customize->add_setting( 'mega_charity_pro_theme_options_help_us_content_type', array(
    'default'           => $options['help_us_content_type'],
    'sanitize_callback' => 'mega_charity_pro_sanitize_select',
) );

$wp_customize->add_control( 'mega_charity_pro_theme_options_help_us_content_type', array(
    'label'             => esc_html__( 'Content Type', 'mega-charity-pro' ),
    'section'           => 'mega_charity_pro_help_us_section',
    'type'              => 'select',
    'active_callback'   => 'mega_charity_pro_is_help_us_section_enable',
    'choices'           => array( 
        'page'      => esc_html__( 'Page', 'mega-charity-pro' ),
        'post'      => esc_html__( 'Post', 'mega-charity-pro' ),
        'category'  => esc_html__( 'Category', 'mega-charity-pro' ),
    ),
) );

for ( $i = 1; $i <= get_theme_mod( 'mega_charity_pro_theme_options_help_us_count', 3 ); $i++ ) :
    // help_us pages drop down chooser control and setting
    $wp_customize->add_setting( 'mega_charity_pro_theme_options[help_us_content_page_' . $i . ']', array(
        'sanitize_callback' => 'mega_charity_pro_sanitize_page',
    ) );

    $wp_customize->add_control( new Mega_Charity_Pro_Dropdown_Chooser( $wp_customize, 'mega_charity_pro_theme_options[help_us_content_page_' . $i . ']', array(
        'label'             => sprintf( esc_html__( 'Select Page %d', 'mega-charity-pro' ), $i ),
        'section'           => 'mega_charity_pro_help_us_section',
        'choices'           => mega_charity_pro_page_choices(),
        'active_callback'   => 'mega_charity_pro_is_help_us_section_content_page_enable',
    ) ) );

    // help_us posts drop down chooser control and setting
    $wp_customize->add_setting( 'mega_charity_pro_theme_options[help_us_content_post_' . $i . ']', array(
        'sanitize_callback' => 'mega_charity_pro_sanitize_page',
    ) );

    $wp_customize->add_control( new Mega_Charity_Pro_Dropdown_Chooser( $wp_customize, 'mega_charity_pro_theme_options[help_us_content_post_' . $i . ']', array(
        'label'             => sprintf( esc_html__( 'Select Post %d', 'mega-charity-pro' ), $i ),
        'section'           => 'mega_charity_pro_help_us_section',
        'choices'           => mega_charity_pro_post_choices(),
        'active_callback'   => 'mega_charity_pro_is_help_us_section_content_post_enable',
    ) ) );
endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'mega_charity_pro_theme_options[help_us_content_category]', array(
    'sanitize_callback' => 'mega_charity_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Mega_Charity_Pro_Dropdown_Taxonomies_Control( $wp_customize,'mega_charity_pro_theme_options[help_us_content_category]', array(
    'label'             => esc_html__( 'Select Category', 'mega-charity-pro' ),
    'description'       => esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'mega-charity-pro' ),
    'section'           => 'mega_charity_pro_help_us_section',
    'type'              => 'dropdown-taxonomies',
    'active_callback'   => 'mega_charity_pro_is_help_us_section_content_category_enable'
) ) );

// help_us btn setting and control
$wp_customize->add_setting( 'mega_charity_pro_theme_options[help_us_btn]', array(
    'sanitize_callback' => 'sanitize_text_field',
    'default'           => $options['help_us_btn'],
    'transport'         => 'postMessage',
) );

$wp_customize->add_control( 'mega_charity_pro_theme_options[help_us_btn]', array(
    'label'             => esc_html__( 'Button', 'mega-charity-pro' ),
    'section'           => 'mega_charity_pro_help_us_section',
    'active_callback'   => 'mega_charity_pro_is_help_us_section_enable',
    'type'              => 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'mega_charity_pro_theme_options[help_us_btn]', array(
        'selector'            => '#help-us a.btn',
        'settings'            => 'mega_charity_pro_theme_options[help_us_btn]',
        'container_inclusive' => false,
        'fallback_refresh'    => true,
        'render_callback'     => 'mega_charity_pro_help_us_btn_partial',
    ) );
}

require get_template_directory() . '/inc/customizer/sections/color/help-us.php';