<?php
/**
 * Hero Banner Section options
 *
 * @package Theme Palace
 * @subpackage Mega Charity Pro
 * @since Mega Charity Pro 1.0.0
 */

// Add Hero Banner section
$wp_customize->add_section( 'mega_charity_pro_hero_banner_section', array(
	'title'             => esc_html__( 'Hero Banner','mega-charity-pro' ),
	'description'       => esc_html__( 'Hero Banner Section options.', 'mega-charity-pro' ),
	'panel'             => 'mega_charity_pro_front_page_panel',
) );

$wp_customize->add_setting(
	'mega_charity_pro_hero_banner_section_setting',
	array(
		'default' => 'setting',
		'sanitize_callback' => 'mega_charity_pro_sanitize_select',
	)
);
$wp_customize->add_control(
	'mega_charity_pro_hero_banner_section_setting',
	array(
		'section'		=> 'mega_charity_pro_hero_banner_section',
		'active_callback' 	=> 'mega_charity_pro_is_hero_banner_section_enable',
		'type'			=> 'radio',
		'choices'		=> array(
				'setting' => esc_html__( 'Setting', 'mega-charity-pro' ),
				'style' => esc_html__( 'Style', 'mega-charity-pro' ),
		 	)
	)
);

// Hero Banner content enable control and setting
$wp_customize->add_setting( 'mega_charity_pro_theme_options[hero_banner_section_enable]', array(
	'default'			=> 	$options['hero_banner_section_enable'],
	'sanitize_callback' => 'mega_charity_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Mega_Charity_Pro_Switch_Control( $wp_customize, 'mega_charity_pro_theme_options[hero_banner_section_enable]', array(
	'label'             => esc_html__( 'Hero Banner Section Enable', 'mega-charity-pro' ),
	'section'           => 'mega_charity_pro_hero_banner_section',
	'on_off_label' 		=> mega_charity_pro_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'mega_charity_pro_theme_options[hero_banner_section_enable]', array(
		'selector'            => '#hero-banner .tooltiptext',
		'settings'            => 'mega_charity_pro_theme_options[hero_banner_section_enable]',
    ) );
}

// long Excerpt length setting and control.
$wp_customize->add_setting( 'mega_charity_pro_theme_options[hero_banner_excerpt_length]', array(
	'sanitize_callback' => 'mega_charity_pro_sanitize_number_range',
	'validate_callback' => 'mega_charity_pro_validate_long_excerpt',
	'default'			=> $options['hero_banner_excerpt_length'],
) );

$wp_customize->add_control( 'mega_charity_pro_theme_options[hero_banner_excerpt_length]', array(
	'label'       		=> esc_html__( 'Hero Banner Excerpt Length', 'mega-charity-pro' ),
	'description' 		=> esc_html__( 'Total description words to be displayed in hero_banner posts.', 'mega-charity-pro' ),
	'section'     		=> 'mega_charity_pro_hero_banner_section',
	'active_callback' 	=> 'mega_charity_pro_is_hero_banner_section_enable',
	'type'        		=> 'number',
	'input_attrs' 		=> array(
		'style'       => 'width: 80px;',
		'max'         => 100,
		'min'         => 5,
	),
) );

// Hero Banner content type control and setting
$wp_customize->add_setting( 'mega_charity_pro_theme_options_hero_banner_content_type', array(
	'default'          	=> $options['hero_banner_content_type'],
	'sanitize_callback' => 'mega_charity_pro_sanitize_select',
) );

$wp_customize->add_control( 'mega_charity_pro_theme_options_hero_banner_content_type', array(
	'label'             => esc_html__( 'Content Type', 'mega-charity-pro' ),
	'section'           => 'mega_charity_pro_hero_banner_section',
	'type'				=> 'select',
	'active_callback' 	=> 'mega_charity_pro_is_hero_banner_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'mega-charity-pro' ),
		'post' 		=> esc_html__( 'Post', 'mega-charity-pro' ),
	),
) );

// hero_banner sub title setting and control
$wp_customize->add_setting( 'mega_charity_pro_theme_options[hero_banner_sub_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['hero_banner_sub_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'mega_charity_pro_theme_options[hero_banner_sub_title]', array(
	'label'           	=> esc_html__( 'Sub Title', 'mega-charity-pro' ),
	'section'        	=> 'mega_charity_pro_hero_banner_section',
	'active_callback' 	=> 'mega_charity_pro_is_hero_banner_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'mega_charity_pro_theme_options[hero_banner_sub_title]', array(
		'selector'            => '#hero-banner h2.entry-title span',
		'settings'            => 'mega_charity_pro_theme_options[hero_banner_sub_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'mega_charity_pro_hero_banner_sub_title_partial',
    ) );
}

// hero_banner pages drop down chooser control and setting
$wp_customize->add_setting( 'mega_charity_pro_theme_options[hero_banner_content_page]', array(
	'sanitize_callback' => 'mega_charity_pro_sanitize_page',
) );

$wp_customize->add_control( new Mega_Charity_Pro_Dropdown_Chooser( $wp_customize, 'mega_charity_pro_theme_options[hero_banner_content_page]', array(
	'label'             => esc_html__( 'Select Page', 'mega-charity-pro' ),
	'section'           => 'mega_charity_pro_hero_banner_section',
	'choices'			=> mega_charity_pro_page_choices(),
	'active_callback'	=> 'mega_charity_pro_is_hero_banner_section_content_page_enable',
) ) );

// hero_banner posts drop down chooser control and setting
$wp_customize->add_setting( 'mega_charity_pro_theme_options[hero_banner_content_post]', array(
	'sanitize_callback' => 'mega_charity_pro_sanitize_page',
) );

$wp_customize->add_control( new Mega_Charity_Pro_Dropdown_Chooser( $wp_customize, 'mega_charity_pro_theme_options[hero_banner_content_post]', array(
	'label'             => esc_html__( 'Select Post', 'mega-charity-pro' ),
	'section'           => 'mega_charity_pro_hero_banner_section',
	'choices'			=> mega_charity_pro_post_choices(),
	'active_callback'	=> 'mega_charity_pro_is_hero_banner_section_content_post_enable',
) ) );

// hero_banner btn title setting and control
$wp_customize->add_setting( 'mega_charity_pro_theme_options[hero_banner_btn_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['hero_banner_btn_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'mega_charity_pro_theme_options[hero_banner_btn_title]', array(
	'label'           	=> esc_html__( 'Button Label', 'mega-charity-pro' ),
	'section'        	=> 'mega_charity_pro_hero_banner_section',
	'active_callback' 	=> 'mega_charity_pro_is_hero_banner_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'mega_charity_pro_theme_options[hero_banner_btn_title]', array(
		'selector'            => '#hero-banner .read-more a.first-btn',
		'settings'            => 'mega_charity_pro_theme_options[hero_banner_btn_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'mega_charity_pro_hero_banner_btn_title_partial',
    ) );
}

// hero_banner btn title setting and control
$wp_customize->add_setting( 'mega_charity_pro_theme_options[hero_banner_alt_btn_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['hero_banner_alt_btn_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'mega_charity_pro_theme_options[hero_banner_alt_btn_title]', array(
	'label'           	=> esc_html__( 'Alternative Button Label', 'mega-charity-pro' ),
	'section'        	=> 'mega_charity_pro_hero_banner_section',
	'active_callback' 	=> 'mega_charity_pro_is_hero_banner_section_enable',
	'type'				=> 'text',
) );
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'mega_charity_pro_theme_options[hero_banner_alt_btn_title]', array(
		'selector'            => '#hero-banner .read-more a.second-btn',
		'settings'            => 'mega_charity_pro_theme_options[hero_banner_alt_btn_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'mega_charity_pro_hero_banner_alt_btn_title_partial',
    ) );
}

// hero_banner btn link setting and control
$wp_customize->add_setting( 'mega_charity_pro_theme_options[hero_banner_alt_btn_link]', array(
	'sanitize_callback' => 'esc_url_raw',
) );

$wp_customize->add_control( 'mega_charity_pro_theme_options[hero_banner_alt_btn_link]', array(
	'label'           	=> esc_html__( 'Alternative Button Link', 'mega-charity-pro' ),
	'section'        	=> 'mega_charity_pro_hero_banner_section',
	'active_callback' 	=> 'mega_charity_pro_is_hero_banner_section_enable',
	'type'				=> 'url',
) );

require get_template_directory() . '/inc/customizer/sections/color/hero-banner.php';