<?php
/**
 * masonry Section options
 *
 * @package Theme Palace
 * @subpackage Mega_Charity Pro
 * @since Mega_Charity Pro 1.0.0
 */

if ( !class_exists('WooCommerce') ) {
    return;
}

// Add masonry section
$wp_customize->add_section( 'mega_charity_pro_masonry_section', array(
	'title'             => esc_html__( 'Collection','mega-charity-pro' ),
	'description'       => esc_html__( 'Note: To activate this section you need to install WooCommerce Plugin.', 'mega-charity-pro' ),
	'panel'             => 'mega_charity_pro_front_page_panel',
) );

$wp_customize->add_setting(
	'mega_charity_pro_masonry_section_setting',
	array(
		'default' => 'setting',
		'sanitize_callback' => 'mega_charity_pro_sanitize_select',
	)
);
$wp_customize->add_control(
	'mega_charity_pro_masonry_section_setting',
	array(
		'section'		=> 'mega_charity_pro_masonry_section',
		'type'			=> 'radio',
		'active_callback' 	=> 'mega_charity_pro_is_masonry_section_enable',
		'choices'		=> array(
				'setting' => esc_html__( 'Setting', 'mega-charity-pro' ),
				'style' => esc_html__( 'Style', 'mega-charity-pro' ),
		 	)
	)
);

// masonry content enable control and setting
$wp_customize->add_setting( 'mega_charity_pro_theme_options[masonry_section_enable]', array(
	'default'			=> 	$options['masonry_section_enable'],
	'sanitize_callback' => 'mega_charity_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Mega_Charity_Pro_Switch_Control( $wp_customize, 'mega_charity_pro_theme_options[masonry_section_enable]', array(
	'label'             => esc_html__( 'collection Section Enable', 'mega-charity-pro' ),
	'section'           => 'mega_charity_pro_masonry_section',
	'on_off_label' 		=> mega_charity_pro_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'mega_charity_pro_theme_options[masonry_section_enable]', array(
		'selector'            => '#masonry .tooltiptext',
		'settings'            => 'mega_charity_pro_theme_options[masonry_section_enable]',
    ) );
}

for ( $i = 1; $i <= 4; $i++ ) :


	// Add dropdown category setting and control.
	$wp_customize->add_setting(  'mega_charity_pro_theme_options[masonry_content_masonry_category_'.$i.']', array(
		'sanitize_callback' => 'absint',
	) ) ;

	$wp_customize->add_control( new Mega_Charity_Pro_Dropdown_Taxonomies_Control( $wp_customize,'mega_charity_pro_theme_options[masonry_content_masonry_category_'.$i.']', array(
		'label'             => esc_html__( 'Select collection Category ', 'mega-charity-pro' ).$i,
		'section'           => 'mega_charity_pro_masonry_section',
		'taxonomy'			=> 'product_cat',
		'type'              => 'dropdown-taxonomies',
		'active_callback'	=> 'mega_charity_pro_is_masonry_section_enable'
	) ) );

endfor;

require get_template_directory() . '/inc/customizer/sections/color/masonry.php';
