<?php
/**
 * Reason Section options
 *
 * @package Theme Palace
 * @subpackage Mega_Charity Pro
 * @since Mega_Charity Pro 1.0.0
 */

// Add Reason section
$wp_customize->add_section( 'mega_charity_pro_reason_section', array(
	'title'             => esc_html__( 'Medical Reason','mega-charity-pro' ),
	'description'       => esc_html__( 'Medical Reason Section options.', 'mega-charity-pro' ),
	'panel'             => 'mega_charity_pro_front_page_panel',
) );

$wp_customize->add_setting(
	'mega_charity_pro_reason_section_setting',
	array(
		'default' => 'setting',
		'sanitize_callback' => 'mega_charity_pro_sanitize_select',
	)
);
$wp_customize->add_control(
	'mega_charity_pro_reason_section_setting',
	array(
		'section'		=> 'mega_charity_pro_reason_section',
		'type'			=> 'radio',
		'active_callback' 	=> 'mega_charity_pro_is_reason_section_enable',
		'choices'		=> array(
				'setting' => esc_html__( 'Setting', 'mega-charity-pro' ),
				'style' => esc_html__( 'Style', 'mega-charity-pro' ),
		 	)
	)
);

// Reason content enable control and setting
$wp_customize->add_setting( 'mega_charity_pro_theme_options[reason_section_enable]', array(
	'default'			=> 	$options['reason_section_enable'],
	'sanitize_callback' => 'mega_charity_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Mega_Charity_Pro_Switch_Control( $wp_customize, 'mega_charity_pro_theme_options[reason_section_enable]', array(
	'label'             => esc_html__( 'Reason Section Enable', 'mega-charity-pro' ),
	'section'           => 'mega_charity_pro_reason_section',
	'on_off_label' 		=> mega_charity_pro_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'mega_charity_pro_theme_options[reason_section_enable]', array(
		'selector'            => '#medical-reasons .tooltiptext',
		'settings'            => 'mega_charity_pro_theme_options[reason_section_enable]',
    ) );
}

// long Excerpt length setting and control.
$wp_customize->add_setting( 'mega_charity_pro_theme_options[reason_excerpt_length]', array(
	'sanitize_callback' => 'mega_charity_pro_sanitize_number_range',
	'validate_callback' => 'mega_charity_pro_validate_long_excerpt',
	'default'			=> $options['reason_excerpt_length'],
) );

$wp_customize->add_control( 'mega_charity_pro_theme_options[reason_excerpt_length]', array(
	'label'       		=> esc_html__( 'Medical Reasons Excerpt Length', 'mega-charity-pro' ),
	'description' 		=> esc_html__( 'Total description words to be displayed in medical reason posts.', 'mega-charity-pro' ),
	'section'     		=> 'mega_charity_pro_reason_section',
	'active_callback' 	=> 'mega_charity_pro_is_reason_section_enable',
	'type'        		=> 'number',
	'input_attrs' 		=> array(
		'style'       => 'width: 80px;',
		'max'         => 100,
		'min'         => 5,
	),
) );

// Reason content type control and setting
$wp_customize->add_setting( 'mega_charity_pro_theme_options_reason_content_type', array(
	'default'          	=> $options['reason_content_type'],
	'sanitize_callback' => 'mega_charity_pro_sanitize_select',
) );

$wp_customize->add_control( 'mega_charity_pro_theme_options_reason_content_type', array(
	'label'             => esc_html__( 'Content Type', 'mega-charity-pro' ),
	'section'           => 'mega_charity_pro_reason_section',
	'type'				=> 'select',
	'active_callback' 	=> 'mega_charity_pro_is_reason_section_enable',
	'choices'			=> array(
		'page' 		=> esc_html__( 'Page', 'mega-charity-pro' ),
		'post' 		=> esc_html__( 'Post', 'mega-charity-pro' ),
	),
) );

// medical reason pages drop down chooser control and setting
$wp_customize->add_setting( 'mega_charity_pro_theme_options[reason_content_page]', array(
	'sanitize_callback' => 'mega_charity_pro_sanitize_page',
) );

$wp_customize->add_control( new Mega_Charity_Pro_Dropdown_Chooser( $wp_customize, 'mega_charity_pro_theme_options[reason_content_page]', array(
	'label'             => esc_html__( 'Select Page', 'mega-charity-pro' ),
	'section'           => 'mega_charity_pro_reason_section',
	'choices'			=> mega_charity_pro_page_choices(),
	'active_callback'	=> 'mega_charity_pro_is_reason_section_content_page_enable',
) ) );

// medical reason posts drop down chooser control and setting
$wp_customize->add_setting( 'mega_charity_pro_theme_options[reason_content_post]', array(
	'sanitize_callback' => 'mega_charity_pro_sanitize_page',
) );

$wp_customize->add_control( new Mega_Charity_Pro_Dropdown_Chooser( $wp_customize, 'mega_charity_pro_theme_options[reason_content_post]', array(
	'label'             => esc_html__( 'Select Post', 'mega-charity-pro' ),
	'section'           => 'mega_charity_pro_reason_section',
	'choices'			=> mega_charity_pro_post_choices(),
	'active_callback'	=> 'mega_charity_pro_is_reason_section_content_post_enable',
) ) );

// Contact social control and setting
$wp_customize->add_setting( 'mega_charity_pro_theme_options[reason_list]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'transport'			=> 'refresh',
    
) );

$wp_customize->add_control( new Mega_Charity_Pro_Multi_Input_Custom_Control( $wp_customize, 'mega_charity_pro_theme_options[reason_list]', array(
    'label'             => esc_html__( 'Add List', 'mega-charity-pro' ),
    'button_text'       => esc_html__( 'Add List.', 'mega-charity-pro' ),
	'section'           => 'mega_charity_pro_reason_section',
    'active_callback' 	=> 'mega_charity_pro_is_reason_section_enable',
	'type'				=> 'multi-input',
)));

require get_template_directory() . '/inc/customizer/sections/color/medical-reasons.php';