<?php
/**
 * Pricing Section options
 *
 * @package Theme Palace
 * @subpackage Mega Charity Pro
 * @since Mega Charity Pro 1.0.0
 */

// Add Pricing section
$wp_customize->add_section( 'mega_charity_pro_pricing_section', array(
	'title'             => esc_html__( 'Pricing','mega-charity-pro' ),
	'description'       => esc_html__( 'Pricing Section options.', 'mega-charity-pro' ),
	'panel'             => 'mega_charity_pro_front_page_panel',
) );

$wp_customize->add_setting(
	'mega_charity_pro_pricing_section_setting',
	array(
		'default' => 'setting',
		'sanitize_callback' => 'mega_charity_pro_sanitize_select',
	)
);
$wp_customize->add_control(
	'mega_charity_pro_pricing_section_setting',
	array(
		'section'		=> 'mega_charity_pro_pricing_section',
		'type'			=> 'radio',
		'active_callback' 	=> 'mega_charity_pro_is_pricing_section_enable',
		'choices'		=> array(
				'setting' => esc_html__( 'Setting', 'mega-charity-pro' ),
				'style' => esc_html__( 'Style', 'mega-charity-pro' ),
		 	)
	)
);

// Pricing content enable control and setting
$wp_customize->add_setting( 'mega_charity_pro_theme_options[pricing_section_enable]', array(
	'default'			=> 	$options['pricing_section_enable'],
	'sanitize_callback' => 'mega_charity_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Mega_Charity_Pro_Switch_Control( $wp_customize, 'mega_charity_pro_theme_options[pricing_section_enable]', array(
	'label'             => esc_html__( 'Pricing Section Enable', 'mega-charity-pro' ),
	'section'           => 'mega_charity_pro_pricing_section',
	'on_off_label' 		=> mega_charity_pro_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'mega_charity_pro_theme_options[pricing_section_enable]', array(
		'selector'            => '#pricing .tooltiptext',
		'settings'            => 'mega_charity_pro_theme_options[pricing_section_enable]',
    ) );
}

// pricing number control and setting
$wp_customize->add_setting( 'mega_charity_pro_theme_options[pricing_image]', array(
	'sanitize_callback' => 'esc_url_raw',
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'mega_charity_pro_theme_options[pricing_image]', array(
	'label'             => esc_html__( 'Background Image', 'mega-charity-pro' ),
	'section'           => 'mega_charity_pro_pricing_section',
	'active_callback'   => 'mega_charity_pro_is_pricing_section_enable',
) ) );

// long Excerpt length setting and control.
$wp_customize->add_setting( 'mega_charity_pro_theme_options[pricing_excerpt_length]', array(
	'sanitize_callback' => 'mega_charity_pro_sanitize_number_range',
	'validate_callback' => 'mega_charity_pro_validate_long_excerpt',
	'default'			=> $options['pricing_excerpt_length'],
) );

$wp_customize->add_control( 'mega_charity_pro_theme_options[pricing_excerpt_length]', array(
	'label'       		=> esc_html__( 'Pricing Excerpt Length', 'mega-charity-pro' ),
	'description' 		=> esc_html__( 'Total description words to be displayed in pricing posts.', 'mega-charity-pro' ),
	'section'     		=> 'mega_charity_pro_pricing_section',
	'active_callback' 	=> 'mega_charity_pro_is_pricing_section_enable',
	'type'        		=> 'number',
	'input_attrs' 		=> array(
		'style'       => 'width: 80px;',
		'max'         => 100,
		'min'         => 5,
	),
) );

// Pricing content type control and setting
$wp_customize->add_setting( 'mega_charity_pro_theme_options_pricing_content_type', array(
	'default'          	=> $options['pricing_content_type'],
	'sanitize_callback' => 'mega_charity_pro_sanitize_select',
) );

$wp_customize->add_control( 'mega_charity_pro_theme_options_pricing_content_type', array(
	'label'             => esc_html__( 'Content Type', 'mega-charity-pro' ),
	'section'           => 'mega_charity_pro_pricing_section',
	'type'				=> 'select',
	'active_callback' 	=> 'mega_charity_pro_is_pricing_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'mega-charity-pro' ),
		'post' 		=> esc_html__( 'Post', 'mega-charity-pro' ),
	),
) );

// pricing pages drop down chooser control and setting
$wp_customize->add_setting( 'mega_charity_pro_theme_options[pricing_content_page]', array(
	'sanitize_callback' => 'mega_charity_pro_sanitize_page',
) );

$wp_customize->add_control( new Mega_Charity_Pro_Dropdown_Chooser( $wp_customize, 'mega_charity_pro_theme_options[pricing_content_page]', array(
	'label'             => esc_html__( 'Select Page', 'mega-charity-pro' ),
	'section'           => 'mega_charity_pro_pricing_section',
	'choices'			=> mega_charity_pro_page_choices(),
	'active_callback'	=> 'mega_charity_pro_is_pricing_section_content_page_enable',
) ) );

// pricing posts drop down chooser control and setting
$wp_customize->add_setting( 'mega_charity_pro_theme_options[pricing_content_post]', array(
	'sanitize_callback' => 'mega_charity_pro_sanitize_page',
) );

$wp_customize->add_control( new Mega_Charity_Pro_Dropdown_Chooser( $wp_customize, 'mega_charity_pro_theme_options[pricing_content_post]', array(
	'label'             => esc_html__( 'Select Post', 'mega-charity-pro' ),
	'section'           => 'mega_charity_pro_pricing_section',
	'choices'			=> mega_charity_pro_post_choices(),
	'active_callback'	=> 'mega_charity_pro_is_pricing_section_content_post_enable',
) ) );

// pricing title setting and control
$wp_customize->add_setting( 'mega_charity_pro_theme_options[pricing_button]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['pricing_button'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'mega_charity_pro_theme_options[pricing_button]', array(
	'label'           	=> esc_html__( 'Pricing Button', 'mega-charity-pro' ),
	'section'        	=> 'mega_charity_pro_pricing_section',
	'active_callback' 	=> 'mega_charity_pro_is_pricing_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'mega_charity_pro_theme_options[pricing_button]', array(
		'selector'            => '#pricing .read-more a.btn',
		'settings'            => 'mega_charity_pro_theme_options[pricing_button]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'mega_charity_pro_pricing_button_partial',
    ) );
}

// pricing hr setting and control
	$wp_customize->add_setting( 'mega_charity_pro_theme_options[pricing_hr]', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( new Mega_Charity_Pro_Customize_Horizontal_Line( $wp_customize, 'mega_charity_pro_theme_options[pricing_hr]',
		array(
			'section'         => 'mega_charity_pro_pricing_section',
			'active_callback' => 'mega_charity_pro_is_pricing_section_enable',
			'type'			  => 'hr'
	) ) );

for ( $i = 1; $i <= 2; $i++ ) :
	// pricing title
	$wp_customize->add_setting( 'mega_charity_pro_theme_options[pricing_title_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'mega_charity_pro_theme_options[pricing_title_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Title %d', 'mega-charity-pro' ), $i ),
		'section'           => 'mega_charity_pro_pricing_section',
		'active_callback'	=> 'mega_charity_pro_is_pricing_section_enable',
	) );

	// pricing price
	$wp_customize->add_setting( 'mega_charity_pro_theme_options[pricing_price_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'mega_charity_pro_theme_options[pricing_price_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Price %d', 'mega-charity-pro' ), $i ),
		'section'           => 'mega_charity_pro_pricing_section',
		'active_callback'	=> 'mega_charity_pro_is_pricing_section_enable',
	) );

	// pricing price
	$wp_customize->add_setting( 'mega_charity_pro_theme_options[time_duration_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'mega_charity_pro_theme_options[time_duration_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Time Duration %d', 'mega-charity-pro' ), $i ),
		'section'           => 'mega_charity_pro_pricing_section',
		'active_callback'	=> 'mega_charity_pro_is_pricing_section_enable',
	) );

	// contact email setting and control
	$wp_customize->add_setting( 'mega_charity_pro_theme_options[price_list_' . $i. ']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( new Mega_Charity_Pro_Multi_Input_Custom_Control( $wp_customize, 'mega_charity_pro_theme_options[price_list_' . $i. ']', array(
		'label'             => esc_html__( 'List text', 'mega-charity-pro' ),
		'button_text'       => esc_html__( 'Add list.', 'mega-charity-pro' ),
		'section'           => 'mega_charity_pro_pricing_section',
		'active_callback' 	=> 'mega_charity_pro_is_pricing_section_enable',
	) ) );

	// pricing btn
	$wp_customize->add_setting( 'mega_charity_pro_theme_options[pricing_btn_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'mega_charity_pro_theme_options[pricing_btn_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Button %d', 'mega-charity-pro' ), $i ),
		'section'           => 'mega_charity_pro_pricing_section',
		'active_callback'	=> 'mega_charity_pro_is_pricing_section_enable',
	) );

	// pricing btn link
	$wp_customize->add_setting( 'mega_charity_pro_theme_options[pricing_btn_url_' . $i . ']', array(
		'sanitize_callback' => 'esc_url_raw',
	) );

	$wp_customize->add_control( 'mega_charity_pro_theme_options[pricing_btn_url_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Link %d', 'mega-charity-pro' ), $i ),
		'section'           => 'mega_charity_pro_pricing_section',
		'active_callback'	=> 'mega_charity_pro_is_pricing_section_enable',
		'type'				=> 'url'
	) );

	// pricing hr setting and control
	$wp_customize->add_setting( 'mega_charity_pro_theme_options[pricing_hr_'. $i .']', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( new Mega_Charity_Pro_Customize_Horizontal_Line( $wp_customize, 'mega_charity_pro_theme_options[pricing_hr_'. $i .']',
		array(
			'section'         => 'mega_charity_pro_pricing_section',
			'active_callback' => 'mega_charity_pro_is_pricing_section_enable',
			'type'			  => 'hr'
	) ) );

endfor;

require get_template_directory() . '/inc/customizer/sections/color/pricing.php';