<?php
/**
 * Recent Products Section options
 *
 * @package Theme Palace
 * @subpackage Mega Charity Pro
 * @since Mega Charity Pro 1.0.0
 */
if ( !class_exists('WooCommerce') ) {
    return;
}

// Add recent_products section
$wp_customize->add_section( 'mega_charity_pro_recent_products_section', array(
    'title'             => esc_html__( 'Recent Product','mega-charity-pro' ),
    'description'       => esc_html__( 'Note: To activate this section you need to install WooCommerce Plugin.', 'mega-charity-pro' ),
    'panel'             => 'mega_charity_pro_front_page_panel',
) );

$wp_customize->add_setting(
    'mega_charity_pro_recent_products_section_setting',
    array(
        'default' => 'setting',
        'sanitize_callback' => 'mega_charity_pro_sanitize_select',
    )
);
$wp_customize->add_control(
    'mega_charity_pro_recent_products_section_setting',
    array(
        'section'       => 'mega_charity_pro_recent_products_section',
        'type'          => 'radio',
        'active_callback'   => 'mega_charity_pro_is_recent_products_section_enable',
        'choices'       => array(
                'setting' => esc_html__( 'Setting', 'mega-charity-pro' ),
                'style' => esc_html__( 'Style', 'mega-charity-pro' ),
            )
    )
);

// recent_products content enable control and setting
$wp_customize->add_setting( 'mega_charity_pro_theme_options[recent_products_section_enable]', array(
    'default'           =>  $options['recent_products_section_enable'],
    'sanitize_callback' => 'mega_charity_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Mega_Charity_Pro_Switch_Control( $wp_customize, 'mega_charity_pro_theme_options[recent_products_section_enable]', array(
    'label'             => esc_html__( 'Recent product Section Enable', 'mega-charity-pro' ),
    'section'           => 'mega_charity_pro_recent_products_section',
    'on_off_label'      => mega_charity_pro_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'mega_charity_pro_theme_options[recent_products_section_enable]', array(
        'selector'            => '#recent-products .tooltiptext',
        'settings'            => 'mega_charity_pro_theme_options[recent_products_section_enable]',
    ) );
}

// recent_products title setting and control
$wp_customize->add_setting( 'mega_charity_pro_theme_options[recent_products_title]', array(
    'sanitize_callback' => 'sanitize_text_field',
    'default'           => $options['recent_products_title'],
    'transport'         => 'postMessage',
) );

$wp_customize->add_control( 'mega_charity_pro_theme_options[recent_products_title]', array(
    'label'             => esc_html__( 'Title', 'mega-charity-pro' ),
    'section'           => 'mega_charity_pro_recent_products_section',
    'active_callback'   => 'mega_charity_pro_is_recent_products_section_enable',
    'type'              => 'text',
) );
// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'mega_charity_pro_theme_options[recent_products_title]', array(
        'selector'            => '#recent-products .shop-section-title',
        'settings'            => 'mega_charity_pro_theme_options[recent_products_title]',
        'container_inclusive' => false,
        'fallback_refresh'    => true,
        'render_callback'     => 'mega_charity_pro_recent_products_title_partial',
    ) );
}

// recent_products title setting and control
$wp_customize->add_setting( 'mega_charity_pro_theme_options[recent_products_sub_title]', array(
    'sanitize_callback' => 'sanitize_text_field',
    'default'           => $options['recent_products_sub_title'],       
    'transport'         => 'postMessage',
) );

$wp_customize->add_control( 'mega_charity_pro_theme_options[recent_products_sub_title]', array(
    'label'             => esc_html__( 'Description', 'mega-charity-pro' ),
    'section'           => 'mega_charity_pro_recent_products_section',
    'active_callback'   => 'mega_charity_pro_is_recent_products_section_enable',
    'type'              => 'textarea',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'mega_charity_pro_theme_options[recent_products_sub_title]', array(
        'selector'            => '#recent-products p.shop-subtitle',
        'settings'            => 'mega_charity_pro_theme_options[recent_products_sub_title]',
        'container_inclusive' => false,
        'fallback_refresh'    => true,
        'render_callback'     => 'mega_charity_pro_recent_products_sub_title_partial',
    ) );
}

$wp_customize->add_setting( 'mega_charity_pro_theme_options_recent_products_count', array(
    'default'           => $options['recent_products_count'],
    'sanitize_callback' => 'mega_charity_pro_sanitize_number_range',
    'validate_callback' => 'mega_charity_pro_validate_recent_products_count',
) );

$wp_customize->add_control( 'mega_charity_pro_theme_options_recent_products_count', array(
    'label'             => esc_html__( 'Number of Product', 'mega-charity-pro' ),
    'description'       => esc_html__( 'Note: Min 1 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'mega-charity-pro' ),
    'section'           => 'mega_charity_pro_recent_products_section',
    'active_callback'   => 'mega_charity_pro_is_recent_products_section_enable',
    'type'              => 'number',
    'input_attrs'       => array(
        'min'   => 1,
        'max'   => 12,
        'style' => 'width: 100px;'
        ),
) );

$wp_customize->add_setting( 'mega_charity_pro_theme_options_recent_products_content_type', array(
    'default'           => $options['recent_products_content_type'],
    'sanitize_callback' => 'mega_charity_pro_sanitize_select',
) );

$wp_customize->add_control( 'mega_charity_pro_theme_options_recent_products_content_type', array(
    'label'             => esc_html__( 'Content Type', 'mega-charity-pro' ),
    'section'           => 'mega_charity_pro_recent_products_section',
    'type'              => 'select',
    'active_callback'   => 'mega_charity_pro_is_recent_products_section_enable',
    'choices'           => array(
        'product'           => esc_html__( 'Product', 'mega-charity-pro' ),
        'product-category'  => esc_html__( 'Product Category', 'mega-charity-pro' ),
        ),
) );

for( $i = 1 ; $i <= get_theme_mod( 'mega_charity_pro_theme_options_recent_products_count', 4 ); $i++ ){

    $wp_customize->add_setting( 'mega_charity_pro_theme_options[recent_products_content_product_' . $i . ']', array(
        'sanitize_callback' => 'mega_charity_pro_sanitize_page',
    ) );

    $wp_customize->add_control( new Mega_Charity_Pro_Dropdown_Chooser( $wp_customize, 'mega_charity_pro_theme_options[recent_products_content_product_' . $i . ']', array(
        'label'             => sprintf( esc_html__( 'Select Product %d', 'mega-charity-pro' ), $i ),
        'section'           => 'mega_charity_pro_recent_products_section',
        'choices'           => mega_charity_pro_product_choices(),
        'active_callback'   => 'mega_charity_pro_is_recent_products_section_content_product_enable',
    ) ) );
}

$wp_customize->add_setting(  'mega_charity_pro_theme_options[recent_products_content_product_category]', array(
        'sanitize_callback' => 'absint',
    ) ) ;

$wp_customize->add_control( new Mega_Charity_Pro_Dropdown_Taxonomies_Control( $wp_customize,'mega_charity_pro_theme_options[recent_products_content_product_category]', array(
    'label'             => esc_html__( 'Select Product Categories', 'mega-charity-pro' ),
    'description'       => esc_html__( 'Note: Press CTRL and select multiple category. Latest four posts will be shown from each selected category', 'mega-charity-pro' ),
    'section'           => 'mega_charity_pro_recent_products_section',
    'taxonomy'          => 'product_cat',
    'type'              => 'dropdown-taxonomies',
    'active_callback'   => 'mega_charity_pro_is_recent_products_section_content_product_category_enable',
) ) );

require get_template_directory() . '/inc/customizer/sections/color/recent-products.php';
