<?php
/**
 * Service Section options
 *
 * @package Theme Palace
 * @subpackage Mega Charity Pro
 * @since Mega Charity Pro 1.0.0
 */

// Add Service section
$wp_customize->add_section( 'mega_charity_pro_service_section', array(
	'title'             => esc_html__( 'Services','mega-charity-pro' ),
	'description'       => esc_html__( 'Services Section options.', 'mega-charity-pro' ),
	'panel'             => 'mega_charity_pro_front_page_panel',
) );

$wp_customize->add_setting(
	'mega_charity_pro_service_section_setting',
	array(
		'default' => 'setting',
		'sanitize_callback' => 'mega_charity_pro_sanitize_select',
	)
);
$wp_customize->add_control(
	'mega_charity_pro_service_section_setting',
	array(
		'section'		=> 'mega_charity_pro_service_section',
		'active_callback' 	=> 'mega_charity_pro_is_service_section_enable',
		'type'			=> 'radio',
		'choices'		=> array(
				'setting' => esc_html__( 'Setting', 'mega-charity-pro' ),
				'style' => esc_html__( 'Style', 'mega-charity-pro' ),
		 	)
	)
);

// Service content enable control and setting
$wp_customize->add_setting( 'mega_charity_pro_theme_options[service_section_enable]', array(
	'default'			=> 	$options['service_section_enable'],
	'sanitize_callback' => 'mega_charity_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Mega_Charity_Pro_Switch_Control( $wp_customize, 'mega_charity_pro_theme_options[service_section_enable]', array(
	'label'             => esc_html__( 'Service Section Enable', 'mega-charity-pro' ),
	'section'           => 'mega_charity_pro_service_section',
	'on_off_label' 		=> mega_charity_pro_switch_options(),
) ) );

if( $options['home_layout'] == 'default-design-all' || $options['home_layout'] == 'default-design' || $options['home_layout'] == 'tenth-design' || $options['home_layout'] == 'ninth-design' ){
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'mega_charity_pro_theme_options[service_section_enable]', array(
		'selector'            => '#our-services .tooltiptext',
		'settings'            => 'mega_charity_pro_theme_options[service_section_enable]',
    ) );
}
}else{
	if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'mega_charity_pro_theme_options[service_section_enable]', array(
		'selector'            => '#business-services-section .tooltiptext',
		'settings'            => 'mega_charity_pro_theme_options[service_section_enable]',
    ) );
}
}

if( in_array($options['home_layout'], array('default-design-all', 'default-design', 'ninth-design') ) ):
// service title setting and control
$wp_customize->add_setting( 'mega_charity_pro_theme_options[service_title]',
	array(
		'default'       		=> $options['service_title'],
		'sanitize_callback'		=> 'mega_charity_pro_santize_allow_tag',
		'transport'				=> 'postMessage',
	)
);
$wp_customize->add_control( 'mega_charity_pro_theme_options[service_title]',
    array(
		'label'      			=> esc_html__( 'Section Title', 'mega-charity-pro' ),
		'section'    			=> 'mega_charity_pro_service_section',
		'type'		 			=> 'textarea',
		'active_callback'		=> 'mega_charity_pro_is_service_section_enable',
    )
);

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'mega_charity_pro_theme_options[service_title]', array(
		'selector'            => '#our-services h2.section-title',
		'settings'            => 'mega_charity_pro_theme_options[service_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'mega_charity_pro_service_title_partial',
    ) );
}

if( $options['home_layout'] == 'default-design-all' || $options['home_layout'] == 'default-design' ){

// service title setting and control
$wp_customize->add_setting( 'mega_charity_pro_theme_options[service_btn_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['service_btn_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'mega_charity_pro_theme_options[service_btn_title]', array(
	'label'           	=> esc_html__( 'Button Label', 'mega-charity-pro' ),
	'section'        	=> 'mega_charity_pro_service_section',
	'active_callback' 	=> 'mega_charity_pro_is_service_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'mega_charity_pro_theme_options[service_btn_title]', array(
		'selector'            => '#our-services a.btn',
		'settings'            => 'mega_charity_pro_theme_options[service_btn_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'mega_charity_pro_service_btn_title_partial',
    ) );
}

$wp_customize->add_setting( 'mega_charity_pro_theme_options[service_btn_url]', array(
	'sanitize_callback' => 'esc_url_raw',
) );

$wp_customize->add_control( 'mega_charity_pro_theme_options[service_btn_url]', array(
	'label'           	=> esc_html__( 'Button Url', 'mega-charity-pro' ),
	'section'        	=> 'mega_charity_pro_service_section',
	'active_callback' 	=> 'mega_charity_pro_is_service_section_enable',
	'type'				=> 'url',
) );

}

endif;

// Servuce count number control and setting
$wp_customize->add_setting( 'mega_charity_pro_theme_options_service_count', array(
	'default'          	=> $options['service_count'],
	'sanitize_callback' => 'mega_charity_pro_sanitize_number_range',
	'validate_callback' => 'mega_charity_pro_validate_service_count',
) );

$wp_customize->add_control( 'mega_charity_pro_theme_options_service_count', array(
	'label'             => esc_html__( 'Number of Posts', 'mega-charity-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'mega-charity-pro' ),
	'section'           => 'mega_charity_pro_service_section',
	'active_callback'   => 'mega_charity_pro_is_service_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 12,
		'style' => 'width: 100px;'
		),
) );

// long Excerpt length setting and control.
$wp_customize->add_setting( 'mega_charity_pro_theme_options[service_excerpt_length]', array(
	'sanitize_callback' => 'mega_charity_pro_sanitize_number_range',
	'validate_callback' => 'mega_charity_pro_validate_long_excerpt',
	'default'			=> $options['service_excerpt_length'],
) );

$wp_customize->add_control( 'mega_charity_pro_theme_options[service_excerpt_length]', array(
	'label'       		=> esc_html__( 'Service Excerpt Length', 'mega-charity-pro' ),
	'description' 		=> esc_html__( 'Total description words to be displayed in service posts.', 'mega-charity-pro' ),
	'section'     		=> 'mega_charity_pro_service_section',
	'active_callback' 	=> 'mega_charity_pro_is_service_section_enable',
	'type'        		=> 'number',
	'input_attrs' 		=> array(
		'style'       => 'width: 80px;',
		'max'         => 100,
		'min'         => 5,
	),
) );

// Service content type control and setting
$wp_customize->add_setting( 'mega_charity_pro_theme_options[service_column_layout]', array(
	'default'          	=> $options['service_column_layout'],
	'sanitize_callback' => 'mega_charity_pro_sanitize_select',
) );

$wp_customize->add_control( 'mega_charity_pro_theme_options[service_column_layout]', array(
	'label'             => esc_html__( 'Column Layout', 'mega-charity-pro' ),
	'section'           => 'mega_charity_pro_service_section',
	'type'				=> 'select',
	'active_callback' 	=> 'mega_charity_pro_is_service_section_enable',
	'choices'			=> array(
            'col-3'      => esc_html__( 'Three Column', 'mega-charity-pro' ),
            'col-4'      => esc_html__( 'Four Column', 'mega-charity-pro' ),
        ),
) );

// Service content type control and setting
$wp_customize->add_setting( 'mega_charity_pro_theme_options_service_content_type', array(
	'default'          	=> $options['service_content_type'],
	'sanitize_callback' => 'mega_charity_pro_sanitize_select',
) );

$wp_customize->add_control( 'mega_charity_pro_theme_options_service_content_type', array(
	'label'             => esc_html__( 'Content Type', 'mega-charity-pro' ),
	'section'           => 'mega_charity_pro_service_section',
	'type'				=> 'select',
	'active_callback' 	=> 'mega_charity_pro_is_service_section_enable',
	'choices'			=> array(
            'page'      => esc_html__( 'Page', 'mega-charity-pro' ),
            'post'      => esc_html__( 'Post', 'mega-charity-pro' ),
            'category'  => esc_html__( 'Category', 'mega-charity-pro' ),
        ),
) );

for ( $i = 1; $i <= get_theme_mod( 'mega_charity_pro_theme_options_service_count', 4); $i++ ) :

	// service note control and setting
	$wp_customize->add_setting( 'mega_charity_pro_theme_options[service_content_icon_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( new Mega_Charity_Pro_Icon_Picker( $wp_customize, 'mega_charity_pro_theme_options[service_content_icon_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Icon %d', 'mega-charity-pro' ), $i ),
		'section'           => 'mega_charity_pro_service_section',
		'active_callback'	=> 'mega_charity_pro_is_service_section_enable',
	) ) );

	// service pages drop down chooser control and setting
	$wp_customize->add_setting( 'mega_charity_pro_theme_options[service_content_page_' . $i . ']', array(
		'sanitize_callback' => 'mega_charity_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Mega_Charity_Pro_Dropdown_Chooser( $wp_customize, 'mega_charity_pro_theme_options[service_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'mega-charity-pro' ), $i ),
		'section'           => 'mega_charity_pro_service_section',
		'choices'			=> mega_charity_pro_page_choices(),
		'active_callback'	=> 'mega_charity_pro_is_service_section_content_page_enable',
	) ) );

	// service posts drop down chooser control and setting
	$wp_customize->add_setting( 'mega_charity_pro_theme_options[service_content_post_' . $i . ']', array(
		'sanitize_callback' => 'mega_charity_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Mega_Charity_Pro_Dropdown_Chooser( $wp_customize, 'mega_charity_pro_theme_options[service_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'mega-charity-pro' ), $i ),
		'section'           => 'mega_charity_pro_service_section',
		'choices'			=> mega_charity_pro_post_choices(),
		'active_callback'	=> 'mega_charity_pro_is_service_section_content_post_enable',
	) ) );

	// service hr setting and control
	$wp_customize->add_setting( 'mega_charity_pro_theme_options[service_hr_'. $i .']', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( new Mega_Charity_Pro_Customize_Horizontal_Line( $wp_customize, 'mega_charity_pro_theme_options[service_hr_'. $i .']',
		array(
			'section'         => 'mega_charity_pro_service_section',
			'active_callback' => 'mega_charity_pro_is_service_section_content_seperator_enable',
			'type'			  => 'hr'
	) ) );

endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'mega_charity_pro_theme_options[service_content_category]', array(
	'sanitize_callback' => 'mega_charity_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Mega_Charity_Pro_Dropdown_Taxonomies_Control( $wp_customize,'mega_charity_pro_theme_options[service_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'mega-charity-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'mega-charity-pro' ),
	'section'           => 'mega_charity_pro_service_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'mega_charity_pro_is_service_section_content_category_enable'
) ) );

require get_template_directory() . '/inc/customizer/sections/color/service.php';