<?php
/**
 * Slider Section options
 *
 * @package Theme Palace
 * @subpackage Mega Charity Pro
 * @since Mega Charity Pro 1.0.0
 */

// Add Slider section
$wp_customize->add_section( 'mega_charity_pro_slider_section', array(
	'title'             => esc_html__( 'Main Slider','mega-charity-pro' ),
	'description'       => esc_html__( 'Slider Section options.', 'mega-charity-pro' ),
	'panel'             => 'mega_charity_pro_front_page_panel',
) );

$wp_customize->add_setting(
	'mega_charity_pro_slider_section_setting',
	array(
		'default' => 'setting',
		'sanitize_callback' => 'mega_charity_pro_sanitize_select',
	)
);
$wp_customize->add_control(
	'mega_charity_pro_slider_section_setting',
	array(
		'section'		=> 'mega_charity_pro_slider_section',
		'type'			=> 'radio',
		'active_callback' 	=> 'mega_charity_pro_is_slider_section_enable',
		'choices'		=> array(
				'setting' => esc_html__( 'Setting', 'mega-charity-pro' ),
				'style' => esc_html__( 'Style', 'mega-charity-pro' ),
		 	)
	)
);

// Slider content enable control and setting
$wp_customize->add_setting( 'mega_charity_pro_theme_options[slider_section_enable]', array(
	'default'			=> 	$options['slider_section_enable'],
	'sanitize_callback' => 'mega_charity_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Mega_Charity_Pro_Switch_Control( $wp_customize, 'mega_charity_pro_theme_options[slider_section_enable]', array(
	'label'             => esc_html__( 'Slider Section Enable', 'mega-charity-pro' ),
	'section'           => 'mega_charity_pro_slider_section',
	'on_off_label' 		=> mega_charity_pro_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'mega_charity_pro_theme_options[slider_section_enable]', array(
		'selector'            => '#featured-slider .tooltiptext',
		'settings'            => 'mega_charity_pro_theme_options[slider_section_enable]',
    ) );
}

// Slider content enable control and setting
$wp_customize->add_setting( 'mega_charity_pro_theme_options[slider_autoplay]', array(
	'default'			=> 	$options['slider_autoplay'],
	'sanitize_callback' => 'mega_charity_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Mega_Charity_Pro_Switch_Control( $wp_customize, 'mega_charity_pro_theme_options[slider_autoplay]', array(
	'label'             => esc_html__( 'Auto Play Enable', 'mega-charity-pro' ),
	'section'           => 'mega_charity_pro_slider_section',
	'on_off_label' 		=> mega_charity_pro_switch_options(),
	'active_callback' 	=> 'mega_charity_pro_is_slider_section_enable',
) ) );

// Slider content enable control and setting
$wp_customize->add_setting( 'mega_charity_pro_theme_options[slider_arrow]', array(
	'default'			=> 	$options['slider_arrow'],
	'sanitize_callback' => 'mega_charity_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Mega_Charity_Pro_Switch_Control( $wp_customize, 'mega_charity_pro_theme_options[slider_arrow]', array(
	'label'             => esc_html__( 'Slider Arrow', 'mega-charity-pro' ),
	'section'           => 'mega_charity_pro_slider_section',
	'on_off_label' 		=> mega_charity_pro_switch_options(),
	'active_callback' 	=> 'mega_charity_pro_is_slider_section_enable',
) ) );

// Slider btn label setting and control
$wp_customize->add_setting( 'mega_charity_pro_theme_options[slider_btn_label]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['slider_btn_label'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'mega_charity_pro_theme_options[slider_btn_label]', array(
	'label'           	=> esc_html__( 'Slider Button Label', 'mega-charity-pro' ),
	'section'        	=> 'mega_charity_pro_slider_section',
	'active_callback' 	=> 'mega_charity_pro_is_slider_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'mega_charity_pro_theme_options[slider_btn_label]', array(
		'selector'            => '#featured-slider .read-more a',
		'settings'            => 'mega_charity_pro_theme_options[slider_btn_label]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'mega_charity_pro_slider_btn_label_partial',
    ) );
}

// long Excerpt length setting and control.
$wp_customize->add_setting( 'mega_charity_pro_theme_options[slider_excerpt_length]', array(
	'sanitize_callback' => 'mega_charity_pro_sanitize_number_range',
	'validate_callback' => 'mega_charity_pro_validate_long_excerpt',
	'default'			=> $options['slider_excerpt_length'],
) );

$wp_customize->add_control( 'mega_charity_pro_theme_options[slider_excerpt_length]', array(
	'label'       		=> esc_html__( 'Slider Excerpt Length', 'mega-charity-pro' ),
	'description' 		=> esc_html__( 'Total description words to be displayed in slider posts.', 'mega-charity-pro' ),
	'section'     		=> 'mega_charity_pro_slider_section',
	'active_callback' 	=> 'mega_charity_pro_is_slider_section_enable',
	'type'        		=> 'number',
	'input_attrs' 		=> array(
		'style'       => 'width: 80px;',
		'max'         => 100,
		'min'         => 5,
	),
) );

// Event social icons number control and setting
$wp_customize->add_setting( 'mega_charity_pro_theme_options_slider_count', array(
	'default'          	=> $options['slider_count'],
	'sanitize_callback' => 'mega_charity_pro_sanitize_number_range',
	'validate_callback' => 'mega_charity_pro_validate_slider_count',
) );

$wp_customize->add_control( 'mega_charity_pro_theme_options_slider_count', array(
	'label'             => esc_html__( 'Number of Slides', 'mega-charity-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'mega-charity-pro' ),
	'section'           => 'mega_charity_pro_slider_section',
	'active_callback'   => 'mega_charity_pro_is_slider_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 12,
		'style' => 'width: 100px;'
		),
) );

// Slider content type control and setting
$wp_customize->add_setting( 'mega_charity_pro_theme_options_slider_content_type', array(
	'default'          	=> $options['slider_content_type'],
	'sanitize_callback' => 'mega_charity_pro_sanitize_select',
) );

$wp_customize->add_control( 'mega_charity_pro_theme_options_slider_content_type', array(
	'label'             => esc_html__( 'Content Type', 'mega-charity-pro' ),
	'section'           => 'mega_charity_pro_slider_section',
	'type'				=> 'select',
	'active_callback' 	=> 'mega_charity_pro_is_slider_section_enable',
	'choices'			=> array(
            'page'      => esc_html__( 'Page', 'mega-charity-pro' ),
            'post'      => esc_html__( 'Post', 'mega-charity-pro' ),
            'category'  => esc_html__( 'Category', 'mega-charity-pro' ),
        )
) );

for ( $i = 1; $i <= get_theme_mod( 'mega_charity_pro_theme_options_slider_count', 3 ); $i++ ) :

	// slider pages drop down chooser control and setting
	$wp_customize->add_setting( 'mega_charity_pro_theme_options[slider_content_page_' . $i . ']', array(
		'sanitize_callback' => 'mega_charity_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Mega_Charity_Pro_Dropdown_Chooser( $wp_customize, 'mega_charity_pro_theme_options[slider_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'mega-charity-pro' ), $i ),
		'section'           => 'mega_charity_pro_slider_section',
		'choices'			=> mega_charity_pro_page_choices(),
		'active_callback'	=> 'mega_charity_pro_is_slider_section_content_page_enable',
	) ) );

	// slider posts drop down chooser control and setting
	$wp_customize->add_setting( 'mega_charity_pro_theme_options[slider_content_post_' . $i . ']', array(
		'sanitize_callback' => 'mega_charity_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Mega_Charity_Pro_Dropdown_Chooser( $wp_customize, 'mega_charity_pro_theme_options[slider_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'mega-charity-pro' ), $i ),
		'section'           => 'mega_charity_pro_slider_section',
		'choices'			=> mega_charity_pro_post_choices(),
		'active_callback'	=> 'mega_charity_pro_is_slider_section_content_post_enable',
	) ) );

endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'mega_charity_pro_theme_options[slider_content_category]', array(
	'sanitize_callback' => 'mega_charity_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Mega_Charity_Pro_Dropdown_Taxonomies_Control( $wp_customize,'mega_charity_pro_theme_options[slider_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'mega-charity-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'mega-charity-pro' ),
	'section'           => 'mega_charity_pro_slider_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'mega_charity_pro_is_slider_section_content_category_enable'
) ) );

require get_template_directory() . '/inc/customizer/sections/color/slider.php';
