<?php
/**
 * Team Section options
 *
 * @package Theme Palace
 * @subpackage Mega Charity Pro
 * @since Mega Charity Pro 1.0.0
 */

// Add Team section
$wp_customize->add_section( 'mega_charity_pro_team_section', array(
	'title'             => esc_html__( 'Teams','mega-charity-pro' ),
	'description'       => esc_html__( 'Teams Section options.', 'mega-charity-pro' ),
	'panel'             => 'mega_charity_pro_front_page_panel',
) );

$wp_customize->add_setting(
	'mega_charity_pro_team_section_setting',
	array(
		'default' => 'setting',
		'sanitize_callback' => 'mega_charity_pro_sanitize_select',
	)
);
$wp_customize->add_control(
	'mega_charity_pro_team_section_setting',
	array(
		'section'		=> 'mega_charity_pro_team_section',
		'type'			=> 'radio',
		'active_callback' 	=> 'mega_charity_pro_is_team_section_enable',
		'choices'		=> array(
				'setting' => esc_html__( 'Setting', 'mega-charity-pro' ),
				'style' => esc_html__( 'Style', 'mega-charity-pro' ),
		 	)
	)
);

// Team content enable control and setting
$wp_customize->add_setting( 'mega_charity_pro_theme_options[team_section_enable]', array(
	'default'			=> 	$options['team_section_enable'],
	'sanitize_callback' => 'mega_charity_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Mega_Charity_Pro_Switch_Control( $wp_customize, 'mega_charity_pro_theme_options[team_section_enable]', array(
	'label'             => esc_html__( 'Team Section Enable', 'mega-charity-pro' ),
	'section'           => 'mega_charity_pro_team_section',
	'on_off_label' 		=> mega_charity_pro_switch_options(),
) ) );


if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'mega_charity_pro_theme_options[team_section_enable]', array(
		'selector'            => '#business-team .tooltiptext',
		'settings'            => 'mega_charity_pro_theme_options[team_section_enable]',
    ) );
}

// team title setting and control
$wp_customize->add_setting( 'mega_charity_pro_theme_options[team_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['team_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'mega_charity_pro_theme_options[team_title]', array(
	'label'           	=> esc_html__( 'Title', 'mega-charity-pro' ),
	'section'        	=> 'mega_charity_pro_team_section',
	'active_callback' 	=> 'mega_charity_pro_is_team_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'mega_charity_pro_theme_options[team_title]', array(
		'selector'            => '#business-team h2.section-title',
		'settings'            => 'mega_charity_pro_theme_options[team_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'mega_charity_pro_team_title_partial',
    ) );
}

// team content type control and setting
$wp_customize->add_setting( 'mega_charity_pro_theme_options[team_column]', array(
	'default'          	=> $options['team_column'],
	'sanitize_callback' => 'mega_charity_pro_sanitize_select',
) );

$wp_customize->add_control( 'mega_charity_pro_theme_options[team_column]', array(
	'label'             => esc_html__( 'Column Layout', 'mega-charity-pro' ),
	'section'           => 'mega_charity_pro_team_section',
	'type'				=> 'select',
	'active_callback' 	=> 'mega_charity_pro_is_team_section_enable',
	'choices'			=> array(
		'col-3'		=> esc_html__( 'Three Column', 'mega-charity-pro' ),
		'col-4'		=> esc_html__( 'Four Column', 'mega-charity-pro' ),
	),
) );

// Team content type control and setting
$wp_customize->add_setting( 'mega_charity_pro_theme_options_team_content_type', array(
	'default'          	=> $options['team_content_type'],
	'sanitize_callback' => 'mega_charity_pro_sanitize_select',
) );

$wp_customize->add_control( 'mega_charity_pro_theme_options_team_content_type', array(
	'label'             => esc_html__( 'Content Type', 'mega-charity-pro' ),
	'section'           => 'mega_charity_pro_team_section',
	'type'				=> 'select',
	'active_callback' 	=> 'mega_charity_pro_is_team_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'mega-charity-pro' ),
		'post' 		=> esc_html__( 'Post', 'mega-charity-pro' ),
		'category' 	=> esc_html__( 'Category', 'mega-charity-pro' ),
	),
) );

// team number control and setting
$wp_customize->add_setting( 'mega_charity_pro_theme_options_team_count', array(
	'default'          	=> $options['team_count'],
	'sanitize_callback' => 'mega_charity_pro_sanitize_number_range',
	'validate_callback' => 'mega_charity_pro_validate_team_count',
) );

$wp_customize->add_control( 'mega_charity_pro_theme_options_team_count', array(
	'label'             => esc_html__( 'Number of Posts', 'mega-charity-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'mega-charity-pro' ),
	'section'           => 'mega_charity_pro_team_section',
	'active_callback'   => 'mega_charity_pro_is_team_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 12,
		'style' => 'width: 100px;'
		),
) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'mega_charity_pro_theme_options[team_content_category]', array(
	'sanitize_callback' => 'mega_charity_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Mega_Charity_Pro_Dropdown_Taxonomies_Control( $wp_customize,'mega_charity_pro_theme_options[team_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'mega-charity-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'mega-charity-pro' ),
	'section'           => 'mega_charity_pro_team_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'mega_charity_pro_is_team_section_content_category_enable'
) ) );


for ( $i = 1; $i <= get_theme_mod( 'mega_charity_pro_theme_options_team_count', 4 ); $i++ ) :

	// team pages drop down chooser control and setting
	$wp_customize->add_setting( 'mega_charity_pro_theme_options[team_content_page_' . $i . ']', array(
		'sanitize_callback' => 'mega_charity_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Mega_Charity_Pro_Dropdown_Chooser( $wp_customize, 'mega_charity_pro_theme_options[team_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'mega-charity-pro' ), $i ),
		'section'           => 'mega_charity_pro_team_section',
		'choices'			=> mega_charity_pro_page_choices(),
		'active_callback'	=> 'mega_charity_pro_is_team_section_content_page_enable',
	) ) );

	// team posts drop down chooser control and setting
	$wp_customize->add_setting( 'mega_charity_pro_theme_options[team_content_post_' . $i . ']', array(
		'sanitize_callback' => 'mega_charity_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Mega_Charity_Pro_Dropdown_Chooser( $wp_customize, 'mega_charity_pro_theme_options[team_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'mega-charity-pro' ), $i ),
		'section'           => 'mega_charity_pro_team_section',
		'choices'			=> mega_charity_pro_post_choices(),
		'active_callback'	=> 'mega_charity_pro_is_team_section_content_post_enable',
	) ) );

	// team custom content
	$wp_customize->add_setting( 'mega_charity_pro_theme_options[team_position_' . $i . ']', array(
		'sanitize_callback' => 'wp_kses_post',
	) );

	$wp_customize->add_control( 'mega_charity_pro_theme_options[team_position_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Position %d', 'mega-charity-pro' ), $i ),
		'section'           => 'mega_charity_pro_team_section',
		'active_callback'	=> 'mega_charity_pro_is_team_section_enable',
	) );

	// team social
	$wp_customize->add_setting( 'mega_charity_pro_theme_options[team_social_' . $i. ']', array(
		'sanitize_callback' => 'esc_url_raw',
	) );

	$wp_customize->add_control( new Mega_Charity_Pro_Multi_Input_Custom_Control( $wp_customize, 'mega_charity_pro_theme_options[team_social_' . $i. ']', array(
		'label'             => esc_html__( 'Social ', 'mega-charity-pro' ),
		'button_text'       => esc_html__( 'Add social.', 'mega-charity-pro' ),
		'section'           => 'mega_charity_pro_team_section',
		'active_callback' 	=> 'mega_charity_pro_is_team_section_enable',
	) ) );

	// team hr setting and control
	$wp_customize->add_setting( 'travel_ultimate_pro_theme_options[team_hr_'. $i .']', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( new Mega_Charity_Pro_Customize_Horizontal_Line( $wp_customize, 'travel_ultimate_pro_theme_options[team_hr_'. $i .']',
		array(
			'section'         => 'mega_charity_pro_team_section',
			'active_callback' => 'mega_charity_pro_is_team_section_enable',
			'type'			  => 'hr'
	) ) );
endfor;

require get_template_directory() . '/inc/customizer/sections/color/team.php';