<?php
/**
 * Testimonial Section options
 *
 * @package Theme Palace
 * @subpackage Mega Charity Pro
 * @since Mega Charity Pro 1.0.0
 */

// Add Testimonial section
$wp_customize->add_section( 'mega_charity_pro_testimonial_section', array(
	'title'             => esc_html__( 'Testimonial','mega-charity-pro' ),
	'description'       => esc_html__( 'Testimonial Section options.', 'mega-charity-pro' ),
	'panel'             => 'mega_charity_pro_front_page_panel',
) );

$wp_customize->add_setting(
	'mega_charity_pro_testimonial_section_setting',
	array(
		'default' => 'setting',
		'sanitize_callback' => 'mega_charity_pro_sanitize_select',
	)
);
$wp_customize->add_control(
	'mega_charity_pro_testimonial_section_setting',
	array(
		'section'		=> 'mega_charity_pro_testimonial_section',
		'type'			=> 'radio',
		'active_callback' 	=> 'mega_charity_pro_is_testimonial_section_enable',
		'choices'		=> array(
				'setting' => esc_html__( 'Setting', 'mega-charity-pro' ),
				'style' => esc_html__( 'Style', 'mega-charity-pro' ),
		 	)
	)
);

// Testimonial content enable control and setting
$wp_customize->add_setting( 'mega_charity_pro_theme_options[testimonial_section_enable]', array(
	'default'			=> 	$options['testimonial_section_enable'],
	'sanitize_callback' => 'mega_charity_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Mega_Charity_Pro_Switch_Control( $wp_customize, 'mega_charity_pro_theme_options[testimonial_section_enable]', array(
	'label'             => esc_html__( 'Testimonial Section Enable', 'mega-charity-pro' ),
	'section'           => 'mega_charity_pro_testimonial_section',
	'on_off_label' 		=> mega_charity_pro_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'mega_charity_pro_theme_options[testimonial_section_enable]', array(
		'selector'            => '#testimonial .tooltiptext',
		'settings'            => 'mega_charity_pro_theme_options[testimonial_section_enable]',
    ) );
}

// Testimonial auto play enable control and setting
$wp_customize->add_setting( 'mega_charity_pro_theme_options[testimonial_auto_play]', array(
	'default'			=> 	$options['testimonial_auto_play'],
	'sanitize_callback' => 'mega_charity_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Mega_Charity_Pro_Switch_Control( $wp_customize, 'mega_charity_pro_theme_options[testimonial_auto_play]', array(
	'label'             => esc_html__( 'Auto Play Enable', 'mega-charity-pro' ),
	'section'           => 'mega_charity_pro_testimonial_section',
	'on_off_label' 		=> mega_charity_pro_switch_options(),
	'active_callback' 	=> 'mega_charity_pro_is_testimonial_section_enable',
) ) );

$wp_customize->add_setting( 'mega_charity_pro_theme_options[testimonial_bg_image]', array(
		'sanitize_callback' => 'mega_charity_pro_sanitize_image'
	) );

	$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'mega_charity_pro_theme_options[testimonial_bg_image]',
			array(
			'label'       		=> esc_html__( 'Background Image ', 'mega-charity-pro' ),
			'section'     		=> 'mega_charity_pro_testimonial_section',
			'active_callback'	=> 'mega_charity_pro_is_testimonial_section_enable',
	) ) );

// Event social icons number control and setting
$wp_customize->add_setting( 'mega_charity_pro_theme_options_testimonial_count', array(
	'default'          	=> $options['testimonial_count'],
	'sanitize_callback' => 'mega_charity_pro_sanitize_number_range',
	'validate_callback' => 'mega_charity_pro_validate_testimonial_count',
) );

$wp_customize->add_control( 'mega_charity_pro_theme_options_testimonial_count', array(
	'label'             => esc_html__( 'Number of Testimonials', 'mega-charity-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 10. Please input the valid number and save. Then refresh the page to see the change.', 'mega-charity-pro' ),
	'section'           => 'mega_charity_pro_testimonial_section',
	'active_callback'   => 'mega_charity_pro_is_testimonial_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 10,
		'style' => 'width: 100px;'
		),
) );

// long Excerpt length setting and control.
$wp_customize->add_setting( 'mega_charity_pro_theme_options[testimonial_excerpt_length]', array(
	'sanitize_callback' => 'mega_charity_pro_sanitize_number_range',
	'validate_callback' => 'mega_charity_pro_validate_long_excerpt',
	'default'			=> $options['testimonial_excerpt_length'],
) );

$wp_customize->add_control( 'mega_charity_pro_theme_options[testimonial_excerpt_length]', array(
	'label'       		=> esc_html__( 'Testimonial Excerpt Length', 'mega-charity-pro' ),
	'description' 		=> esc_html__( 'Total description words to be displayed in testimonial posts.', 'mega-charity-pro' ),
	'section'     		=> 'mega_charity_pro_testimonial_section',
	'active_callback' 	=> 'mega_charity_pro_is_testimonial_section_enable',
	'type'        		=> 'number',
	'input_attrs' 		=> array(
		'style'       => 'width: 80px;',
		'max'         => 100,
		'min'         => 5,
	),
) );

// Testimonial content type control and setting
$wp_customize->add_setting( 'mega_charity_pro_theme_options_testimonial_content_type', array(
	'default'          	=> $options['testimonial_content_type'],
	'sanitize_callback' => 'mega_charity_pro_sanitize_select',
) );

$wp_customize->add_control( 'mega_charity_pro_theme_options_testimonial_content_type', array(
	'label'             => esc_html__( 'Content Type', 'mega-charity-pro' ),
	'section'           => 'mega_charity_pro_testimonial_section',
	'type'				=> 'select',
	'active_callback' 	=> 'mega_charity_pro_is_testimonial_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'mega-charity-pro' ),
		'post' 		=> esc_html__( 'Post', 'mega-charity-pro' ),
		'category' 	=> esc_html__( 'Category', 'mega-charity-pro' ),
	),
) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'mega_charity_pro_theme_options[testimonial_content_category]', array(
	'sanitize_callback' => 'mega_charity_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Mega_Charity_Pro_Dropdown_Taxonomies_Control( $wp_customize,'mega_charity_pro_theme_options[testimonial_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'mega-charity-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'mega-charity-pro' ),
	'section'           => 'mega_charity_pro_testimonial_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'mega_charity_pro_is_testimonial_section_content_category_enable'
) ) );

for ( $i = 1; $i <= get_theme_mod( 'mega_charity_pro_theme_options_testimonial_count', 4 ); $i++ ) :
	// testimonial pages drop down chooser control and setting
	$wp_customize->add_setting( 'mega_charity_pro_theme_options[testimonial_content_page_' . $i . ']', array(
		'sanitize_callback' => 'mega_charity_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Mega_Charity_Pro_Dropdown_Chooser( $wp_customize, 'mega_charity_pro_theme_options[testimonial_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'mega-charity-pro' ), $i ),
		'section'           => 'mega_charity_pro_testimonial_section',
		'choices'			=> mega_charity_pro_page_choices(),
		'active_callback'	=> 'mega_charity_pro_is_testimonial_section_content_page_enable',
	) ) );

	// testimonial posts drop down chooser control and setting
	$wp_customize->add_setting( 'mega_charity_pro_theme_options[testimonial_content_post_' . $i . ']', array(
		'sanitize_callback' => 'mega_charity_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Mega_Charity_Pro_Dropdown_Chooser( $wp_customize, 'mega_charity_pro_theme_options[testimonial_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'mega-charity-pro' ), $i ),
		'section'           => 'mega_charity_pro_testimonial_section',
		'choices'			=> mega_charity_pro_post_choices(),
		'active_callback'	=> 'mega_charity_pro_is_testimonial_section_content_post_enable',
	) ) );

	$wp_customize->add_setting( 'mega_charity_pro_theme_options[testimonial_author_name_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'mega_charity_pro_theme_options[testimonial_author_name_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'Author Name %d', 'mega-charity-pro' ), $i ),
		'section'        	=> 'mega_charity_pro_testimonial_section',
		'active_callback' 	=> 'mega_charity_pro_is_testimonial_section_enable',
		'type'				=> 'text',
	) );

	$wp_customize->add_setting( 'mega_charity_pro_theme_options[testimonial_author_link_' . $i . ']', array(
		'sanitize_callback' => 'esc_url_raw',
	) );

	$wp_customize->add_control( 'mega_charity_pro_theme_options[testimonial_author_link_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'Author Url %d', 'mega-charity-pro' ), $i ),
		'section'        	=> 'mega_charity_pro_testimonial_section',
		'active_callback' 	=> 'mega_charity_pro_is_testimonial_section_enable',
		'type'				=> 'url',
	) );

	$wp_customize->add_setting( 'mega_charity_pro_theme_options[testimonial_author_position_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'mega_charity_pro_theme_options[testimonial_author_position_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'Author Position %d', 'mega-charity-pro' ), $i ),
		'section'        	=> 'mega_charity_pro_testimonial_section',
		'active_callback' 	=> 'mega_charity_pro_is_testimonial_section_enable',
		'type'				=> 'text',
	) );

	// testimonial hr setting and control
	$wp_customize->add_setting( 'mega_charity_pro_theme_options[testimonial_hr_'. $i .']', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( new Mega_Charity_Pro_Customize_Horizontal_Line( $wp_customize, 'mega_charity_pro_theme_options[testimonial_hr_'. $i .']',
		array(
			'section'         => 'mega_charity_pro_testimonial_section',
			'active_callback' => 'mega_charity_pro_is_testimonial_section_enable',
			'type'			  => 'hr'
	) ) );
endfor;

require get_template_directory() . '/inc/customizer/sections/color/testimonial.php';
