<?php
/**
 * Video Section options
 *
 * @package Theme Palace
 * @subpackage Mega Charity Pro
 * @since Mega Charity Pro 1.0.0
 */

// Add Video section
$wp_customize->add_section( 'mega_charity_pro_video_section', array(
	'title'             => esc_html__( 'Video','mega-charity-pro' ),
	'description'       => esc_html__( 'Video Section options.', 'mega-charity-pro' ),
	'panel'             => 'mega_charity_pro_front_page_panel',
) );

$wp_customize->add_setting(
	'mega_charity_pro_video_section_setting',
	array(
		'default' => 'setting',
		'sanitize_callback' => 'mega_charity_pro_sanitize_select',
	)
);
$wp_customize->add_control(
	'mega_charity_pro_video_section_setting',
	array(
		'section'		=> 'mega_charity_pro_video_section',
		'type'			=> 'radio',
		'active_callback' 	=> 'mega_charity_pro_is_video_section_enable',
		'choices'		=> array(
				'setting' => esc_html__( 'Setting', 'mega-charity-pro' ),
				'style' => esc_html__( 'Style', 'mega-charity-pro' ),
		 	)
	)
);

// Video content enable control and setting
$wp_customize->add_setting( 'mega_charity_pro_theme_options[video_section_enable]', array(
	'default'			=> 	$options['video_section_enable'],
	'sanitize_callback' => 'mega_charity_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Mega_Charity_Pro_Switch_Control( $wp_customize, 'mega_charity_pro_theme_options[video_section_enable]', array(
	'label'             => esc_html__( 'Video Section Enable', 'mega-charity-pro' ),
	'section'           => 'mega_charity_pro_video_section',
	'on_off_label' 		=> mega_charity_pro_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'mega_charity_pro_theme_options[video_section_enable]', array(
		'selector'            => '#video .tooltiptext',
		'settings'            => 'mega_charity_pro_theme_options[video_section_enable]',
    ) );
}

// video image setting and control.
$wp_customize->add_setting( 'mega_charity_pro_theme_options[video_bg_image]', array(
	'sanitize_callback' => 'mega_charity_pro_sanitize_image'
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'mega_charity_pro_theme_options[video_bg_image]',
		array(
		'label'       		=> esc_html__( 'Video Background Image', 'mega-charity-pro' ),
		'section'     		=> 'mega_charity_pro_video_section',
		'active_callback'	=> 'mega_charity_pro_is_video_section_enable',
) ) );

// long Excerpt length setting and control.
$wp_customize->add_setting( 'mega_charity_pro_theme_options[video_excerpt_length]', array(
	'sanitize_callback' => 'mega_charity_pro_sanitize_number_range',
	'validate_callback' => 'mega_charity_pro_validate_long_excerpt',
	'default'			=> $options['video_excerpt_length'],
) );

$wp_customize->add_control( 'mega_charity_pro_theme_options[video_excerpt_length]', array(
	'label'       		=> esc_html__( 'Video Excerpt Length', 'mega-charity-pro' ),
	'description' 		=> esc_html__( 'Total description words to be displayed in video posts.', 'mega-charity-pro' ),
	'section'     		=> 'mega_charity_pro_video_section',
	'active_callback' 	=> 'mega_charity_pro_is_video_section_enable',
	'type'        		=> 'number',
	'input_attrs' 		=> array(
		'style'       => 'width: 80px;',
		'max'         => 100,
		'min'         => 5,
	),
) );

// Video content type control and setting
$wp_customize->add_setting( 'mega_charity_pro_theme_options_video_content_type', array(
	'default'          	=> $options['video_content_type'],
	'sanitize_callback' => 'mega_charity_pro_sanitize_select',
) );

$wp_customize->add_control( 'mega_charity_pro_theme_options_video_content_type', array(
	'label'             => esc_html__( 'Content Type', 'mega-charity-pro' ),
	'section'           => 'mega_charity_pro_video_section',
	'type'				=> 'select',
	'active_callback' 	=> 'mega_charity_pro_is_video_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'mega-charity-pro' ),
		'post' 		=> esc_html__( 'Post', 'mega-charity-pro' ),
	),
) );


// video pages drop down chooser control and setting
$wp_customize->add_setting( 'mega_charity_pro_theme_options[video_content_page]', array(
	'sanitize_callback' => 'mega_charity_pro_sanitize_page',
) );

$wp_customize->add_control( new Mega_Charity_Pro_Dropdown_Chooser( $wp_customize, 'mega_charity_pro_theme_options[video_content_page]', array(
	'label'             => esc_html__( 'Select Page', 'mega-charity-pro' ),
	'section'           => 'mega_charity_pro_video_section',
	'choices'			=> mega_charity_pro_page_choices(),
	'active_callback'	=> 'mega_charity_pro_is_video_section_content_page_enable',
) ) );

// video posts drop down chooser control and setting
$wp_customize->add_setting( 'mega_charity_pro_theme_options[video_content_post]', array(
	'sanitize_callback' => 'mega_charity_pro_sanitize_page',
) );

$wp_customize->add_control( new Mega_Charity_Pro_Dropdown_Chooser( $wp_customize, 'mega_charity_pro_theme_options[video_content_post]', array(
	'label'             => esc_html__( 'Select Post', 'mega-charity-pro' ),
	'section'           => 'mega_charity_pro_video_section',
	'choices'			=> mega_charity_pro_post_choices(),
	'active_callback'	=> 'mega_charity_pro_is_video_section_content_post_enable',
) ) );

	$wp_customize->add_setting( 'mega_charity_pro_theme_options[video_url]', array(
		'sanitize_callback' => 'esc_url_raw',
	) );

	$wp_customize->add_control( 'mega_charity_pro_theme_options[video_url]', array(
		'label'           	=> esc_html__( 'Video Url ', 'mega-charity-pro' ),
		'section'        	=> 'mega_charity_pro_video_section',
		'active_callback' 	=> 'mega_charity_pro_is_video_section_enable',
		'type'				=> 'url',
	) );

	require get_template_directory() . '/inc/customizer/sections/color/video.php';