<?php
/**
 * Theme Palace options
 *
 * @package Theme Palace
 * @subpackage Mega Charity Pro
 * @since Mega Charity Pro 1.0.0
 */

/**
 * List of pages for page choices.
 * @return Array Array of page ids and name.
 */
function mega_charity_pro_page_choices() {
    $pages = get_pages();
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'mega-charity-pro' );
    foreach ( $pages as $page ) {
        $choices[ $page->ID ] = $page->post_title;
    }
    return  $choices;
}

/**
 * List of posts for post choices.
 * @return Array Array of post ids and name.
 */
function mega_charity_pro_post_choices() {
    $posts = get_posts( array( 'numberposts' => -1 ) );
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'mega-charity-pro' );
    foreach ( $posts as $post ) {
        $choices[ $post->ID ] = $post->post_title;
    }
    return  $choices;
}

/**
 * List of events for post choices.
 * @return Array Array of post ids and name.
 */
function mega_charity_pro_event_choices() {
    $posts = get_posts( array( 'numberposts' => -1, 'post_type' => 'tp-event' ) );
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'mega-charity-pro' );
    foreach ( $posts as $post ) {
        $choices[ $post->ID ] = $post->post_title;
    }
    return  $choices;
}

/**
 * List of trips for post choices.
 * @return Array Array of post ids and name.
 */
function mega_charity_pro_trip_choices() {
    $posts = get_posts( array( 'post_type' => 'itineraries', 'numberposts' => -1 ) );
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'mega-charity-pro' );
    foreach ( $posts as $post ) {
        $choices[ $post->ID ] = $post->post_title;
    }
    return  $choices;
}

function mega_charity_pro_product_choices() {
    $full_product_list = array();
    $product_id = array();
    $loop = new WP_Query(array('post_type' => array('product', 'product_variation'), 'posts_per_page' => -1));
    while ($loop->have_posts()) : $loop->the_post();
        $product_id[] = get_the_id();
    endwhile;
    wp_reset_postdata();
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'mega-charity-pro' );
    foreach ( $product_id  as $id ) {
        $choices[ $id ] = get_the_title( $id );
    }
    return  $choices;
}

if ( ! function_exists( 'mega_charity_pro_typography_options' ) ) :
    /**
     * Returns list of typography
     * @return array font styles
     */
    function mega_charity_pro_typography_options(){
        $font_family_arr = array();
        $font_family_arr[''] = esc_html__( '--Default--', 'mega-charity-pro' );

        // Make the request
        $request = wp_remote_get( get_theme_file_uri( 'assets/webfonts.json' ) );

        if( is_wp_error( $request ) ) {
            return false; // Bail early
        }
        // Retrieve the data
        $body = wp_remote_retrieve_body( $request );
        $data = json_decode( $body );
        if ( ! empty( $data ) ) {
            foreach ( $data->items as $items => $fonts ) {
                $family_str_arr = explode( ' ', $fonts->family );
                $family_value = implode( '+', $family_str_arr );
                $font_family_arr[ $family_value ] = $fonts->family;
            }
        }

        return $font_family_arr;
    }
endif;


if ( ! function_exists( 'mega_charity_pro_selected_sidebar' ) ) :
    /**
     * Sidebars options
     * @return array Sidbar positions
     */
    function mega_charity_pro_selected_sidebar() {
        $mega_charity_pro_selected_sidebar = array(
            'sidebar-1'             => esc_html__( 'Default Sidebar', 'mega-charity-pro' ),
            'optional-sidebar'      => esc_html__( 'Optional Sidebar 1', 'mega-charity-pro' ),
            'optional-sidebar-2'    => esc_html__( 'Optional Sidebar 2', 'mega-charity-pro' ),
            'optional-sidebar-3'    => esc_html__( 'Optional Sidebar 3', 'mega-charity-pro' ),
            'optional-sidebar-4'    => esc_html__( 'Optional Sidebar 4', 'mega-charity-pro' ),
        );

        $output = apply_filters( 'mega_charity_pro_selected_sidebar', $mega_charity_pro_selected_sidebar );

        return $output;
    }
endif;

if ( ! function_exists( 'mega_charity_pro_site_layout' ) ) :
    /**
     * Site Layout
     * @return array site layout options
     */
    function mega_charity_pro_site_layout() {
        $mega_charity_pro_site_layout = array(
            'wide-layout'  => get_template_directory_uri() . '/assets/images/full.png',
            'boxed-layout' => get_template_directory_uri() . '/assets/images/boxed.png',
            'frame-layout' => get_template_directory_uri() . '/assets/images/framed.png',
        );

        $output = apply_filters( 'mega_charity_pro_site_layout', $mega_charity_pro_site_layout );
        return $output;
    }
endif;


if ( ! function_exists( 'mega_charity_pro_global_sidebar_position' ) ) :
    /**
     * Global Sidebar position
     * @return array Global Sidebar positions
     */
    function mega_charity_pro_global_sidebar_position() {
        $mega_charity_pro_global_sidebar_position = array(
            'right-sidebar' => get_template_directory_uri() . '/assets/images/right.png',
            'left-sidebar'  => get_template_directory_uri() . '/assets/images/left.png',
            'no-sidebar'    => get_template_directory_uri() . '/assets/images/full.png',
        );

        $output = apply_filters( 'mega_charity_pro_global_sidebar_position', $mega_charity_pro_global_sidebar_position );

        return $output;
    }
endif;


if ( ! function_exists( 'mega_charity_pro_sidebar_position' ) ) :
    /**
     * Sidebar position
     * @return array Sidbar positions
     */
    function mega_charity_pro_sidebar_position() {
        $mega_charity_pro_sidebar_position = array(
            'right-sidebar' => get_template_directory_uri() . '/assets/images/right.png',
            'left-sidebar'  => get_template_directory_uri() . '/assets/images/left.png',
            'no-sidebar'    => get_template_directory_uri() . '/assets/images/full.png',
            'no-sidebar-content'   => get_template_directory_uri() . '/assets/images/boxed.png',
        );

        $output = apply_filters( 'mega_charity_pro_sidebar_position', $mega_charity_pro_sidebar_position );

        return $output;
    }
endif;


if ( ! function_exists( 'mega_charity_pro_pagination_options' ) ) :
    /**
     * Pagination
     * @return array site pagination options
     */
    function mega_charity_pro_pagination_options() {
        $mega_charity_pro_pagination_options = array(
            'numeric'   => esc_html__( 'Numeric', 'mega-charity-pro' ),
            'default'   => esc_html__( 'Default(Older/Newer)', 'mega-charity-pro' ),
            'infinite'  => esc_html__( 'Infinite', 'mega-charity-pro' ),
        );

        $output = apply_filters( 'mega_charity_pro_pagination_options', $mega_charity_pro_pagination_options );

        return $output;
    }
endif;

if ( ! function_exists( 'mega_charity_pro_get_spinner_list' ) ) :
    /**
     * List of spinner icons options.
     * @return array List of all spinner icon options.
     */
    function mega_charity_pro_get_spinner_list() {
        $arr = array(
            'default'               => esc_html__( 'Default', 'mega-charity-pro' ),
            'spinner-wheel'         => esc_html__( 'Wheel', 'mega-charity-pro' ),
            'spinner-double-circle' => esc_html__( 'Double Circle', 'mega-charity-pro' ),
            'spinner-two-way'       => esc_html__( 'Two Way', 'mega-charity-pro' ),
            'spinner-umbrella'      => esc_html__( 'Umbrella', 'mega-charity-pro' ),
            'spinner-dots'          => esc_html__( 'Dots', 'mega-charity-pro' ),
            'spinner-one-way'       => esc_html__( 'One Way', 'mega-charity-pro' ),
            'spinner-fidget'        => esc_html__( 'Fidget', 'mega-charity-pro' ),
        );
        return apply_filters( 'mega_charity_pro_spinner_list', $arr );
    }
endif;

if ( ! function_exists( 'mega_charity_pro_switch_options' ) ) :
    /**
     * List of custom Switch Control options
     * @return array List of switch control options.
     */
    function mega_charity_pro_switch_options() {
        $arr = array(
            'on'        => esc_html__( 'Enable', 'mega-charity-pro' ),
            'off'       => esc_html__( 'Disable', 'mega-charity-pro' )
        );
        return apply_filters( 'mega_charity_pro_switch_options', $arr );
    }
endif;

if ( ! function_exists( 'mega_charity_pro_hide_options' ) ) :
    /**
     * List of custom Switch Control options
     * @return array List of switch control options.
     */
    function mega_charity_pro_hide_options() {
        $arr = array(
            'on'        => esc_html__( 'Yes', 'mega-charity-pro' ),
            'off'       => esc_html__( 'No', 'mega-charity-pro' )
        );
        return apply_filters( 'mega_charity_pro_hide_options', $arr );
    }
endif;

if ( ! function_exists( 'mega_charity_pro_sortable_sections' ) ) :
    /**
     * List of sections Control options
     * @return array List of Sections control options.
     */
    function mega_charity_pro_sortable_sections() {
        $sections = array(
            'slider'                => esc_html__( 'Slider', 'mega-charity-pro' ),
            'hero_banner'           => esc_html__( 'Hero Banner', 'mega-charity-pro' ),
            'service'               => esc_html__( 'Service', 'mega-charity-pro' ),
            'cta'                   => esc_html__( 'CTA', 'mega-charity-pro' ),
            'about'                 => esc_html__( 'About', 'mega-charity-pro' ),
            'counter'               => esc_html__( 'Counter', 'mega-charity-pro' ),
            'help_us'               => esc_html__( 'Help Us', 'mega-charity-pro' ),
            'pricing'               => esc_html__( 'Pricing', 'mega-charity-pro' ),
            'gallery'               => esc_html__( 'Gallery', 'mega-charity-pro' ),
            'stories'               => esc_html__( 'Stories', 'mega-charity-pro' ),
            'testimonial'           => esc_html__( 'Testimonial', 'mega-charity-pro' ),
            'team'                  => esc_html__( 'Team', 'mega-charity-pro' ),
            'latest_posts'          => esc_html__( 'Latest Post', 'mega-charity-pro' ),
            'contact'               => esc_html__( 'Contact Us', 'mega-charity-pro' ),
            'subscription'          => esc_html__( 'Subscription', 'mega-charity-pro' ),
            'blog'                  => esc_html__( 'Blog', 'mega-charity-pro' ),
            'video'                 => esc_html__( 'Video', 'mega-charity-pro' ),
            'medical_services'      => esc_html__( 'Medical Services', 'mega-charity-pro' ),
            'medical_features'      => esc_html__( 'Medical Features', 'mega-charity-pro' ),
            'reason'                => esc_html__( 'Medical Reason', 'mega-charity-pro' ),
            'medical_news'          => esc_html__( 'Medical News', 'mega-charity-pro' ),
            'masonry'               => esc_html__( 'Masonry', 'mega-charity-pro' ),
            'recent_products'       => esc_html__( 'Recent Products', 'mega-charity-pro' ),
            'featured_products'     => esc_html__( 'Featured Products', 'mega-charity-pro' ),
            'release'               => esc_html__( 'Release', 'mega-charity-pro' ),
            'event'                 => esc_html__( 'Event', 'mega-charity-pro' ),
        );
        return apply_filters( 'mega_charity_pro_sortable_sections', $sections );
    }
endif;

if ( ! function_exists( 'mega_charity_pro_blog_content_type' ) ) :
    /**
     * blog options
     * @return array site blog options
     */
    function mega_charity_pro_blog_content_type() {
        $mega_charity_pro_blog_content_type = array(
            'page'      => esc_html__( 'Page', 'mega-charity-pro' ),
            'post'      => esc_html__( 'Post', 'mega-charity-pro' ),
            'category'  => esc_html__( 'Category', 'mega-charity-pro' ),
            'recent'    => esc_html__( 'Recent', 'mega-charity-pro' ),
        );

        if ( class_exists( 'WP_Travel' ) ) {
            $mega_charity_pro_blog_content_type = array_merge( $mega_charity_pro_blog_content_type, array(
                'trip'          => esc_html__( 'Trip', 'mega-charity-pro' ),
                'trip-types'    => esc_html__( 'Trip Types', 'mega-charity-pro' ),
                'destination'   => esc_html__( 'Destination', 'mega-charity-pro' ),
                'activity'      => esc_html__( 'Activity', 'mega-charity-pro' ),
                ) );
        }

        $output = apply_filters( 'mega_charity_pro_blog_content_type', $mega_charity_pro_blog_content_type );


        return $output;
    }
endif;



if ( ! function_exists( 'mega_charity_pro_featured_content_type' ) ) :
    /**
     * featured Options
     * @return array site featured options
     */
    function mega_charity_pro_featured_content_type() {
        $mega_charity_pro_featured_content_type = array(
            'page'      => esc_html__( 'Page', 'mega-charity-pro' ),
            'post'      => esc_html__( 'Post', 'mega-charity-pro' ),
            'category'  => esc_html__( 'Category', 'mega-charity-pro' ),
        );

        if ( class_exists( 'WP_Travel' ) ) {
            $mega_charity_pro_featured_content_type = array_merge( $mega_charity_pro_featured_content_type, array(
                'trip'          => esc_html__( 'Trip', 'mega-charity-pro' ),
                'trip-types'    => esc_html__( 'Trip Types', 'mega-charity-pro' ),
                'destination'   => esc_html__( 'Destination', 'mega-charity-pro' ),
                'activity'      => esc_html__( 'Activity', 'mega-charity-pro' ),
                ) );
        }

        $output = apply_filters( 'mega_charity_pro_featured_content_type', $mega_charity_pro_featured_content_type );


        return $output;
    }
endif;

if ( ! function_exists( 'mega_charity_pro_traveler_choice_content_type' ) ) :
    /**
     * Destination Options
     * @return array site gallery options
     */
    function mega_charity_pro_traveler_choice_content_type() {
        $mega_charity_pro_traveler_choice_content_type = array(
            'page'      => esc_html__( 'Page', 'mega-charity-pro' ),
            'post'      => esc_html__( 'Post', 'mega-charity-pro' ),
            'category'  => esc_html__( 'Category', 'mega-charity-pro' ),
        );

        if ( class_exists( 'WP_Travel' ) ) {
            $mega_charity_pro_traveler_choice_content_type = array_merge( $mega_charity_pro_traveler_choice_content_type, array(
                'trip'          => esc_html__( 'Trip', 'mega-charity-pro' ),
                'trip-types'    => esc_html__( 'Trip Types', 'mega-charity-pro' ),
                'destination'   => esc_html__( 'Destination', 'mega-charity-pro' ),
                'activity'      => esc_html__( 'Activity', 'mega-charity-pro' ),
                ) );
        }

        $output = apply_filters( 'mega_charity_pro_traveler_choice_content_type', $mega_charity_pro_traveler_choice_content_type );


        return $output;
    }
endif;

if ( ! function_exists( 'mega_charity_pro_discover_places_content_type' ) ) :
    /**
     * Destination Options
     * @return array site gallery options
     */
    function mega_charity_pro_discover_places_content_type() {
        $mega_charity_pro_discover_places_content_type = array(
            'page'      => esc_html__( 'Page', 'mega-charity-pro' ),
            'post'      => esc_html__( 'Post', 'mega-charity-pro' ),
            'category'  => esc_html__( 'Category', 'mega-charity-pro' ),
        );

        if ( class_exists( 'WP_Travel' ) ) {
            $mega_charity_pro_discover_places_content_type = array_merge( $mega_charity_pro_discover_places_content_type, array(
                'trip'          => esc_html__( 'Trip', 'mega-charity-pro' ),
                'trip-types'    => esc_html__( 'Trip Types', 'mega-charity-pro' ),
                'destination'   => esc_html__( 'Destination', 'mega-charity-pro' ),
                'activity'      => esc_html__( 'Activity', 'mega-charity-pro' ),
                ) );
        }

        $output = apply_filters( 'mega_charity_pro_discover_places_content_type', $mega_charity_pro_discover_places_content_type );


        return $output;
    }
endif;

if ( ! function_exists( 'mega_charity_pro_heading_tags' ) ) :
    /**
     * Destination Options
     * @return array site gallery options
     */
    function mega_charity_pro_heading_tags() {
        
        $mega_charity_pro_heading_tags = array(
			'h1'	=> esc_html__('H1', 'mega-charity-pro'),
			'h2'	=> esc_html__('H2', 'mega-charity-pro'),
			'h3'	=> esc_html__('H3', 'mega-charity-pro'),
			'h4'	=> esc_html__('H4', 'mega-charity-pro'),
			'h5'	=> esc_html__('H5', 'mega-charity-pro'),
			'h6'	=> esc_html__('H6', 'mega-charity-pro'),
			'p'		=> esc_html__('Paragraph', 'mega-charity-pro'),
		);

        $output = apply_filters( 'mega_charity_pro_heading_tags', $mega_charity_pro_heading_tags );


        return $output;
    }
endif;


if ( ! function_exists( 'mega_charity_pro_popular_product_content_type' ) ) :
    /**
     * List of product_layout_similar_product options
     * @return array List of product_layout_similar_product options.
     */
    function mega_charity_pro_popular_product_content_type() {
    
        if ( class_exists( 'WooCommerce' ) ) {
                $arr = array(
                'product'           => esc_html__( 'Product', 'mega-charity-pro' ),
                'product_cat'       => esc_html__( 'Product Category', 'mega-charity-pro' ),
                'recent_product'    => esc_html__( 'Recent Product', 'mega-charity-pro' ),
            );
        }

        return apply_filters( 'mega_charity_pro_popular_product_content_type', $arr );
    }
endif;

if ( ! function_exists( 'mega_charity_pro_latest_product_content_type' ) ) :
    /**
     * List of product_layout_similar_product options
     * @return array List of product_layout_similar_product options.
     */
    function mega_charity_pro_latest_product_content_type() {
    
        if ( class_exists( 'WooCommerce' ) ) {
                $arr = array(
                'product'           => esc_html__( 'Product', 'mega-charity-pro' ),
                'product_cat'       => esc_html__( 'Product Category', 'mega-charity-pro' ),
                'recent_product'    => esc_html__( 'Recent Product', 'mega-charity-pro' ),
            );
        }

        return apply_filters( 'mega_charity_pro_latest_product_content_type', $arr );
    }
endif;

if ( ! function_exists( 'mega_charity_pro_featured_product_content_type' ) ) :
    /**
     * List of product_layout_similar_product options
     * @return array List of product_layout_similar_product options.
     */
    function mega_charity_pro_featured_product_content_type() {
        $arr = array(
            'page'      => esc_html__( 'Page', 'mega-charity-pro' ),
            'post'      => esc_html__( 'Post', 'mega-charity-pro' ),
            'category'  => esc_html__( 'Post Category', 'mega-charity-pro' ),
        );
    
        if ( class_exists( 'WooCommerce' ) ) {
            $arr = array_merge( $arr, array(
                'product'           => esc_html__( 'Product', 'mega-charity-pro' ),
                'product-category'   => esc_html__( 'Product Category', 'mega-charity-pro' ),
                ) );
        }

        return apply_filters( 'mega_charity_pro_featured_product_content_type', $arr );
    }
endif;


if ( ! function_exists( 'mega_charity_pro_event_content_type' ) ) :
    /**
     * Special Offer Options
     * @return array site event options
     */
    function mega_charity_pro_event_content_type() {
        $mega_charity_pro_event_content_type = array(
            'page'      => esc_html__( 'Page', 'mega-charity-pro' ),
            'post'      => esc_html__( 'Post', 'mega-charity-pro' ),
            'category'  => esc_html__( 'Category', 'mega-charity-pro' ),
        );

        if ( class_exists( 'TP_Education' ) ) {
            $mega_charity_pro_event_content_type = array_merge( $mega_charity_pro_event_content_type, array(
                'event'   => esc_html__( 'Event', 'mega-charity-pro' ),
                'event-category'   => esc_html__( 'Event Category', 'mega-charity-pro' ),
                ) );
        }

        $output = apply_filters( 'mega_charity_pro_event_content_type', $mega_charity_pro_event_content_type );


        return $output;
    }
endif;