<?php
/**
 * Blog section
 *
 * This is the template for the content of blog section
 *
 * @package Theme Palace
 * @subpackage Mega Charity Pro
 * @since Mega Charity Pro 1.0.0
 */
if ( ! function_exists( 'mega_charity_pro_add_blog_section' ) ) :
    /**
    * Add blog section
    *
    *@since Mega Charity Pro 1.0.0
    */
    function mega_charity_pro_add_blog_section() {
        $options = mega_charity_pro_get_theme_options();
        // Check if blog is enabled on frontpage
        $blog_enable = apply_filters( 'mega_charity_pro_section_status', true, 'blog_section_enable' );

        if ( true !== $blog_enable ) {
            return false;
        }
        // Get blog section details
        $section_details = array();
        $section_details = apply_filters( 'mega_charity_pro_filter_blog_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render blog section now.
        mega_charity_pro_render_blog_section( $section_details );
    }
endif;

if ( ! function_exists( 'mega_charity_pro_get_blog_section_details' ) ) :
    /**
    * blog section details.
    *
    * @since Mega Charity Pro 1.0.0
    * @param array $input blog section details.
    */
    function mega_charity_pro_get_blog_section_details( $input ) {
        $options = mega_charity_pro_get_theme_options();

        // Content type.
        $blog_content_type  = get_theme_mod( 'mega_charity_pro_theme_options_blog_content_type', 'category' );
        $blog_count = get_theme_mod( 'mega_charity_pro_theme_options_blog_count', 3 );
        $content = array();
        switch ( $blog_content_type ) {
            
            case 'page':
                $page_ids = array();
                $author = array();

                for ( $i = 1; $i <= $blog_count; $i++ ) {
                    if ( ! empty( $options['blog_content_page_' . $i] ) ) :
                        $page_ids[] = $options['blog_content_page_' . $i];
                    endif;
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $blog_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();
                $author = array();

                for ( $i = 1; $i <= $blog_count; $i++ ) {
                    if ( ! empty( $options['blog_content_post_' . $i] ) ) :
                        $post_ids[] = $options['blog_content_post_' . $i];
                    endif;
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $blog_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['blog_content_category'] ) ? $options['blog_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $blog_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;
            
            default:
            break;
        }

        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['title']     = get_the_title();
                $page_post['url']       = get_the_permalink();
                $page_post['excerpt']   = mega_charity_pro_trim_content( $options['blog_excerpt_length'] );
                $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'large' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-590x650.jpg';

                // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
        endif;
        wp_reset_postdata();
   
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// blog section content details.
add_filter( 'mega_charity_pro_filter_blog_section_details', 'mega_charity_pro_get_blog_section_details' );


if ( ! function_exists( 'mega_charity_pro_render_blog_section' ) ) :
  /**
   * Start blog section
   *
   * @return string blog content
   * @since Mega Charity Pro 1.0.0
   *
   */
   function mega_charity_pro_render_blog_section( $content_details = array() ) {
        $options = mega_charity_pro_get_theme_options();

        $class = ( $options['home_layout'] == 'sixth-design' || $options['home_layout'] == 'ninth-design') ? 'no-padding-top' : '';

        if ( empty( $content_details ) ) {
            return;
        } ?>
        
        <div id="latest-posts" class="page-section relative <?php echo esc_attr( $class ); ?>">
                <div class="wrapper">
                <?php if ( is_customize_preview()):
                mega_charity_pro_section_tooltip( 'latest-posts' );
                endif; ?>
                    <div class="section-header">
                    <?php if( !empty( $options['blog_title'] ) ): ?>
                        <h2 class="section-title"><?php echo esc_html( $options['blog_title'] ); ?></h2>
                    <?php endif;

                        if( !empty( $options['blog_description'] ) ):
                     ?>
                        <p class="subtitle"><?php echo esc_html( $options['blog_description'] ); ?></p>
                    <?php endif; ?>
                    </div><!-- .section-header -->

                    <div class="section-content col-3">
                        <div class="archive-blog-wrapper clear">
                            
                             <?php foreach ( $content_details as $content ) : ?>

                            <article class="hentry">
                                <div class="post-wrapper">
                                    <div class="featured-image" style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');">
                                        <a href="<?php echo esc_url( $content['url'] ); ?>" class="post-thumbnail-link"></a>
                                    </div><!-- .featured-image -->

                                    <div class="entry-container">
                                        <div class="entry-meta">
                                            <?php mega_charity_pro_posted_on( $content['id'] );
                                            echo mega_charity_pro_author_meta( $content['id'] ); ?>
                                        </div><!-- .entry-meta -->

                                        <header class="entry-header">
                                            <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                        </header>

                                        <div class="entry-content">
                                            <p><?php echo wp_kses_post( $content['excerpt'] ); ?></p>
                                        </div><!-- .entry-content -->
                                    </div><!-- .entry-container -->
                                </div><!-- .post-wrapper -->
                            </article>

                            <?php endforeach; ?>

                        </div><!-- .archive-blog-wrapper -->
                    </div><!-- .section-content -->
                </div><!-- .wrapper -->
            </div><!-- .recent -->

    <?php }
endif;