<?php
/**
 * Counter section
 *
 * This is the template for the content of counter section
 *
 * @package Theme Palace
 * @subpackage Mega Charity Pro
 * @since Mega Charity Pro 1.0.0
 */
if ( ! function_exists( 'mega_charity_pro_add_counter_section' ) ) :
    /**
    * Add counter section
    *
    *@since Mega Charity Pro 1.0.0
    */
    function mega_charity_pro_add_counter_section() {
        $options = mega_charity_pro_get_theme_options();
        // Check if counter is enabled on frontpage
        $counter_enable = apply_filters( 'mega_charity_pro_section_status', true, 'counter_section_enable' );

        if ( true !== $counter_enable ) {
            return false;
        }

        // Render counter section now.
        mega_charity_pro_render_counter_section();
    }
endif;

if ( ! function_exists( 'mega_charity_pro_render_counter_section' ) ) :
  /**
   * Start counter section
   *
   * @return string counter content
   * @since Mega Charity Pro 1.0.0
   *
   */
   function mega_charity_pro_render_counter_section() {
        $options = mega_charity_pro_get_theme_options();
        $counter_column = ! empty( $options['counter_column'] ) ? $options['counter_column'] : 'col-4';
      
        ?>
        <?php if( $options['home_layout'] == 'default-design-all' || $options['home_layout'] == 'default-design' || $options['home_layout'] == 'eight-design' || $options['home_layout'] == 'ninth-design' ): ?>
        <div id="counter" class="relative">
          <div class="wrapper">
            <?php if ( is_customize_preview()):
            mega_charity_pro_section_tooltip( 'counter' );
            endif; ?>
            <div class="section-content clear <?php echo esc_attr( $counter_column ); ?>">

              <?php for ( $i = 1; $i <= get_theme_mod( 'mega_charity_pro_theme_options_counter_count', 4 ); $i++) { 

                if ( ! empty( $options['counter_value_' . $i] ) && ! empty( $options['counter_label_' . $i] ) ) :
                 ?>
               <article>
                <header class="entry-header">
                  <h2 class="entry-title"><?php echo esc_html( $options['counter_value_' . $i] ); ?></h2>
                </header>
                <div class="entry-content">
                  <p><?php echo esc_html( $options['counter_label_' . $i] ); ?></p>
                </div>
              </article>

            <?php endif;

          } ?>
        </div><!-- .business-section-content -->
      </div><!-- .wrapper -->
    </div><!-- #counter -->
  <?php endif; ?>

  <?php if( in_array($options['home_layout'], array('fifth-design', 'tenth-design') ) ): ?>

    <div id="business-counter" class="relative page-section" style="background-image: url('<?php echo esc_url( $options['counter_image'] ); ?>');">
      <div class="overlay"></div>
      <div class="wrapper">
      <?php if ( is_customize_preview()):
            mega_charity_pro_section_tooltip( 'business-counter' );
            endif; ?>
        <div class="business-section-content clear <?php echo esc_attr( $counter_column ); ?>">

          <?php for ( $i = 1; $i <= get_theme_mod( 'mega_charity_pro_theme_options_counter_count', 4 ); $i++) { 
            $icon    = isset($options['counter_icon_'.$i]) ? $options['counter_icon_'.$i] : 'fa-user';
            ?>

            <article>
              <header class="entry-header">
                <?php if ( $icon !== '' ): ?>
                  <div class="counter-icon">
                    <i class="fa <?php echo esc_attr( $icon ) ; ?>"></i>
                  </div><!-- .counter-icon -->
                <?php endif; ?>

                <?php if( !empty( $options['counter_value_' . $i] ) && !empty( $options['counter_label_' . $i] ) ): ?>
                  <h3 class="counter-value"><?php echo esc_html( $options['counter_value_' . $i] ); ?></h3>
                  <div class="separator-line"></div>
                  <h2 class="entry-title"><?php echo esc_html( $options['counter_label_' . $i] ); ?></h2>
                <?php endif; ?>
              </header>
            </article>

            <?php } ?>

          </div><!-- .business-section-content -->
        </div><!-- .wrapper -->
      </div><!-- #business-counter -->

    <?php endif; ?>
            
    <?php }
endif;