<?php
/**
 * CTA section
 *
 * This is the template for the content of cta section
 *
 * @package Theme Palace
 * @subpackage Mega Charity Pro
 * @since Mega Charity Pro 1.0.0
 */
if ( ! function_exists( 'mega_charity_pro_add_cta_section' ) ) :
    /**
    * Add cta section
    *
    *@since Mega Charity Pro 1.0.0
    */
    function mega_charity_pro_add_cta_section() {
    	$options = mega_charity_pro_get_theme_options();
        // Check if cta is enabled on frontpage
        $cta_enable = apply_filters( 'mega_charity_pro_section_status', true, 'cta_section_enable' );

        if ( true !== $cta_enable ) {
            return false;
        }
        // Get cta section details
        $section_details = array();
        $section_details = apply_filters( 'mega_charity_pro_filter_cta_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render cta section now.
        mega_charity_pro_render_cta_section( $section_details );
    }
endif;

if ( ! function_exists( 'mega_charity_pro_get_cta_section_details' ) ) :
    /**
    * cta section details.
    *
    * @since Mega Charity Pro 1.0.0
    * @param array $input cta section details.
    */
    function mega_charity_pro_get_cta_section_details( $input ) {
        $options = mega_charity_pro_get_theme_options();

        // Content type.
        $cta_content_type  = get_theme_mod( 'mega_charity_pro_theme_options_cta_content_type', 'page' );
        
        $content = array();
        switch ( $cta_content_type ) {

            case 'page':
                $page_id = ! empty( $options['cta_content_page'] ) ? $options['cta_content_page'] : '';
                $args = array(
                    'post_type'         => 'page',
                    'page_id'           => $page_id,
                    'posts_per_page'    => 1,
                    );                    
            break;

            case 'post':
                $post_id = ! empty( $options['cta_content_post'] ) ? $options['cta_content_post'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'p'                 => $post_id,
                    'posts_per_page'    => 1,
                    );
            break;

            default:
            break;
        }

            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['title']     = get_the_title();
                    $page_post['url']       = get_the_permalink();
                    $page_post['excerpt']   = mega_charity_pro_trim_content( $options['cta_excerpt_length'] );

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// cta section content details.
add_filter( 'mega_charity_pro_filter_cta_section_details', 'mega_charity_pro_get_cta_section_details' );


if ( ! function_exists( 'mega_charity_pro_render_cta_section' ) ) :
  /**
   * Start cta section
   *
   * @return string cta content
   * @since Mega Charity Pro 1.0.0
   *
   */
   function mega_charity_pro_render_cta_section( $content_details = array() ) {
        $options = mega_charity_pro_get_theme_options();
        $image = ( ! empty( $options['cta_image'] ) ) ? $options['cta_image'] : '' ;
        $cta_subtitle = ( ! empty( $options['cta_subtitle'] ) ) ? $options['cta_subtitle'] : '' ;

        if ( empty( $content_details ) ) {
            return;
        } ?>

        <?php foreach ( $content_details as $content ) :  ?>

            <div id="cta" class="page-section" style="background-image:url('<?php echo esc_url( $image ); ?>')">
                <div class="overlay"></div>
                <div class="wrapper">
                    <?php if ( is_customize_preview()):
                    mega_charity_pro_section_tooltip( 'cta' );
                    endif; ?>
                    <div class="cta-wrapper">
                        <div class="section-header">
                        <?php if( !empty( $cta_subtitle ) ): ?>
                            <p class="section-subtitle"><?php echo esc_html( $cta_subtitle ); ?></p>
                        <?php endif;

                        if( !empty( $content['title'] ) ): ?>
                            <h2 class="section-title"><?php echo esc_html( $content['title'] ); ?></h2>
                        <?php endif; ?>
                        </div>

                        <div class="section-content">
                        <?php if( !empty( $content['excerpt'] ) ): ?>
                            <div class="entry-content">
                                <p><?php echo esc_html( $content['excerpt'] ); ?></p>
                            </div><!-- .entry-content -->
                        <?php endif; ?>

                            <div class="read-more">
                            <?php if( !empty( $options['cta_button'] ) && !empty( $content['url'] ) ): ?>
                                <a href="<?php echo esc_url( $content['url'] ); ?>" class="btn first-btn"><?php echo esc_html( $options['cta_button'] ); ?></a>
                            <?php endif;
                            if( !empty( $options['cta_alt_button_link'] ) && !empty( $options['cta_alt_button'] ) ):
                             ?>
                                <a href="<?php echo esc_url( $options['cta_alt_button_link'] ); ?>" class="btn second-btn"><?php echo esc_html( $options['cta_alt_button'] ); ?></a>
                            <?php endif; ?>
                            </div><!-- .read-more -->
                        </div><!-- .section-content -->
                    </div><!-- .cta-wrapper -->
                </div><!-- .wrapper -->
            </div><!-- #cta -->

        <?php endforeach; ?>

<?php    }
endif;