<?php
/**
 * Event section
 *
 * This is the template for the content of event section
 *
 * @package Theme Palace
 * @subpackage Mega Charity Pro
 * @since Mega Charity Pro 1.0.0
 */
if ( ! function_exists( 'mega_charity_pro_add_event_section' ) ) :
    /**
    * Add event section
    *
    *@since Mega Charity Pro 1.0.0
    */
    function mega_charity_pro_add_event_section() {
    	$options = mega_charity_pro_get_theme_options();
        // Check if event is enabled on frontpage
        $event_enable = apply_filters( 'mega_charity_pro_section_status', true, 'event_section_enable' );

        if ( true !== $event_enable ) {
            return false;
        }
        // Get event section details
        $section_details = array();
        $section_details = apply_filters( 'mega_charity_pro_filter_event_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render event section now.
        mega_charity_pro_render_event_section( $section_details );
    }
endif;

if ( ! function_exists( 'mega_charity_pro_get_event_section_details' ) ) :
    /**
    * event section details.
    *
    * @since Mega Charity Pro 1.0.0
    * @param array $input event section details.
    */
    function mega_charity_pro_get_event_section_details( $input ) {
        $options = mega_charity_pro_get_theme_options();

        // Content type.
        $event_content_type  = get_theme_mod( 'mega_charity_pro_theme_options_event_content_type', 'category' );
        $event_count = get_theme_mod( 'mega_charity_pro_theme_options_event_count', 3 );

        $content = array();
        switch ( $event_content_type ) {
        	
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $event_count; $i++ ) {
                    if ( ! empty( $options['event_content_page_' . $i] ) )
                        $page_ids[] = $options['event_content_page_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $event_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $event_count; $i++ ) {
                    if ( ! empty( $options['event_content_post_' . $i] ) )
                        $post_ids[] = $options['event_content_post_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $event_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['event_content_category'] ) ? $options['event_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $event_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'event':
                $page_ids = array();

                for ( $i = 1; $i <= $event_count; $i++ ) {
                    if ( ! empty( $options['event_content_event_' . $i] ) )
                        $page_ids[] = $options['event_content_event_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'tp-event',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $event_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'event-category':
                $cat_id = ! empty( $options['event_content_event_category'] ) ? $options['event_content_event_category'] : '';
                $args = array(
                    'post_type'      => 'tp-event',
                    'tax_query' => array(
                        array(
                            'taxonomy' => 'tp-event-category',
                            'field'    => 'id',
                            'terms'    => $cat_id,
                        ),
                    ),
                    'posts_per_page'  => absint( $event_count ),
                    );                    
            break;

            default:
            break;
        }

        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['title']     = get_the_title();
                $page_post['url']       = get_the_permalink();
                $page_post['excerpt']   = mega_charity_pro_trim_content( 5 );
                $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'thumbnail' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-150x150.jpg';

                // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
        endif;
        wp_reset_postdata();
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// event section content details.
add_filter( 'mega_charity_pro_filter_event_section_details', 'mega_charity_pro_get_event_section_details' );


if ( ! function_exists( 'mega_charity_pro_render_event_section' ) ) :
  /**
   * Start event section
   *
   * @return string event content
   * @since Mega Charity Pro 1.0.0
   *
   */
   function mega_charity_pro_render_event_section( $content_details = array() ) {
        $options = mega_charity_pro_get_theme_options();
        $event_content_type  = get_theme_mod( 'mega_charity_pro_theme_options_event_content_type' );
        
        if ( empty( $content_details ) ) {
            return;
        } ?>

        <div id="upcoming-events" class="relative">
                <div class="wrapper">
                <?php if ( is_customize_preview()):
                mega_charity_pro_section_tooltip( 'upcoming-events' );
                endif; ?>
                    <div class="section-header">
                    <?php if( !empty( $options['event_subtitle'] ) ): ?>
                        <p class="section-subtitle"><?php echo esc_html( $options['event_subtitle'] ); ?></p>
                    <?php endif;
                    if( !empty( $options['event_title'] ) ):
                     ?>
                        <h2 class="section-title"><?php echo esc_html( $options['event_title'] ); ?></h2>
                    <?php endif; ?>
                    </div><!-- .section-header -->

                    <div class="section-content">
                        
                        <?php foreach ( $content_details as $content ) : 
                        if ( in_array( $event_content_type, array( 'event', 'event-category' ) ) && class_exists( 'TP_Education' ) ) :
                            $event_date = get_tp_event_date( $content['id'] );
                            $event_location = get_tp_event_location( $content['id'] );
                            $event_time = get_tp_event_start_time( $content['id'] );
                        endif;
                    ?>

                        <article>

                           <?php if ( in_array( $event_content_type, array( 'event', 'event-category' ) ) && ! empty( $event_date ) ) : ?>
                                <h4 class="event-date"><?php tp_event_date( $content['id'] ); ?></h4>
                            <?php endif; ?>

                            <header class="entry-header">
                                <img src="<?php echo esc_url( $content['image'] ); ?>" alt="event-01">
                                <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                <?php if ( in_array( $event_content_type, array( 'event', 'event-category' ) ) && ! empty( $event_location ) ) : ?>
                                    <p class="location"><?php tp_event_location( $content['id'] ); ?></p>
                                <?php else : ?>
                                    <p class="location"><?php echo esc_html( $content['excerpt'] ); ?></p>
                                <?php endif; ?>
                            </header>

                            <?php if ( in_array( $event_content_type, array( 'event', 'event-category' ) ) && ! empty( $event_time ) ) : ?>
                            <span class="event-time">
                                <svg  viewBox="0 0 512 512">
                                    <path d="M347.216,301.211l-71.387-53.54V138.609c0-10.966-8.864-19.83-19.83-19.83c-10.966,0-19.83,8.864-19.83,19.83v118.978
                                        c0,6.246,2.935,12.136,7.932,15.864l79.318,59.489c3.569,2.677,7.734,3.966,11.878,3.966c6.048,0,11.997-2.717,15.884-7.952
                                        C357.766,320.208,355.981,307.775,347.216,301.211z"/>
                                    <path d="M256,0C114.833,0,0,114.833,0,256s114.833,256,256,256s256-114.833,256-256S397.167,0,256,0z M256,472.341
                                        c-119.275,0-216.341-97.066-216.341-216.341S136.725,39.659,256,39.659c119.295,0,216.341,97.066,216.341,216.341
                                        S375.275,472.341,256,472.341z"/>
                                </svg>
                                <?php tp_event_start_time( $content['id'] ); ?>
                            </span>
                            <?php endif;

                            if( !empty( $options['event_readmore'] ) ): ?>
                            <span class="buy-ticket"><a href="<?php echo esc_url( $content['url'] ); ?>" class="btn"><?php echo esc_html( $options['event_readmore'] ); ?></a></span>
                        <?php endif; ?>
                        
                        </article>

                         <?php endforeach; ?>

                    </div><!-- .section-content -->

                    <?php if ( ! empty( $options['event_btn_title'] ) && ! empty( $options['event_btn_link'] ) ) : ?>
                    <div class="read-more">
                        <a href="<?php echo esc_url( $options['event_btn_link'] ); ?>" class="btn btn-fill"><?php echo esc_html( $options['event_btn_title'] ); ?></a>
                    </div><!-- .read-more -->
                <?php endif; ?>
                </div><!-- .wrapper -->
            </div><!-- #upcoming-events -->

    <?php }
endif;