<?php
/**
 * Medical Features section
 *
 * This is the template for the content of medical_features section
 *
 * @package Theme Palace
 * @subpackage Mega Charity Pro
 * @since Mega Charity Pro 1.0.0
 */
if ( ! function_exists( 'mega_charity_pro_add_medical_features_section' ) ) :
    /**
    * Add medical_features section
    *
    *@since Mega Charity Pro 1.0.0
    */
    function mega_charity_pro_add_medical_features_section() {
        $options = mega_charity_pro_get_theme_options();
        // Check if medical_features is enabled on frontpage
        $medical_features_enable = apply_filters( 'mega_charity_pro_section_status', true, 'medical_features_section_enable' );

        if ( true !== $medical_features_enable ) {
            return false;
        }
        // Get medical_features section details
        $section_details = array();
        $section_details = apply_filters( 'mega_charity_pro_filter_medical_features_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render medical_features section now.
        mega_charity_pro_render_medical_features_section( $section_details );
    }
endif;

if ( ! function_exists( 'mega_charity_pro_get_medical_features_section_details' ) ) :
    /**
    * medical_features section details.
    *
    * @since Mega Charity Pro 1.0.0
    * @param array $input medical_features section details.
    */
    function mega_charity_pro_get_medical_features_section_details( $input ) {
        $options = mega_charity_pro_get_theme_options();

        // Content type.
        $medical_features_content_type  = get_theme_mod( 'mega_charity_pro_theme_options_medical_features_content_type', 'category' );
        $medical_features_count  = get_theme_mod( 'mega_charity_pro_theme_options_medical_features_count', 3 );
        
        $content = array();
        switch ( $medical_features_content_type ) {
            
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $medical_features_count; $i++ ) {
                    if ( ! empty( $options['medical_features_content_page_' . $i] ) )
                        $page_ids[] = $options['medical_features_content_page_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => $medical_features_count,
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $medical_features_count; $i++ ) {
                    if ( ! empty( $options['medical_features_content_post_' . $i] ) )
                        $post_ids[] = $options['medical_features_content_post_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => $medical_features_count,
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['medical_features_content_category'] ) ? $options['medical_features_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => $medical_features_count,
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            default:
            break;
        }

        // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['title']     = get_the_title();
                    $page_post['url']       = get_the_permalink();
                    $page_post['excerpt']   = mega_charity_pro_trim_content( $options['medical_features_excerpt_length'] );

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();

            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// medical_features section content details.
add_filter( 'mega_charity_pro_filter_medical_features_section_details', 'mega_charity_pro_get_medical_features_section_details' );


if ( ! function_exists( 'mega_charity_pro_render_medical_features_section' ) ) :
  /**
   * Start medical_features section
   *
   * @return string medical_features content
   * @since Mega Charity Pro 1.0.0
   *
   */
   function mega_charity_pro_render_medical_features_section( $content_details = array() ) {
        $options = mega_charity_pro_get_theme_options();
        
        $column = $options['medical_features_column_layout'] ? $options['medical_features_column_layout'] : 'col-3';

        if ( empty( $content_details ) ) {
            return;
        } 
        ?> 

        <div id="medical-features" class="relative page-section">
            <div class="wrapper">
            <?php if ( is_customize_preview()):
                mega_charity_pro_section_tooltip( 'medical-features' );
                endif; ?>
                <?php if( !empty( $options['medical_features_title'] ) ): ?>
                    <div class="section-header">
                        <h2 class="section-title"><?php echo esc_html( $options['medical_features_title'] ); ?></h2>
                    </div>
                <?php endif; ?>

                <div class="section-content <?php echo esc_attr( $column ); ?> clear">

                    <?php $i = 1; foreach ( $content_details as $content ) : ?>

                    <article>
                        <div class="medical-feature-item">
                            <div class="feature-icon">
                                <a href="<?php echo esc_url( $content['url'] ); ?>">
                                    <i class="fa <?php echo ! empty( $options['medical_features_content_icon_' . $i] ) ? esc_attr( $options['medical_features_content_icon_' . $i] ) : 'fa-user-md'; ?>"></i>
                                </a>
                            </div><!-- .feature-icon -->

                            <div class="entry-container">
                                <header class="entry-header">
                                    <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                </header>

                                <div class="entry-content">
                                    <p><?php echo esc_html( $content['excerpt'] ); ?></p>
                                </div><!-- .entry-content -->
                            </div><!-- .entry-container -->
                        </div><!-- .medical-feature-item -->
                    </article>

                    <?php $i++; endforeach; ?>

                </div><!-- .section-content -->
            </div><!-- .wrapper -->
        </div><!-- #medical-features -->

    <?php }
endif;