<?php
/**
 * Medical news section
 *
 * This is the template for the content of medical_news section
 *
 * @package Theme Palace
 * @subpackage Mega Charity Pro
 * @since Mega Charity Pro 1.0.0
 */
if ( ! function_exists( 'mega_charity_pro_add_medical_news_section' ) ) :
    /**
    * Add medical_news section
    *
    *@since Mega Charity Pro 1.0.0
    */
    function mega_charity_pro_add_medical_news_section() {
        $options = mega_charity_pro_get_theme_options();
        // Check if medical_news is enabled on frontpage
        $medical_news_enable = apply_filters( 'mega_charity_pro_section_status', true, 'medical_news_section_enable' );

        if ( true !== $medical_news_enable ) {
            return false;
        }
        // Get medical_news section details
        $section_details = array();
        $section_details = apply_filters( 'mega_charity_pro_filter_medical_news_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render medical_news section now.
        mega_charity_pro_render_medical_news_section( $section_details );
    }
endif;

if ( ! function_exists( 'mega_charity_pro_get_medical_news_section_details' ) ) :
    /**
    * medical_news section details.
    *
    * @since Mega Charity Pro 1.0.0
    * @param array $input medical_news section details.
    */
    function mega_charity_pro_get_medical_news_section_details( $input ) {
        $options = mega_charity_pro_get_theme_options();

        // Content type.
        $medical_news_content_type  = get_theme_mod( 'mega_charity_pro_theme_options_medical_news_content_type', 'category' );
        $medical_news_count = get_theme_mod( 'mega_charity_pro_theme_options_medical_news_count', 3 );
        $content = array();
        switch ( $medical_news_content_type ) {
            
            case 'page':
                $page_ids = array();
                $author = array();

                for ( $i = 1; $i <= $medical_news_count; $i++ ) {
                    if ( ! empty( $options['medical_news_content_page_' . $i] ) ) :
                        $page_ids[] = $options['medical_news_content_page_' . $i];
                    endif;
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $medical_news_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();
                $author = array();

                for ( $i = 1; $i <= $medical_news_count; $i++ ) {
                    if ( ! empty( $options['medical_news_content_post_' . $i] ) ) :
                        $post_ids[] = $options['medical_news_content_post_' . $i];
                    endif;
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $medical_news_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['medical_news_content_category'] ) ? $options['medical_news_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $medical_news_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;
            
            default:
            break;
        }

        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['title']     = get_the_title();
                $page_post['url']       = get_the_permalink();
                $page_post['excerpt']   = mega_charity_pro_trim_content( $options['medical_news_excerpt_length'] );
                $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'large' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-590x650.jpg';

                // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
        endif;
        wp_reset_postdata();
   
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// medical_news section content details.
add_filter( 'mega_charity_pro_filter_medical_news_section_details', 'mega_charity_pro_get_medical_news_section_details' );


if ( ! function_exists( 'mega_charity_pro_render_medical_news_section' ) ) :
  /**
   * Start medical_news section
   *
   * @return string medical_news content
   * @since Mega Charity Pro 1.0.0
   *
   */
   function mega_charity_pro_render_medical_news_section( $content_details = array() ) {
        $options = mega_charity_pro_get_theme_options();

        if ( empty( $content_details ) ) {
            return;
        } ?>
        
       <div id="medical-news" class="relative page-section">
                <div class="wrapper">
                <?php if ( is_customize_preview()):
                mega_charity_pro_section_tooltip( 'medical-news' );
                endif; ?>
                <?php if( !empty( $options['medical_news_title'] ) ): ?>
                    <div class="section-header">
                        <h2 class="section-title"><?php echo esc_html( $options['medical_news_title'] ); ?></h2>
                    </div><!-- .section-header -->
                <?php endif; ?>

                    <div class="section-content col-3 clear">
                        
                         <?php foreach ( $content_details as $content ) : ?>

                        <article>
                            <div class="medical-news-item">
                                <div class="featured-image" style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');">
                                    <a href="<?php echo esc_url( $content['url'] ); ?>" class="post-thumbnail-link"></a>
                                    <div class="date"><?php mega_charity_pro_posted_on( $content['id'] ); ?></div>
                                </div><!-- .featured-image -->

                                <div class="entry-container">
                                    <header class="entry-header">
                                        <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                    </header>

                                    <div class="entry-content">
                                        <p><?php echo wp_kses_post( $content['excerpt'] ); ?></p>
                                    </div><!-- .entry-content -->

                                    <?php if( !empty( $options['medical_news_btn'] ) ): ?>
                                    <div class="post-read-more">
                                        <a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $options['medical_news_btn'] ); ?></a>
                                    </div><!-- .post-read-more -->
                                <?php endif; ?>
                                </div><!-- .entry-container -->
                            </div><!-- .medical-news-item -->
                        </article>

                    <?php endforeach; ?>

                    </div><!-- .section-content -->
                </div><!-- .wrapper -->
            </div><!-- #medical-news -->

    <?php }
endif;