<?php
/**
 * Reason section
 *
 * This is the template for the content of about section
 *
 * @package Theme Palace
 * @subpackage mega_charity Pro
 * @since mega_charity Pro 1.0.0
 */
if ( ! function_exists( 'mega_charity_pro_add_reason_section' ) ) :
    /**
    * Add about section
    *
    *@since mega_charity Pro 1.0.0
    */
    function mega_charity_pro_add_reason_section() {
    	$options = mega_charity_pro_get_theme_options();
        // Check if about is enabled on frontpage
        $reason_enable = apply_filters( 'mega_charity_pro_section_status', true, 'reason_section_enable' );

        if ( true !== $reason_enable ) {
            return false;
        }
        // Get about section details
        $section_details = array();
        $section_details = apply_filters( 'mega_charity_pro_filter_reason_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        mega_charity_pro_render_reason_section( $section_details );
    }
endif;

if ( ! function_exists( 'mega_charity_pro_get_reason_section_details' ) ) :
    /**
    * about section details.
    *
    * @since mega_charity Pro 1.0.0
    * @param array $input about section details.
    */
    function mega_charity_pro_get_reason_section_details( $input ) {
        $options = mega_charity_pro_get_theme_options();

        // Content type.
        $reason_content_type  = get_theme_mod( 'mega_charity_pro_theme_options_reason_content_type', 'post' );
        $content = array();
        switch ( $reason_content_type ) {
            
            case 'page':
                $page_id = ! empty( $options['reason_content_page'] ) ? $options['reason_content_page'] : '';
                $args = array(
                    'post_type'         => 'page',
                    'page_id'           => $page_id,
                    'posts_per_page'    => 1,
                    );                    
            break;

            case 'post':
                $post_id = ! empty( $options['reason_content_post'] ) ? $options['reason_content_post'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'p'                 => $post_id,
                    'posts_per_page'    => 1,
                    'ignore_sticky_posts' => true,
                    );
            break;

            default:
            break;
        }

            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['title']     = get_the_title();
                    $page_post['url']       = get_the_permalink();
                    $page_post['excerpt']   = mega_charity_pro_trim_content( $options['about_excerpt_length'] );
                    $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'large' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-590x650.jpg';

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// about section content details.
add_filter( 'mega_charity_pro_filter_reason_section_details', 'mega_charity_pro_get_reason_section_details' );


if ( ! function_exists( 'mega_charity_pro_render_reason_section' ) ) :
  /**
   * Start about section
   *
   * @return string about content
   * @since mega_charity Pro 1.0.0
   *
   */
   function mega_charity_pro_render_reason_section( $content_details = array() ) {
        $options = mega_charity_pro_get_theme_options();

        $content = $content_details[0];
        if ( empty( $content_details ) ) {
            return;
        }  ?>
        
        <div id="medical-reasons" class="relative page-section">
                <div class="wrapper">
                    <article class="has-post-thumbnail">
                    <?php if(!empty($content['image'])): ?>
                        <div class="featured-image" style="background-image: url('<?php echo esc_url($content['image']); ?>');">
                            <a href="<?php echo esc_url( $content['url'] ) ; ?>" class="post-thumbnail-link"></a>
                        </div><!-- .featured-image -->
                    <?php endif; ?>
                        <div class="entry-container">
                    <?php if ( is_customize_preview()):
                    mega_charity_pro_section_tooltip( 'medical-reasons' );
                    endif; ?>
                        <?php if( !empty( $content['title'] ) ): ?>
                            <header class="entry-header">
                                <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ) ; ?>"><?php echo esc_html( $content['title'] ) ; ?></a></h2>
                            </header>
                        <?php endif; 
                        if( !empty( $content['excerpt'] ) ):
                        ?>

                            <div class="entry-content">
                                <p><?php echo wp_kses_post( $content['excerpt'] ) ; ?></p>
                            </div><!-- .entry-content -->
                        <?php endif; ?>

                            <ul>
                                <?php 
                                $reason_list = explode("|", $options['reason_list']);
                                ?>
                                <?php foreach($reason_list as $list): 
                                if(empty($list)) continue;
                                echo '<li>'.esc_html($list).'</li>';
                                endforeach;
                                ?>
                            </ul>
                        </div><!-- .entry-container -->
                    </article>
                </div>
            </div><!-- #medical-reasons -->

    <?php }
endif;

