<?php
/**
 * Medical Services section
 *
 * This is the template for the content of medical_services section
 *
 * @package Theme Palace
 * @subpackage Mega Charity Pro
 * @since Mega Charity Pro 1.0.0
 */
if ( ! function_exists( 'mega_charity_pro_add_medical_services_section' ) ) :
    /**
    * Add medical_services section
    *
    *@since Mega Charity Pro 1.0.0
    */
    function mega_charity_pro_add_medical_services_section() {
    	$options = mega_charity_pro_get_theme_options();
        // Check if medical_services is enabled on frontpage
        $medical_services_enable = apply_filters( 'mega_charity_pro_section_status', true, 'medical_services_section_enable' );

        if ( true !== $medical_services_enable ) {
            return false;
        }
        // Get medical_services section details
        $section_details = array();
        $section_details = apply_filters( 'mega_charity_pro_filter_medical_services_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render medical_services section now.
        mega_charity_pro_render_medical_services_section( $section_details );
    }
endif;

if ( ! function_exists( 'mega_charity_pro_get_medical_services_section_details' ) ) :
    /**
    * medical_services section details.
    *
    * @since Mega Charity Pro 1.0.0
    * @param array $input medical_services section details.
    */
    function mega_charity_pro_get_medical_services_section_details( $input ) {
        $options = mega_charity_pro_get_theme_options();

        // Content type.
        $medical_services_content_type  = get_theme_mod( 'mega_charity_pro_theme_options_medical_services_content_type', 'category' );
        $medical_services_count = get_theme_mod( 'mega_charity_pro_theme_options_medical_services_count', 3 );
        
        $content = array();
        switch ( $medical_services_content_type ) {
        	
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $medical_services_count; $i++ ) {
                    if ( ! empty( $options['medical_services_content_page_' . $i] ) )
                        $page_ids[] = $options['medical_services_content_page_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $medical_services_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $medical_services_count; $i++ ) {
                    if ( ! empty( $options['medical_services_content_post_' . $i] ) )
                        $post_ids[] = $options['medical_services_content_post_' . $i];
                }
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $medical_services_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['medical_services_content_category'] ) ? $options['medical_services_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $medical_services_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            default:
            break;
        }


            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['id']        = get_the_id();
                    $page_post['title']     = get_the_title();
                    $page_post['url']       = get_the_permalink();
                    $page_post['image']  	= has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'full' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-590x650.jpg';

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// medical_services section content details.
add_filter( 'mega_charity_pro_filter_medical_services_section_details', 'mega_charity_pro_get_medical_services_section_details' );


if ( ! function_exists( 'mega_charity_pro_render_medical_services_section' ) ) :
  /**
   * Start medical_services section
   *
   * @return string medical_services content
   * @since Mega Charity Pro 1.0.0
   *
   */
   function mega_charity_pro_render_medical_services_section( $content_details = array() ) {
        $options = mega_charity_pro_get_theme_options();

        $col_class = !empty( $options['medical_services_column_layout'] ) ? $options['medical_services_column_layout'] : 'col-3';

        if ( empty( $content_details ) ) {
            return;
        } ?>

         <div id="medical-services" class="relative page-section">
                <div class="wrapper">

                    <?php if ( is_customize_preview()):
                    mega_charity_pro_section_tooltip( 'medical-services' );
                    endif; ?>
                
                    <div class="section-content <?php echo esc_attr( $col_class ); ?> clear">
                        
                        <?php foreach ( $content_details as $content ) : ?>

                        <article>
                            <div class="medical-service-item">
                                <div class="inner-box">
                                    <div class="featured-image">
                                        <a href="<?php echo esc_url( $content['url'] ); ?>"><img src="<?php echo esc_url( $content['image'] ); ?>" alt="medical-service-01"></a>
                                    </div><!-- .featured-image -->

                                    <header class="entry-header">
                                        <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                    </header><!-- .entry-header -->
                                </div><!-- .inner-box -->
                            </div><!-- .medical-service-item -->
                        </article>

                        <?php endforeach; ?>

                    </div><!-- .section-content -->
                </div><!-- .wrapper -->
            </div><!-- #medical-services -->

        <?php }
endif;