<?php
/**
 * Pricing section
 *
 * This is the template for the content of pricing section
 *
 * @package Theme Palace
 * @subpackage Mega Charity Pro
 * @since Mega Charity Pro 1.0.0
 */
if ( ! function_exists( 'mega_charity_pro_add_pricing_section' ) ) :
    /**
    * Add pricing section
    *
    *@since Mega Charity Pro 1.0.0
    */
    function mega_charity_pro_add_pricing_section() {
    	$options = mega_charity_pro_get_theme_options();
        // Check if pricing is enabled on frontpage
        $pricing_enable = apply_filters( 'mega_charity_pro_section_status', true, 'pricing_section_enable' );

        if ( true !== $pricing_enable ) {
            return false;
        }
        // Get pricing section details
        $section_details = array();
        $section_details = apply_filters( 'mega_charity_pro_filter_pricing_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render pricing section now.
        mega_charity_pro_render_pricing_section( $section_details );
    }
endif;

if ( ! function_exists( 'mega_charity_pro_get_pricing_section_details' ) ) :
    /**
    * pricing section details.
    *
    * @since Mega Charity Pro 1.0.0
    * @param array $input pricing section details.
    */
    function mega_charity_pro_get_pricing_section_details( $input ) {
        $options = mega_charity_pro_get_theme_options();

        // Content type.
        $pricing_content_type  = get_theme_mod( 'mega_charity_pro_theme_options_pricing_content_type', 'page' );
        
        $content = array();
        switch ( $pricing_content_type ) {
            
            case 'page':
                $page_id = ! empty( $options['pricing_content_page'] ) ? $options['pricing_content_page'] : '';
                $args = array(
                    'post_type'         => 'page',
                    'page_id'           => $page_id,
                    'posts_per_page'    => 1,
                    );                    
            break;

            case 'post':
                $post_id = ! empty( $options['pricing_content_post'] ) ? $options['pricing_content_post'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'p'                 => $post_id,
                    'posts_per_page'    => 1,
                    );
            break;

            default:
            break;
        }
            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['title']     = get_the_title();
                    $page_post['url']       = get_the_permalink();
                    $page_post['excerpt']   = mega_charity_pro_trim_content( $options['pricing_excerpt_length'] );

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// pricing section content details.
add_filter( 'mega_charity_pro_filter_pricing_section_details', 'mega_charity_pro_get_pricing_section_details' );


if ( ! function_exists( 'mega_charity_pro_render_pricing_section' ) ) :
  /**
   * Start pricing section
   *
   * @return string pricing content
   * @since Mega Charity Pro 1.0.0
   *
   */
   function mega_charity_pro_render_pricing_section( $content_details = array() ) {
        $options = mega_charity_pro_get_theme_options();
        $image = ( ! empty( $options['pricing_image'] ) ) ? $options['pricing_image'] : '' ;

        if ( empty( $content_details ) ) {
            return;
        } ?>

        <div id="pricing" class="page-section relative col-2" style="background-image:url('<?php echo esc_url( $image ); ?>')">   
            <div class="overlay"></div>
            <div class="wrapper">
             <?php if ( is_customize_preview()):
            mega_charity_pro_section_tooltip( 'pricing' );
            endif; ?>

                <?php foreach ( $content_details as $content ) :  ?>

                    <article class="hentry">
                        <div class="entry-container">

                            <?php if( !empty( $content['title'] ) ): ?>

                                <div class="section-header">
                                    <h2 class="section-title"><?php echo esc_html( $content['title'] ); ?></span></h2>
                                </div><!-- .section-header -->
                                <?php 
                                endif;
                                if( !empty( $content['excerpt'] ) ): ?>
                                <div class="entry-content">
                                    <p><?php echo esc_html( $content['excerpt'] ); ?></p> 
                                </div><!-- .entry-content -->
                            <?php endif;
                            if( !empty( $content['url'] ) && !empty( $options['pricing_button'] ) ):
                                ?>

                            <div class="read-more">
                                <a href="<?php echo esc_url( $content['url'] ); ?>" class="btn"><?php echo esc_html( $options['pricing_button'] ); ?></a>
                            </div><!-- .read-more -->
                        <?php endif; ?>
                    </div><!-- .entry-container -->
                </article>

            <?php endforeach; ?>


            <article class="hentry">

                <?php for( $i=1; $i<=2; $i++ ): ?>

                    <div class="price-table-wrapper">
                        <div class="section-header">
                            <?php if( !empty( $options['pricing_title_' . $i ] ) ):
                            ?>
                            <span><?php echo esc_html( $options['pricing_title_' . $i ] ); ?></span>

                        <?php endif;

                        if( !empty( $options['pricing_price_' . $i ] ) ):

                            ?>
                        <h2 class="section-title"><?php echo esc_html( $options['pricing_price_' . $i ] ); ?></span></h2>

                    <?php endif;

                    if( !empty( $options['time_duration_' . $i ] ) ):

                        ?>
                    <span><?php echo esc_html( $options['time_duration_' . $i ] ); ?></span>
                <?php endif; ?>
            </div><!-- .section-header -->
            <div class="details-wrapper">
                <ul>
                    <?php 
                    $price_lists = ! empty( $options['price_list_' . $i ] ) ? explode( '|', $options['price_list_' . $i ] ) : array();
                    foreach ($price_lists as $price_list ) { 
                        if ( isset( $price_list ) ) { 
                            ?>
                            <li><?php echo esc_html( $price_list ); ?></li>
                            <?php }  
                        } ?>
                    </ul>

                    <?php if( !empty( $options['pricing_btn_url_' . $i ] ) && !empty( $options['pricing_btn_' . $i ] ) ): ?>
                    <div class="read-more">
                    <a href="<?php echo esc_url( $options['pricing_btn_url_' . $i ] ); ?>" class="btn"><?php echo esc_html( $options['pricing_btn_' . $i ] ); ?></a>
                    </div>
                <?php endif; ?>
                </div>
            </div>

        <?php endfor; ?>

    </article>

</div>
</div><!-- #pricing -->

<?php    }
endif;