<?php
/**
 * recent_products section
 *
 * This is the template for the content of recent_products section
 *
 * @package Theme Palace
 * @subpackage Mega Charity Pro
 * @since Mega Charity Pro 1.0.0
 */
if ( ! function_exists( 'mega_charity_pro_add_recent_products_section' ) ) :
    /**
    * Add recent_products section
    *
    *@since Mega Charity Pro 1.0.0
    */
    function mega_charity_pro_add_recent_products_section() {
        $options = mega_charity_pro_get_theme_options();
        // Check if recent_products is enabled on frontpage
        $recent_products_enable = apply_filters( 'mega_charity_pro_section_status', true, 'recent_products_section_enable' );

        if ( ( true !== $recent_products_enable ) || ! class_exists( 'WooCommerce' ) ) {
            return false;
        }
        // Get recent_products section details
        $section_details = array();
        $section_details = apply_filters( 'mega_charity_pro_filter_recent_products_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render recent_products section now.
        mega_charity_pro_render_recent_products_section( $section_details );
    }
endif;

if ( ! function_exists( 'mega_charity_pro_get_recent_products_section_details' ) ) :
    /**
    * recent_products section details.
    *
    * @since Mega Charity Pro 1.0.0
    * @param array $input recent_products section details.
    */
    function mega_charity_pro_get_recent_products_section_details( $input ) {
        $options = mega_charity_pro_get_theme_options();

        // Content type.
        $recent_products_content_type  = get_theme_mod( 'mega_charity_pro_theme_options_recent_products_content_type', 'product-category' );    
        $recent_products_count = get_theme_mod( 'mega_charity_pro_theme_options_recent_products_count', 4 );
        
        $content = array();
        $content = array();
        switch ( $recent_products_content_type ) {

            case 'product':
                $page_ids = array();

                for ( $i = 1; $i <= $recent_products_count; $i++ ) {
                    if ( ! empty( $options['recent_products_content_product_' . $i] ) )
                        $page_ids[] = $options['recent_products_content_product_' . $i];
                }

                $args = array(
                    'post_type'         => 'product',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $recent_products_count ),
                    'orderby'           => 'post__in',
                    );
            break;
            case 'product-category':
                $cat_id = ! empty( $options['recent_products_content_product_category'] ) ? $options['recent_products_content_product_category'] : '';

                $args = array(
                'post_type'         => 'product',
                'posts_per_page'    => absint( $recent_products_count ),
                'tax_query'         => array(
                    array(
                        'taxonomy'  => 'product_cat',
                        'field'     => 'id',
                        'terms'     => $cat_id
                    )
                ) );
            break;

            default:
            break;
        }


        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['title']     = get_the_title();
                $page_post['url']       = get_the_permalink();
                $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'large' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-590x650.jpg';

                // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
        endif;
        wp_reset_postdata();

        
    
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// recent_products section content details.
add_filter( 'mega_charity_pro_filter_recent_products_section_details', 'mega_charity_pro_get_recent_products_section_details' );


if ( ! function_exists( 'mega_charity_pro_render_recent_products_section' ) ) :
  /**
   * Start recent_products section
   *
   * @return string recent_products content
   * @since Mega Charity Pro 1.0.0
   *
   */
   function mega_charity_pro_render_recent_products_section( $content_details = array() ) {
        $options = mega_charity_pro_get_theme_options();
        $class = ( $options['home_layout'] == 'sixth-design' || $options['home_layout'] == 'default-design-all' ) ? 'shop-' : '';

        if ( empty( $content_details ) ) {
            return;
        } ?>
        
        <div id="recent-products" class="relative page-section same-background">
            <div class="wrapper">
            <?php if ( is_customize_preview()):
                mega_charity_pro_section_tooltip( 'recent-products' );
                endif; ?>
                <div class="section-header">
                    <?php if( !empty( $options['recent_products_title'] ) ): ?>
                        <h2 class="<?php echo esc_attr( $class ); ?>section-title"><?php echo esc_html( $options['recent_products_title'] ) ; ?></h2>
                    <?php endif;
                    if( !empty( $options['recent_products_sub_title'] ) ):
                       ?>
                   <p class="<?php echo esc_attr( $class ); ?>subtitle"><?php echo esc_html( $options['recent_products_sub_title'] ) ; ?></p>
               <?php endif; ?>
           </div><!-- .section-header -->

           <div class="section-content">
            <ul class="products col-4">

               <?php foreach ( $content_details as $content ): 
               $image = $content['image'] == '' ? get_template_directory_uri().'/assets/uploads/no-featured-image-590x650.jpg' : $content['image'] ;
               ?>

               <li class="product featured-products">
                <a href="<?php echo esc_url( $content['url'] ) ; ?>" class="woocommerce-LoopProduct-link woocommerce-loop-product__link">
                    <img src="<?php echo esc_url($image); ?>">
                    <h2 class="woocommerce-loop-product__title"><?php echo esc_html( $content['title'] ); ?></h2>
                    <span class="price">
                        <ins><span class="woocommerce-Price-amount amount">
                            <?php 
                            $product = new WC_Product( $content['id'] );
                            echo $product->get_price_html();
                            ?>
                        </span></ins>
                    </span>
                </a>
                <?php if( $options['home_layout'] == 'ninth-design' ): ?>
                <a href="<?php echo do_shortcode( '[add_to_cart_url id="' . absint( $content['id'] ) . '"]' ); ?>" class="button product_type_simple add_to_cart_button ajax_add_to_cart"><?php esc_html_e('Add to cart', 'mega-charity-pro'); ?></a>
            <?php endif; ?>
            </li>

        <?php endforeach; ?>

    </ul><!-- .product-slider -->
</div><!-- .section-content -->
</div><!-- .wrapper -->
</div><!-- #recent-products -->

    <?php }
endif;