<?php
/**
 * release section
 *
 * This is the template for the content of release section
 *
 * @package Theme Palace
 * @subpackage Mega Charity Pro
 * @since Mega Charity Pro 1.0.0
 */
if ( ! function_exists( 'mega_charity_pro_add_release_section' ) ) :
    /**
    * Add release section
    *
    *@since Mega Charity Pro 1.0.0
    */
    function mega_charity_pro_add_release_section() {
        $options = mega_charity_pro_get_theme_options();
        // Check if release is enabled on frontpage
        $release_enable = apply_filters( 'mega_charity_pro_section_status', true, 'release_section_enable' );

        if ( true !== $release_enable ) {
            return false;
        }
        // Get release section details
        $section_details = array();
        $section_details = apply_filters( 'mega_charity_pro_filter_release_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render release section now.
        mega_charity_pro_render_release_section( $section_details );
    }
endif;

if ( ! function_exists( 'mega_charity_pro_get_release_section_details' ) ) :
    /**
    * release section details.
    *
    * @since Mega Charity Pro 1.0.0
    * @param array $input release section details.
    */
    function mega_charity_pro_get_release_section_details( $input ) {
        $options = mega_charity_pro_get_theme_options();

        // Content type.
        $release_content_type  = get_theme_mod( 'mega_charity_pro_theme_options_release_content_type', 'post' );
        $release_count = get_theme_mod( 'mega_charity_pro_theme_options_release_count', 3 );
        
        $content = array();
        switch ( $release_content_type ) {
            
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $release_count; $i++ ) {
                    if ( ! empty( $options['release_content_page_' . $i] ) )
                        $page_ids[] = $options['release_content_page_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $release_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $release_count; $i++ ) {
                    if ( ! empty( $options['release_content_post_' . $i] ) )
                        $post_ids[] = $options['release_content_post_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $release_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['release_content_category'] ) ? $options['release_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $release_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            default:
            break;
        }


        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['title']     = get_the_title();
                $page_post['url']       = get_the_permalink();
                $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'full' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-590x650.jpg';

                // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
        endif;
        wp_reset_postdata();

            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// release section content details.
add_filter( 'mega_charity_pro_filter_release_section_details', 'mega_charity_pro_get_release_section_details' );


if ( ! function_exists( 'mega_charity_pro_render_release_section' ) ) :
  /**
   * Start release section
   *
   * @return string release content
   * @since Mega Charity Pro 1.0.0
   *
   */
   function mega_charity_pro_render_release_section( $content_details = array() ) {
        $options = mega_charity_pro_get_theme_options();

        if ( empty( $content_details ) ) {
            return;
        } ?>

       <div id="release" class="page-section">
                <div class="wrapper">
                   <?php if ( is_customize_preview()):
                   mega_charity_pro_section_tooltip( 'release' );
                   endif; ?>
                <?php if( !empty( $options['release_title'] ) ): ?>
                    <div class="section-header">
                        <h2 class="section-title"><?php echo esc_html( $options['release_title'] ); ?></h2>
                    </div>
                <?php endif; ?>

                    <div class="release-wrapper <?php echo esc_attr( $options['release_column_layout'] ); ?> clear">
                        
                        <?php foreach ($content_details as $content): ?>

                        <article class="hentry">
                            <div class="featured-image" style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');">
                                <header class="entry-header">
                                    <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                </header>
                            </div>
                        </article>

                    <?php endforeach; ?>
                         
                    </div><!-- .release-wrapper -->

                    <?php if( !empty( $options['release_btn_url'] ) && !empty( $options['release_btn_title'] ) ): ?>
                    <div class="read-more">
                        <a href="<?php echo esc_url( $options['release_btn_url'] ); ?>" class="btn btn-fill" tabindex="0"><?php echo esc_html( $options['release_btn_title'] ); ?></a>
                    </div><!-- .read-more -->
                <?php endif; ?>
                </div><!-- .wrapper -->
            </div><!-- #relaese -->

    <?php }
endif;