<?php
/**
 * Service section
 *
 * This is the template for the content of service section
 *
 * @package Theme Palace
 * @subpackage Mega Charity Pro
 * @since Mega Charity Pro 1.0.0
 */
if ( ! function_exists( 'mega_charity_pro_add_service_section' ) ) :
    /**
    * Add service section
    *
    *@since Mega Charity Pro 1.0.0
    */
    function mega_charity_pro_add_service_section() {
        $options = mega_charity_pro_get_theme_options();
        // Check if service is enabled on frontpage
        $service_enable = apply_filters( 'mega_charity_pro_section_status', true, 'service_section_enable' );

        if ( true !== $service_enable ) {
            return false;
        }
        // Get service section details
        $section_details = array();
        $section_details = apply_filters( 'mega_charity_pro_filter_service_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render service section now.
        mega_charity_pro_render_service_section( $section_details );
    }
endif;

if ( ! function_exists( 'mega_charity_pro_get_service_section_details' ) ) :
    /**
    * service section details.
    *
    * @since Mega Charity Pro 1.0.0
    * @param array $input service section details.
    */
    function mega_charity_pro_get_service_section_details( $input ) {
        $options = mega_charity_pro_get_theme_options();

        // Content type.
        $service_content_type  = get_theme_mod( 'mega_charity_pro_theme_options_service_content_type', 'category' );
        $service_count  = get_theme_mod( 'mega_charity_pro_theme_options_service_count', 4 );
        
        $content = array();
        switch ( $service_content_type ) {
            
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $service_count; $i++ ) {
                    if ( ! empty( $options['service_content_page_' . $i] ) )
                        $page_ids[] = $options['service_content_page_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => $service_count,
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $service_count; $i++ ) {
                    if ( ! empty( $options['service_content_post_' . $i] ) )
                        $post_ids[] = $options['service_content_post_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => $service_count,
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['service_content_category'] ) ? $options['service_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => $service_count,
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            default:
            break;
        }

        // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['title']     = get_the_title();
                    $page_post['url']       = get_the_permalink();
                    $page_post['excerpt']   = mega_charity_pro_trim_content( $options['service_excerpt_length'] );
                    $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'full' ) : '';

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();

            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// service section content details.
add_filter( 'mega_charity_pro_filter_service_section_details', 'mega_charity_pro_get_service_section_details' );


if ( ! function_exists( 'mega_charity_pro_render_service_section' ) ) :
  /**
   * Start service section
   *
   * @return string service content
   * @since Mega Charity Pro 1.0.0
   *
   */
   function mega_charity_pro_render_service_section( $content_details = array() ) {
        $options = mega_charity_pro_get_theme_options();
        
        $button = $options['service_btn_title'] ? $options['service_btn_title'] : '';
        $column = $options['service_column_layout'] ? $options['service_column_layout'] : 'col-4';

        if ( empty( $content_details ) ) {
            return;
        } 
        ?> 

        <?php if( in_array($options['home_layout'], array( 'default-design-all', 'default-design', 'ninth-design', 'tenth-design' ) ) ): ?>
        
        <div id="our-services" class="relative page-section">
            <div class="wrapper">
            <?php if ( is_customize_preview()):
                mega_charity_pro_section_tooltip( 'our-services' );
                endif; ?>

                <?php if( $options['home_layout'] == 'default-design-all' || $options['home_layout'] == 'default-design' || $options['home_layout'] == 'ninth-design' ): ?>
                <div class="section-header-wrapper">
                    <?php if( !empty( $options['service_title'] ) ): ?>
                        <div class="section-header">
                            <h2 class="section-title"><?php echo mega_charity_pro_santize_allow_tag( $options['service_title'] ); ?></h2>
                        </div><!-- .section-header -->
                    <?php endif; 

                    if( $options['home_layout'] == 'default-design-all' || $options['home_layout'] == 'default-design' ):

                        if( !empty( $options['service_btn_url'] ) && !empty( $button ) ):
                            ?>
                        <a href="<?php echo esc_url( $options['service_btn_url'] ); ?>" class="btn"><?php echo esc_html( $button ); ?></a>
                        <?php 
                        endif;
                        endif;
                        ?>
                </div><!-- .section-header-wrapper -->

            <?php endif; ?>

                <div class="section-content <?php echo esc_attr( $column ); ?> clear">

                <?php $i = 1; foreach ( $content_details as $content ) : ?>

                    <article class ="hentry">
                        <div class="service-item-wrapper">
                            <div class="service-icon">
                                <a href="<?php echo esc_url( $content['url'] ); ?>">
                                     <i class="fa <?php echo ! empty( $options['service_content_icon_' . $i] ) ? esc_attr( $options['service_content_icon_' . $i] ) : 'fa-handshake-o'; ?>"></i>
                                </a>
                            </div><!-- .service-icon -->

                            <header class="entry-header">
                                <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                            </header>

                            <div class="entry-content">
                                <p><?php echo esc_html( $content['excerpt'] ); ?></p>
                            </div><!-- .entry-content -->
                        </div><!-- .service-item-wrapper -->
                    </article>

                <?php $i++; endforeach; ?>

                </div>

                <?php if( $options['home_layout'] == 'default-design-all' || $options['home_layout'] == 'default-design' ):

                if( !empty( $options['service_btn_url'] ) && !empty( $button ) ): ?>
                <div class="read-more">
                    <a href="<?php echo esc_url( $options['service_btn_url'] ); ?>" class="btn"><?php echo esc_html( $button ); ?></a>
                </div>
            <?php endif;

            endif; ?>
            
            </div><!-- .wrapper -->
        </div><!-- #our-services -->

    <?php endif; ?>

        <?php if( in_array($options['home_layout'], array( 'fifth-design', 'eight-design' ) ) ): ?>

            <div id="business-services-section" class="relative page-section">
                <div class="wrapper">
                <?php if ( is_customize_preview()):
                mega_charity_pro_section_tooltip( 'business-services-section' );
                endif; ?>
                    <div class="section-content <?php echo esc_attr( $column ); ?> clear">
                        
                        <?php $i = 1; foreach ( $content_details as $content ) : ?>
                       
                        <article>
                            <div class="service-item">
                                <div class="icon-container">
                                    
                                    <a href="<?php echo esc_url( $content['url'] ); ?>">
                                       <i class="fa <?php echo ! empty( $options['service_content_icon_' . $i] ) ? esc_attr( $options['service_content_icon_' . $i] ) : 'fa-handshake-o'; ?>"></i>
                                   </a>

                                </div><!-- .icon-container -->

                                <header class="entry-header">
                                    <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                </header>

                                <div class="entry-content">
                                    <p><?php echo esc_html( $content['excerpt'] ); ?></p>                    
                                </div><!-- .entry-content -->
                            </div><!-- .service-item -->
                        </article>

                       <?php $i++; endforeach; ?>

                    </div><!-- .section-content -->
                </div><!-- .wrapper -->
            </div><!-- #business-services-section -->

        <?php endif; ?>

        <?php if( $options['home_layout'] == 'sixth-design' ): ?>

            <div id="our-services" class="relative page-section">
                <div class="wrapper">
                    <div class="<?php echo esc_attr( $column ); ?> clear">
                       
                       <?php $i = 1; foreach ( $content_details as $content ) : ?>

                        <article>
                            <div class="service-item-wrapper">
                                <div class="service-icon">
                                   <a href="<?php echo esc_url( $content['url'] ); ?>">
                                       <i class="fa <?php echo ! empty( $options['service_content_icon_' . $i] ) ? esc_attr( $options['service_content_icon_' . $i] ) : 'fa-handshake-o'; ?>"></i>
                                   </a>
                                </div><!-- .service-icon -->

                                <div class="entry-container">
                                    <header class="entry-header">
                                        <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                        <span><?php echo esc_html( $content['excerpt'] ); ?></span>
                                    </header>
                                </div><!-- .entry-container -->
                            </div><!-- .service-item-wrapper -->
                        </article>

                        <?php $i++; endforeach; ?>

                    </div><!-- .col-3 -->
                </div><!-- .wrapper -->
            </div><!-- #our-services -->

        <?php endif; ?>

    <?php }
endif;