<?php
/**
 * Stories section
 *
 * This is the template for the content of stories section
 *
 * @package Theme Palace
 * @subpackage Mega Charity Pro
 * @since Mega Charity Pro 1.0.0
 */
if ( ! function_exists( 'mega_charity_pro_add_stories_section' ) ) :
    /**
    * Add stories section
    *
    *@since Mega Charity Pro 1.0.0
    */
    function mega_charity_pro_add_stories_section() {
        $options = mega_charity_pro_get_theme_options();
        // Check if stories is enabled on frontpage
        $stories_enable = apply_filters( 'mega_charity_pro_section_status', true, 'stories_section_enable' );

        if ( true !== $stories_enable ) {
            return false;
        }
        // Get stories section details
        $section_details = array();
        $section_details = apply_filters( 'mega_charity_pro_filter_stories_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render stories section now.
        mega_charity_pro_render_stories_section( $section_details );
    }
endif;

if ( ! function_exists( 'mega_charity_pro_get_stories_section_details' ) ) :
    /**
    * stories section details.
    *
    * @since Mega Charity Pro 1.0.0
    * @param array $input stories section details.
    */
    function mega_charity_pro_get_stories_section_details( $input ) {
        $options = mega_charity_pro_get_theme_options();

        // Content type.
        $stories_content_type  = get_theme_mod( 'mega_charity_pro_theme_options_stories_content_type', 'category' );
        $stories_count = get_theme_mod( 'mega_charity_pro_theme_options_stories_count', 5 );
        $content = array();
        switch ( $stories_content_type ) {
            
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $stories_count; $i++ ) {
                    if ( ! empty( $options['stories_content_page_' . $i] ) ) :
                        $page_ids[] = $options['stories_content_page_' . $i];
                    endif;
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $stories_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $stories_count; $i++ ) {
                    if ( ! empty( $options['stories_content_post_' . $i] ) ) :
                        $post_ids[] = $options['stories_content_post_' . $i];
                    endif;
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $stories_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['stories_content_category'] ) ? $options['stories_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $stories_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;
            
            default:
            break;
        }

        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['title']     = get_the_title();
                $page_post['url']       = get_the_permalink();
                $page_post['excerpt']   = mega_charity_pro_trim_content( $options['stories_excerpt_length'] );
                $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'large' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-590x650.jpg';

                // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
        endif;
        wp_reset_postdata();
   
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// stories section content details.
add_filter( 'mega_charity_pro_filter_stories_section_details', 'mega_charity_pro_get_stories_section_details' );


if ( ! function_exists( 'mega_charity_pro_render_stories_section' ) ) :
  /**
   * Start stories section
   *
   * @return string stories content
   * @since Mega Charity Pro 1.0.0
   *
   */
   function mega_charity_pro_render_stories_section( $content_details = array() ) {
        $options = mega_charity_pro_get_theme_options();
        $autoplay = !empty( $options['stories_auto_play'] ) ? $options['stories_auto_play'] : 'false';

        if ( empty( $content_details ) ) {
            return;
        } ?>
        
        <div id="stories" class="page-section no-padding-top">
            <div class="wrapper">
            <?php if ( is_customize_preview()):
            mega_charity_pro_section_tooltip( 'stories' );
            endif; ?>
                <?php if( !empty( $options['stories_section_title'] ) ): ?>
                    <div class="section-header">
                        <h2 class="section-title"><?php echo esc_html( $options['stories_section_title'] ); ?></h2>
                    </div>
                <?php endif; ?>

                <div class="story-slider" data-slick='{"slidesToShow": 4, "slidesToScroll": 1, "infinite": true, "speed": 1500, "dots": false, "arrows":false, "autoplay": <?php echo esc_attr( $autoplay ); ?>, "draggable": true, "fade": false }'>

                    <?php $i = 1 ; foreach ( $content_details as $content ) : ?>

                    <article>
                        <div class="help-wrapper">
                            <div class="featured-image" style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');">
                                <a href="<?php echo esc_url( $content['url'] ); ?>" class="post-thumbnail-link"></a>
                                <div class="overlay"></div>
                                <?php if( !empty( $content['url'] ) && !empty( $options['stories_btn'] ) ): ?>
                                    <a href="<?php echo esc_url( $content['url'] ); ?>" class="btn"><?php echo esc_html( $options['stories_btn'] ); ?></a>
                                <?php endif; ?>
                            </div><!-- .featured-image -->

                            <div class="entry-container">
                                <header class="entry-header">
                                    <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                </header>

                                <?php if ( !empty($options['stories_years_age_'.$i]) ): ?>
                                    <div class="entry-meta">
                                        <span class="cat-links">
                                            <ul class="post-categories">
                                                <li><?php echo esc_html( $options['stories_years_age_'.$i] ); ?></li>
                                            </ul>
                                        </span>
                                    </div><!-- .entry-meta -->
                                <?php endif; ?>

                                <div class="entry-content">
                                    <p><?php echo wp_kses_post( $content['excerpt'] ); ?></p>
                                </div>

                            </div><!-- .entry-container -->
                        </div><!-- .help-wrapper -->
                    </article>

                    <?php $i++ ; endforeach ; ?>

                </div>
            </div>
        </div>
       
    <?php }
endif;
