<?php
/**
 * Video section
 *
 * This is the template for the content of video section
 *
 * @package Theme Palace
 * @subpackage Mega Charity Pro
 * @since Mega Charity Pro 1.0.0
 */
if ( ! function_exists( 'mega_charity_pro_add_video_section' ) ) :
    /**
    * Add video section
    *
    *@since Mega Charity Pro 1.0.0
    */
    function mega_charity_pro_add_video_section() {
    	$options = mega_charity_pro_get_theme_options();
        // Check if video is enabled on frontpage
        $video_enable = apply_filters( 'mega_charity_pro_section_status', true, 'video_section_enable' );

        if ( true !== $video_enable ) {
            return false;
        }
        // Get video section details
        $section_details = array();
        $section_details = apply_filters( 'mega_charity_pro_filter_video_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render video section now.
        mega_charity_pro_render_video_section( $section_details );
    }
endif;

if ( ! function_exists( 'mega_charity_pro_get_video_section_details' ) ) :
    /**
    * video section details.
    *
    * @since Mega Charity Pro 1.0.0
    * @param array $input video section details.
    */
    function mega_charity_pro_get_video_section_details( $input ) {
        $options = mega_charity_pro_get_theme_options();

        // Content type.
        $video_content_type  = get_theme_mod( 'mega_charity_pro_theme_options_video_content_type', 'page' );
        
        $content = array();
        switch ( $video_content_type ) {
        
            case 'page':
                $page_id = ! empty( $options['video_content_page'] ) ? $options['video_content_page'] : '';
                $args = array(
                    'post_type'         => 'page',
                    'page_id'           => $page_id,
                    'posts_per_page'    => 1,
                    );                    
            break;

            case 'post':
                $post_id = ! empty( $options['video_content_post'] ) ? $options['video_content_post'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'p'                 => $post_id,
                    'posts_per_page'    => 1,
                    );
            break;

            default:
            break;
        }
        
            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['id']        = get_the_id();
                    $page_post['title']     = get_the_title();
                    $page_post['excerpt']   = mega_charity_pro_trim_content( $options['video_excerpt_length'] );
                    $page_post['url']       = get_the_permalink();

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// video section content details.
add_filter( 'mega_charity_pro_filter_video_section_details', 'mega_charity_pro_get_video_section_details' );


if ( ! function_exists( 'mega_charity_pro_render_video_section' ) ) :
  /**
   * Start video section
   *
   * @return string video content
   * @since Mega Charity Pro 1.0.0
   *
   */
function mega_charity_pro_render_video_section( $content_details = array() ) {
    $options = mega_charity_pro_get_theme_options();

    if ( empty( $content_details ) ) {
        return;
    } 
    ?>
    

    <div id="video" class="relative page-section" style="background-image:url('<?php echo esc_url( $options['video_bg_image'] ); ?>')">
        <div class="wrapper">
            <?php if ( is_customize_preview()):
            mega_charity_pro_section_tooltip( 'video' );
            endif; ?>
            <?php foreach ( $content_details as $content ) : ?>
                <div class="video-wrapper">
                <?php if( !empty( $content['title'] ) ): ?>
                    <div class="section-header">
                        <h2 class="section-title"><?php echo esc_html( $content['title'] ) ; ?></h2>
                    </div>
                <?php endif; ?>

                    <div class="section-content">
                    <?php if( !empty( $content['excerpt'] ) ): ?>
                        <div class="entry-content">
                        <p><?php echo esc_html( $content['excerpt'] ) ; ?></p>
                        </div><!-- .entry-content -->
                    <?php endif; ?>

                    <?php if( !empty( $options['video_url'] ) ): ?>
                        <div class="video-button">
                            <a href="<?php echo esc_url( $options['video_url'] ) ; ?>" class="popup-youtube">
                                <svg class="svg-inline--fa fa-play fa-w-14" viewBox="0 0 448 512"><path d="M424.4 214.7L72.4 6.6C43.8-10.3 0 6.1 0 47.9V464c0 37.5 40.7 60.1 72.4 41.3l352-208c31.4-18.5 31.5-64.1 0-82.6z"></path></svg>
                            </a>
                        </div>
                    <?php endif; ?>
                    </div><!-- .section-content -->
                </div>
            <?php endforeach; ?>
        </div>
    </div>


    <?php
}
endif;

